@@ -72,10 +72,12 @@ OperationParameters* AlgorithmCiftiCorrelationGradient::getParameters()
     cerebCorrAreasOpt->addMetricParameter(1, "area-metric", "the corrected vertex areas, as a metric");
     
     OptionalParameter* presmoothSurfOpt = ret->createOptionalParameter(6, "-surface-presmooth", "smooth on the surface before computing the gradient");
-    presmoothSurfOpt->addDoubleParameter(1, "surface-kernel", "the sigma for the gaussian surface smoothing kernel, in mm");
+    presmoothSurfOpt->addDoubleParameter(1, "surface-kernel", "the size of the gaussian surface smoothing kernel in mm, as sigma by default");
     
     OptionalParameter* presmoothVolOpt = ret->createOptionalParameter(7, "-volume-presmooth", "smooth the volume before computing the gradient");
-    presmoothVolOpt->addDoubleParameter(1, "volume-kernel", "the sigma for the gaussian volume smoothing kernel, in mm");
+    presmoothVolOpt->addDoubleParameter(1, "volume-kernel", "the size of the gaussian volume smoothing kernel in mm, as sigma by default");
+    
+    ret->createOptionalParameter(15, "-presmooth-fwhm", "smoothing kernel sizes are FWHM, not sigma");
     
     ret->createOptionalParameter(8, "-undo-fisher-z", "apply the inverse fisher small z transform to the input");
     
@@ -153,6 +155,11 @@ void AlgorithmCiftiCorrelationGradient::useParameters(OperationParameters* myPar
     {
         volKern = (float)presmoothVolOpt->getDouble(1);
     }
+    if (myParams->getOptionalParameter(15)->m_present)
+    {
+        if (surfKern > 0.0f) surfKern = surfKern / (2.0f * sqrt(2.0f * log(2.0f)));
+        if (volKern > 0.0f) volKern = volKern / (2.0f * sqrt(2.0f * log(2.0f)));
+    }
     bool undoFisherInput = myParams->getOptionalParameter(8)->m_present;
     bool applyFisher = myParams->getOptionalParameter(12)->m_present;
     float surfaceExclude = -1.0f;
@@ -786,12 +793,12 @@ void AlgorithmCiftiCorrelationGradient::processVolumeComponent(StructureEnum::En
     int64_t offset[3];
     if (mapSize > 0)
     {//make a voxel bounding box to minimize memory usage
-        int extrema[6] = { myMap[0].m_ijk[0],
-            myMap[0].m_ijk[0],
-            myMap[0].m_ijk[1],
-            myMap[0].m_ijk[1],
-            myMap[0].m_ijk[2],
-            myMap[0].m_ijk[2]
+        int64_t extrema[6] = { myMap[0].m_ijk[0],
+                               myMap[0].m_ijk[0],
+                               myMap[0].m_ijk[1],
+                               myMap[0].m_ijk[1],
+                               myMap[0].m_ijk[2],
+                               myMap[0].m_ijk[2]
         };
         for (int64_t i = 1; i < mapSize; ++i)
         {
@@ -935,12 +942,12 @@ void AlgorithmCiftiCorrelationGradient::processVolumeComponent(StructureEnum::En
     int64_t offset[3];
     if (mapSize > 0)
     {//make a voxel bounding box to minimize memory usage
-        int extrema[6] = { myMap[0].m_ijk[0],
-            myMap[0].m_ijk[0],
-            myMap[0].m_ijk[1],
-            myMap[0].m_ijk[1],
-            myMap[0].m_ijk[2],
-            myMap[0].m_ijk[2]
+        int64_t extrema[6] = { myMap[0].m_ijk[0],
+                               myMap[0].m_ijk[0],
+                               myMap[0].m_ijk[1],
+                               myMap[0].m_ijk[1],
+                               myMap[0].m_ijk[2],
+                               myMap[0].m_ijk[2]
         };
         for (int64_t i = 1; i < mapSize; ++i)
         {
