@@ -21,10 +21,12 @@
 #include "AlgorithmVolumeToSurfaceMapping.h"
 #include "AlgorithmException.h"
 
+#include "CaretAssert.h"
 #include "CaretOMP.h"
 #include "FloatMatrix.h"
 #include "MathFunctions.h"
 #include "MetricFile.h"
+#include "SignedDistanceHelper.h"
 #include "SurfaceFile.h"
 #include "TopologyHelper.h"
 #include "Vector3D.h"
@@ -68,12 +70,15 @@ OperationParameters* AlgorithmVolumeToSurfaceMapping::getParameters()
     ribbonOpt->addSurfaceParameter(1, "inner-surf", "the inner surface of the ribbon");
     ribbonOpt->addSurfaceParameter(2, "outer-surf", "the outer surface of the ribbon");
     OptionalParameter* roiVol = ribbonOpt->createOptionalParameter(3, "-volume-roi", "use a volume roi");
-    roiVol->addVolumeParameter(1, "roi-volume", "the volume file");
+    roiVol->addVolumeParameter(1, "roi-volume", "the roi volume file");
+    roiVol->createOptionalParameter(2, "-weighted", "treat the roi values as weightings rather than binary");
     OptionalParameter* ribbonSubdiv = ribbonOpt->createOptionalParameter(4, "-voxel-subdiv", "voxel divisions while estimating voxel weights");
     ribbonSubdiv->addIntegerParameter(1, "subdiv-num", "number of subdivisions, default 3");
     ribbonOpt->createOptionalParameter(7, "-thin-columns", "use non-overlapping polyhedra");
     OptionalParameter* gaussianOpt = ribbonOpt->createOptionalParameter(8, "-gaussian", "reduce weight to voxels that aren't near <surface>");
     gaussianOpt->addDoubleParameter(1, "scale", "value to multiply the local thickness by, to get the gaussian sigma");
+    OptionalParameter* ribbonInterpOpt = ribbonOpt->createOptionalParameter(10, "-interpolate", "instead of a weighted average of voxels, interpolate at subpoints inside the ribbon");
+    ribbonInterpOpt->addStringParameter(1, "method", "interpolation method, must be CUBIC, ENCLOSING_VOXEL, or TRILINEAR");
     OptionalParameter* badVertOpt = ribbonOpt->createOptionalParameter(9, "-bad-vertices-out", "output an ROI of which vertices didn't intersect any valid voxels");
     badVertOpt->addMetricOutputParameter(1, "roi-out", "the output metric file of vertices that have no data");
     OptionalParameter* ribbonWeights = ribbonOpt->createOptionalParameter(5, "-output-weights", "write the voxel weights for a vertex to a volume file");
@@ -93,7 +98,8 @@ OperationParameters* AlgorithmVolumeToSurfaceMapping::getParameters()
     
     ret->setHelpText(
         AString("You must specify exactly one mapping method.  Enclosing voxel uses the value from the voxel the vertex lies inside, while trilinear does a 3D ") + 
-        "linear interpolation based on the voxels immediately on each side of the vertex's position.\n\n" +
+        "linear interpolation based on the voxels immediately on each side of the vertex's position." +
+        "\n\n" +
         "The ribbon mapping method constructs a polyhedron from the vertex's neighbors on each " +
         "surface, and estimates the amount of this polyhedron's volume that falls inside any nearby voxels, to use as the weights for sampling.  " +
         "If -thin-columns is specified, the polyhedron uses the edge midpoints and triangle centroids, so that neighboring vertices do not have overlapping polyhedra.  " +
@@ -102,7 +108,11 @@ OperationParameters* AlgorithmVolumeToSurfaceMapping::getParameters()
         "voxels that don't have a positive value in the mask.  The subdivision number specifies how it approximates the amount of the volume the polyhedron " +
         "intersects, by splitting each voxel into NxNxN pieces, and checking whether the center of each piece is inside the polyhedron.  If you have very large " +
         "voxels, consider increasing this if you get zeros in your output.  " +
-        "The -gaussian option makes it act more like the myelin method, where the distance of a voxel from <surface> is used to downweight the voxel.\n\n" +
+        "The -gaussian option makes it act more like the myelin method, where the distance of a voxel from <surface> is used to downweight the voxel.  " +
+        "The -interpolate suboption, instead of doing a weighted average of voxels, interpolates from the volume at the subdivided points inside the ribbon.  " +
+        "If using both -interpolate and the -weighted suboption to -volume-roi, the roi volume weights are linearly interpolated, " +
+        "unless the -interpolate method is ENCLOSING_VOXEL, in which case ENCLOSING_VOXEL is also used for sampling the roi volume weights." +
+        "\n\n" +
         "The myelin style method uses part of the caret5 myelin mapping command to do the mapping: for each surface vertex, take all voxels that are in a cylinder " +
         "with radius and height equal to cortical thickness, centered on the vertex and aligned with the surface normal, and that are also within the ribbon ROI, " +
         "and apply a gaussian kernel with the specified sigma to them to get the weights to use.  " +
@@ -196,9 +206,11 @@ void AlgorithmVolumeToSurfaceMapping::useParameters(OperationParameters* myParam
             SurfaceFile* outerSurf = ribbonOpt->getSurface(2);
             OptionalParameter* roiVol = ribbonOpt->getOptionalParameter(3);
             VolumeFile* myRoiVol = NULL;
+            bool weightedRoi = false;
             if (roiVol->m_present)
             {
                 myRoiVol = roiVol->getVolume(1);
+                weightedRoi = roiVol->getOptionalParameter(2)->m_present;
             }
             int32_t subdivisions = 3;
             OptionalParameter* ribbonSubdiv = ribbonOpt->getOptionalParameter(4);
@@ -218,6 +230,23 @@ void AlgorithmVolumeToSurfaceMapping::useParameters(OperationParameters* myParam
                 gaussScale = (float)gaussianOpt->getDouble(1);
                 if (!(gaussScale > 0.0f)) throw AlgorithmException("gaussian scale must be positive");
             }
+            bool ribbonInterp = false;
+            OptionalParameter* ribbonInterpOpt = ribbonOpt->getOptionalParameter(10);
+            if (ribbonInterpOpt->m_present)
+            {
+                ribbonInterp = true;
+                AString interpMethod = ribbonInterpOpt->getString(1);
+                if (interpMethod == "CUBIC")
+                {
+                    volInterpMethod = VolumeFile::CUBIC;
+                } else if (interpMethod == "TRILINEAR") {
+                    volInterpMethod = VolumeFile::TRILINEAR;
+                } else if (interpMethod == "ENCLOSING_VOXEL") {
+                    volInterpMethod = VolumeFile::ENCLOSING_VOXEL;
+                } else {
+                    throw AlgorithmException("unrecognized volume interpolation method");
+                }
+            }
             MetricFile* badVertices = NULL;
             OptionalParameter* badVertOpt = ribbonOpt->getOptionalParameter(9);
             if (badVertOpt->m_present)
@@ -232,9 +261,19 @@ void AlgorithmVolumeToSurfaceMapping::useParameters(OperationParameters* myParam
                 weightsOutVertex = (int)ribbonWeights->getInteger(1);
                 weightsOut = ribbonWeights->getOutputVolume(2);
             }
-            AlgorithmVolumeToSurfaceMapping(myProgObj, myVolume, mySurface, myMetricOut, innerSurf, outerSurf, myRoiVol, subdivisions, thinColumns,
-                                            mySubVol, gaussScale, badVertices, weightsOutVertex, weightsOut);
             OptionalParameter* ribbonWeightsText = ribbonOpt->getOptionalParameter(6);
+            if (ribbonInterp)
+            {
+                if (ribbonWeightsText->m_present || weightsOut != NULL)
+                {
+                    throw AlgorithmException("-output-weights options are incompatible with -interpolate");
+                }
+                AlgorithmVolumeToSurfaceMapping(myProgObj, myVolume, mySurface, myMetricOut, innerSurf, outerSurf, volInterpMethod, myRoiVol, weightedRoi, subdivisions, thinColumns,
+                                                mySubVol, gaussScale, badVertices);
+            } else {
+                AlgorithmVolumeToSurfaceMapping(myProgObj, myVolume, mySurface, myMetricOut, innerSurf, outerSurf, myRoiVol, weightedRoi, subdivisions, thinColumns,
+                                                mySubVol, gaussScale, badVertices, weightsOutVertex, weightsOut);
+            }
             if (ribbonWeightsText->m_present)
             {//do this after the algorithm, to let it do the error condition checking
                 ofstream outFile(ribbonWeightsText->getString(1).toLocal8Bit().constData());
@@ -242,7 +281,7 @@ void AlgorithmVolumeToSurfaceMapping::useParameters(OperationParameters* myParam
                 vector<vector<VoxelWeight> > myWeights;
                 const float* roiFrame = NULL;
                 if (myRoiVol != NULL) roiFrame = myRoiVol->getFrame();
-                AlgorithmVolumeToSurfaceMapping::precomputeWeightsRibbon(myWeights, myVolume->getVolumeSpace(), innerSurf, outerSurf, roiFrame, subdivisions, thinColumns, mySurface, gaussScale);
+                AlgorithmVolumeToSurfaceMapping::precomputeWeightsRibbon(myWeights, myVolume->getVolumeSpace(), innerSurf, outerSurf, roiFrame, weightedRoi, subdivisions, thinColumns, mySurface, gaussScale);
                 for (int i = 0; i < (int)myWeights.size(); ++i)
                 {
                     outFile << i << ", " << myWeights[i].size();
@@ -369,7 +408,7 @@ AlgorithmVolumeToSurfaceMapping::AlgorithmVolumeToSurfaceMapping(ProgressObject*
 
 //ribbon mapping
 AlgorithmVolumeToSurfaceMapping::AlgorithmVolumeToSurfaceMapping(ProgressObject* myProgObj, const VolumeFile* myVolume, const SurfaceFile* mySurface, MetricFile* myMetricOut,
-                                                                 const SurfaceFile* innerSurf, const SurfaceFile* outerSurf, const VolumeFile* roiVol,
+                                                                 const SurfaceFile* innerSurf, const SurfaceFile* outerSurf, const VolumeFile* roiVol, const bool roiWeights,
                                                                  const int32_t& subdivisions, const bool& thinColumns, const int64_t& mySubVol, const float& gaussScale, MetricFile* badVertices,
                                                                  const int& weightsOutVertex, VolumeFile* weightsOut) : AbstractAlgorithm(myProgObj)
 {
@@ -415,7 +454,7 @@ AlgorithmVolumeToSurfaceMapping::AlgorithmVolumeToSurfaceMapping(ProgressObject*
     vector<vector<VoxelWeight> > myWeights;
     const float* roiFrame = NULL;
     if (roiVol != NULL) roiFrame = roiVol->getFrame();
-    precomputeWeightsRibbon(myWeights, myVolume->getVolumeSpace(), innerSurf, outerSurf, roiFrame, subdivisions, thinColumns, mySurface, gaussScale);
+    precomputeWeightsRibbon(myWeights, myVolume->getVolumeSpace(), innerSurf, outerSurf, roiFrame, roiWeights, subdivisions, thinColumns, mySurface, gaussScale);
     if (weightsOut != NULL)
     {
         weightsOut->setValueAllVoxels(0.0f);
@@ -511,17 +550,150 @@ AlgorithmVolumeToSurfaceMapping::AlgorithmVolumeToSurfaceMapping(ProgressObject*
     }
 }
 
+//interpolation ribbon mapping
+AlgorithmVolumeToSurfaceMapping::AlgorithmVolumeToSurfaceMapping(ProgressObject* myProgObj, const VolumeFile* myVolume, const SurfaceFile* mySurface, MetricFile* myMetricOut,
+                                                                 const SurfaceFile* innerSurf, const SurfaceFile* outerSurf, const VolumeFile::InterpType interpType, const VolumeFile* roiVol, const bool roiWeights,
+                                                                 const int32_t& subdivisions, const bool& thinColumns, const int64_t& mySubVol, const float& gaussScale, MetricFile* badVertices) : AbstractAlgorithm(myProgObj)
+{
+    LevelProgress myProgress(myProgObj);
+    vector<int64_t> myVolDims;
+    myVolume->getDimensions(myVolDims);
+    if (mySubVol >= myVolDims[3] || mySubVol < -1)
+    {
+        throw AlgorithmException("invalid subvolume specified");
+    }
+    if (!mySurface->hasNodeCorrespondence(*outerSurf) || !mySurface->hasNodeCorrespondence(*innerSurf))
+    {
+        throw AlgorithmException("all surfaces must have vertex correspondence");
+    }
+    if (roiVol != NULL && !roiVol->matchesVolumeSpace(myVolume))
+    {
+        throw AlgorithmException("roi volume is not in the same volume space as input volume");
+    }
+    int64_t startVol = 0, endVol = myVolDims[3];
+    if (mySubVol > -1)
+    {
+        startVol = mySubVol;
+        endVol = mySubVol + 1;
+    }
+    int64_t numColumns = (endVol - startVol) * myVolDims[4];
+    int64_t numNodes = mySurface->getNumberOfNodes();
+    myMetricOut->setNumberOfNodesAndColumns(numNodes, numColumns);
+    myMetricOut->setStructure(mySurface->getStructure());
+    vector<float> badVertScratch, myScratchArray(numNodes);
+    if (badVertices != NULL)
+    {
+        badVertices->setNumberOfNodesAndColumns(numNodes, 1);
+        badVertices->setStructure(mySurface->getStructure());
+        badVertScratch.resize(numNodes, 0.0f);
+    }
+    const float* roiFrame = NULL;
+    if (roiVol != NULL) roiFrame = roiVol->getFrame();
+    vector<vector<PointWeight> > pointList = RibbonMappingHelper::computePointsRibbon(myVolume->getVolumeSpace(), innerSurf, outerSurf, roiFrame, subdivisions, thinColumns);
+    CaretPointer<SignedDistanceHelperBase> myHelpBase;
+    if (gaussScale > 0.0f)
+    {
+        myHelpBase.grabNew(new SignedDistanceHelperBase(mySurface));
+    }
+    MetricFile thickness;
+    VolumeFile::InterpType roiInterp = VolumeFile::TRILINEAR;//TODO: should this change based on interpType? be explicit?
+    if (interpType == VolumeFile::ENCLOSING_VOXEL)
+    {
+        roiInterp = VolumeFile::ENCLOSING_VOXEL;
+    }
+    AlgorithmSurfaceToSurface3dDistance(NULL, innerSurf, outerSurf, &thickness);
+    for (int64_t i = startVol; i < endVol; ++i)
+    {
+        for (int64_t j = 0; j < myVolDims[4]; ++j)
+        {
+            if (interpType == VolumeFile::CUBIC)
+            {
+                myVolume->validateSpline(i, j);//to do spline deconvolution in parallel
+            }
+            int64_t thisCol = (i - startVol) * myVolDims[4] + j;
+            AString metricLabel = myVolume->getMapName(i);
+            if (myVolDims[4] != 1)
+            {
+                metricLabel += " component " + AString::number(j);
+            }
+            myMetricOut->setColumnName(thisCol, metricLabel);
+#pragma omp CARET_PAR
+            {
+                CaretPointer<SignedDistanceHelper> distHelp;
+                if (gaussScale > 0.0f)
+                {
+                    distHelp.grabNew(new SignedDistanceHelper(myHelpBase));
+                }
+#pragma omp CARET_FOR
+                for (int64_t node = 0; node < numNodes; ++node)
+                {
+                    double accum = 0.0, weightAccum = 0.0;
+                    float thisThick = thickness.getValue(node, 0);
+                    for (auto& point : pointList[node])
+                    {
+                        float value = myVolume->interpolateValue(point.coord, interpType, NULL, i, j);
+                        float weight = point.weight;
+                        if (roiWeights)
+                        {
+                            weight = weight * roiVol->interpolateValue(point.coord, roiInterp);
+                        }
+                        if (gaussScale > 0.0f)
+                        {
+                            float dist = distHelp->dist(point.coord, SignedDistanceHelper::EVEN_ODD);//could make a function for unsigned distance to speed this up some
+                            float toSquare = dist / (thisThick * gaussScale);
+                            weight = weight * exp(-toSquare * toSquare / 2);
+                        }
+                        accum += value * weight;
+                        weightAccum += weight;
+                    }
+                    if (weightAccum > 0.0)
+                    {
+                        myScratchArray[node] = accum / weightAccum;
+                    } else {
+                        myScratchArray[node] = 0.0f;
+                        if (badVertices != NULL)
+                        {
+                            badVertScratch[node] = 1.0f;
+                        }
+                    }
+                }
+            }
+            myMetricOut->setValuesForColumn(thisCol, myScratchArray.data());
+            if (interpType == VolumeFile::CUBIC)
+            {
+                myVolume->freeSpline(i, j);//release memory we no longer need, if we allocated it
+            }
+        }
+    }
+    if (badVertices != NULL)
+    {
+        badVertices->setValuesForColumn(0, badVertScratch.data());
+    }
+}
+
 void AlgorithmVolumeToSurfaceMapping::precomputeWeightsRibbon(vector<vector<VoxelWeight> >& myWeights, const VolumeSpace& volSpace,
-                                                              const SurfaceFile* innerSurf, const SurfaceFile* outerSurf, const float* roiFrame,
+                                                              const SurfaceFile* innerSurf, const SurfaceFile* outerSurf, const float* roiFrame, const bool roiWeights,
                                                               const int& subdivisions, const bool& thinColumns, const SurfaceFile* gaussSurf, const float& gaussScale)
 {
     RibbonMappingHelper::computeWeightsRibbon(myWeights, volSpace, innerSurf, outerSurf, roiFrame, subdivisions, thinColumns);
+    const int numNodes = innerSurf->getNumberOfNodes();
+    if (roiWeights)
+    {
+        CaretAssert(roiFrame != NULL);
+        for (int i = 0; i < numNodes; ++i)
+        {//modify the weights from the ribbon helper
+            vector<VoxelWeight>& nodeWeights = myWeights[i];
+            for (int j = 0; j < (int)nodeWeights.size(); ++j)
+            {
+                nodeWeights[j].weight *= roiFrame[volSpace.getIndex(nodeWeights[j].ijk)];
+            }
+        }
+    }
     if (gaussScale > 0.0f)
     {
         VolumeFile signedDistVol;
         MetricFile thickness;
         AlgorithmSurfaceToSurface3dDistance(NULL, innerSurf, outerSurf, &thickness);
-        int numNodes = innerSurf->getNumberOfNodes();
         float maxThick = thickness.getValue(0, 0);
         for (int i = 1; i < numNodes; ++i)
         {
