@@ -26,6 +26,7 @@
 #include "Annotation.h"
 #include "AnnotationArrangerExecutor.h"
 #include "AnnotationBrowserTab.h"
+#include "AnnotationClipboard.h"
 #include "AnnotationColorBar.h"
 #include "AnnotationFile.h"
 #include "AnnotationGroup.h"
@@ -50,9 +51,9 @@
 #include "EventBrowserWindowContent.h"
 #include "EventGetDisplayedDataFiles.h"
 #include "EventManager.h"
+#include "SamplesFile.h"
 #include "SceneClass.h"
 #include "SceneClassAssistant.h"
-#include "EventUserInputModeGet.h"
 
 using namespace caret;
 
@@ -66,15 +67,20 @@ using namespace caret;
 
 /**
  * Constructor.
+ * @param userInputMode
+ *    The user input mode
+ * @param brain
+ *    The brain
  */
-AnnotationManager::AnnotationManager(Brain* brain)
+AnnotationManager::AnnotationManager(const UserInputModeEnum::Enum userInputMode,
+                                     Brain* brain)
 : CaretObject(),
+m_userInputMode(userInputMode),
 m_brain(brain)
 {
     CaretAssert(m_brain);
     
-    m_clipboardAnnotationFile = NULL;
-    m_clipboardAnnotation.grabNew(NULL);
+    m_clipboard.reset(new AnnotationClipboard(m_brain));
     
     m_annotationsExceptBrowserTabsRedoUndoStack.grabNew(new CaretUndoStack());
     m_annotationsExceptBrowserTabsRedoUndoStack->setUndoLimit(500);
@@ -82,8 +88,10 @@ m_brain(brain)
     m_browserTabAnnotationsRedoUndoStack.grabNew(new CaretUndoStack());
     m_browserTabAnnotationsRedoUndoStack->setUndoLimit(100);
     
+    m_samplesAnnotationsRedoUndoStack.grabNew(new CaretUndoStack());
+    m_samplesAnnotationsRedoUndoStack->setUndoLimit(100);
+    
     for (int32_t i = 0; i < BrainConstants::MAXIMUM_NUMBER_OF_BROWSER_WINDOWS; i++) {
-        m_annotationBeingDrawnInWindow[i] = NULL;
         m_selectionInformation[i] = new AnnotationEditingSelectionInformation(i);
     }
 
@@ -100,15 +108,12 @@ AnnotationManager::~AnnotationManager()
     EventManager::get()->removeAllEventsFromListener(this);
     
     for (int32_t i = 0; i < BrainConstants::MAXIMUM_NUMBER_OF_BROWSER_WINDOWS; i++) {
-        if (m_annotationBeingDrawnInWindow[i] != NULL) {
-            delete m_annotationBeingDrawnInWindow[i];
-        }
-        
         delete m_selectionInformation[i];
     }
 
     m_annotationsExceptBrowserTabsRedoUndoStack->clear();
     m_browserTabAnnotationsRedoUndoStack->clear();
+    m_samplesAnnotationsRedoUndoStack->clear();
     
     delete m_sceneAssistant;
 }
@@ -121,6 +126,8 @@ AnnotationManager::reset()
 {
     m_annotationsExceptBrowserTabsRedoUndoStack->clear();
     m_browserTabAnnotationsRedoUndoStack->clear();
+    m_samplesAnnotationsRedoUndoStack->clear();
+    Annotation::unlockAllPolyhedronsInAllWindows();
 }
 
 /**
@@ -128,8 +135,6 @@ AnnotationManager::reset()
  * the command, the command is placed on the undo stack so that the
  * user can undo or redo the command.
  *
- * @param userInputMode
- *     The current user input mode which MUST be ANNOTATIONS or TILE_TABS_MANUAL_LAYOUT_EDITING
  * @param command
  *     Command that will be applied to the selected annotations.
  *     Annotation manager will take ownership of the command and
@@ -138,12 +143,10 @@ AnnotationManager::reset()
  *     Output with error information if command fails.
  */
 bool
-AnnotationManager::applyCommand(const UserInputModeEnum::Enum userInputMode,
-                                AnnotationRedoUndoCommand* command,
+AnnotationManager::applyCommand(AnnotationRedoUndoCommand* command,
                                 AString& errorMessageOut)
 {
-    return applyCommandInWindow(userInputMode,
-                                command,
+    return applyCommandInWindow(command,
                                 -1,
                                 errorMessageOut);
 }
@@ -153,8 +156,6 @@ AnnotationManager::applyCommand(const UserInputModeEnum::Enum userInputMode,
  * the command, the command is placed on the undo stack so that the
  * user can undo or redo the command.
  *
- * @param userInputMode
- *     The current user input mode which MUST be ANNOTATIONS or TILE_TABS_MANUAL_LAYOUT_EDITING
  * @param command
  *     Command that will be applied to the selected annotations.
  *     Annotation manager will take ownership of the command and
@@ -165,8 +166,7 @@ AnnotationManager::applyCommand(const UserInputModeEnum::Enum userInputMode,
  *     Output with error information if command fails.
  */
 bool
-AnnotationManager::applyCommandInWindow(const UserInputModeEnum::Enum userInputMode,
-                                        AnnotationRedoUndoCommand* command,
+AnnotationManager::applyCommandInWindow(AnnotationRedoUndoCommand* command,
                                         const int32_t windowIndex,
                                         AString& errorMessageOut)
 {
@@ -186,9 +186,9 @@ AnnotationManager::applyCommandInWindow(const UserInputModeEnum::Enum userInputM
     /*
      * "Redo" the command and add it to the undo stack
      */
-    const bool result = getCommandRedoUndoStack(userInputMode)->pushAndRedo(command,
-                                                                            windowIndex,
-                                                                            errorMessageOut);
+    const bool result = getCommandRedoUndoStack()->pushAndRedo(command,
+                                                               windowIndex,
+                                                               errorMessageOut);
     return result;
 }
 
@@ -201,51 +201,83 @@ AnnotationManager::applyCommandInWindow(const UserInputModeEnum::Enum userInputM
 void
 AnnotationManager::deselectAllAnnotationsForEditing(const int32_t windowIndex)
 {
-    std::vector<AnnotationFile*> annotationFiles;
-    m_brain->getAllAnnotationFilesIncludingSceneAnnotationFile(annotationFiles);
-    
-    for (std::vector<AnnotationFile*>::iterator fileIter = annotationFiles.begin();
-         fileIter != annotationFiles.end();
-         fileIter++) {
-        AnnotationFile* file = *fileIter;
-        CaretAssert(file);
-        
-        file->setAllAnnotationsSelectedForEditing(windowIndex,
-                                        false);
-    }
+    switch (m_userInputMode) {
+        case UserInputModeEnum::Enum::INVALID:
+            break;
+        case UserInputModeEnum::Enum::ANNOTATIONS:
+        {
+            std::vector<AnnotationFile*> annotationFiles;
+            m_brain->getAllAnnotationFilesIncludingSceneAnnotationFile(annotationFiles);
+            
+            for (std::vector<AnnotationFile*>::iterator fileIter = annotationFiles.begin();
+                 fileIter != annotationFiles.end();
+                 fileIter++) {
+                AnnotationFile* file = *fileIter;
+                CaretAssert(file);
+                
+                file->setAllAnnotationsSelectedForEditing(windowIndex,
+                                                          false);
+            }
 
-    EventAnnotationBarsGet barsEvent;
-    EventManager::get()->sendEvent(barsEvent.getPointer());
-    std::vector<AnnotationColorBar*> colorBars = barsEvent.getAnnotationColorBars();
-
-    for (std::vector<AnnotationColorBar*>::iterator iter = colorBars.begin();
-         iter != colorBars.end();
-         iter++) {
-        AnnotationColorBar* cb = *iter;
-        cb->setSelectedForEditing(windowIndex,
-                                  false);
-    }
-    
-    std::vector<AnnotationScaleBar*> scaleBars = barsEvent.getAnnotationScaleBars();
-    for (auto sb : scaleBars) {
-        sb->setSelectedForEditing(windowIndex,
-                                  false);
-    }
-    
-    EventAnnotationChartLabelGet chartLabelEvent;
-    EventManager::get()->sendEvent(chartLabelEvent.getPointer());
-    std::vector<Annotation*> chartLabels = chartLabelEvent.getAnnotationChartLabels();
-    for (auto label : chartLabels) {
-        label->setSelectedForEditing(windowIndex,
-                                     false);
-    }
-    
-    EventBrowserTabGetAll allTabsEvent;
-    EventManager::get()->sendEvent(allTabsEvent.getPointer());
-    std::vector<BrowserTabContent*> allTabs = allTabsEvent.getAllBrowserTabs();
-    for (auto tab : allTabs) {
-        tab->getManualLayoutBrowserTabAnnotation()->setSelectedForEditing(windowIndex,
-                                                                          false);
+            EventAnnotationBarsGet barsEvent;
+            EventManager::get()->sendEvent(barsEvent.getPointer());
+            std::vector<AnnotationColorBar*> colorBars = barsEvent.getAnnotationColorBars();
+            
+            for (std::vector<AnnotationColorBar*>::iterator iter = colorBars.begin();
+                 iter != colorBars.end();
+                 iter++) {
+                AnnotationColorBar* cb = *iter;
+                cb->setSelectedForEditing(windowIndex,
+                                          false);
+            }
+            
+            std::vector<AnnotationScaleBar*> scaleBars = barsEvent.getAnnotationScaleBars();
+            for (auto sb : scaleBars) {
+                sb->setSelectedForEditing(windowIndex,
+                                          false);
+            }
+            
+            EventAnnotationChartLabelGet chartLabelEvent;
+            EventManager::get()->sendEvent(chartLabelEvent.getPointer());
+            std::vector<Annotation*> chartLabels = chartLabelEvent.getAnnotationChartLabels();
+            for (auto label : chartLabels) {
+                label->setSelectedForEditing(windowIndex,
+                                             false);
+            }
+        }
+            break;
+        case UserInputModeEnum::Enum::BORDERS:
+            break;
+        case UserInputModeEnum::Enum::FOCI:
+            break;
+        case UserInputModeEnum::Enum::IMAGE:
+            break;
+        case UserInputModeEnum::Enum::SAMPLES_EDITING:
+        {
+            std::vector<SamplesFile*> samplesFiles(m_brain->getAllSamplesFiles());
+            for (auto& sf : samplesFiles) {
+                sf->setAllAnnotationsSelectedForEditing(windowIndex,
+                                                        false);
+            }
+//            Annotation::setSelectionLockedPolyhedronInWindow(windowIndex,
+//                                                             NULL);
+        }
+            break;
+        case UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING:
+        {
+            EventBrowserTabGetAll allTabsEvent;
+            EventManager::get()->sendEvent(allTabsEvent.getPointer());
+            std::vector<BrowserTabContent*> allTabs = allTabsEvent.getAllBrowserTabs();
+            for (auto tab : allTabs) {
+                tab->getManualLayoutBrowserTabAnnotation()->setSelectedForEditing(windowIndex,
+                                                                                  false);
+            }
+        }
+            break;
+        case UserInputModeEnum::Enum::VIEW:
+            break;
+        case UserInputModeEnum::Enum::VOLUME_EDIT:
+            break;
     }
 }
 
@@ -312,8 +344,28 @@ void
 AnnotationManager::setAnnotationsForEditing(const int32_t windowIndex,
                                             const std::vector<Annotation*>& selectedAnnotations)
 {
+    /*
+     * If only one annotation for selection
+     */
+    bool oneDeselectFlag(false);
+    if (selectedAnnotations.size() == 1) {
+        CaretAssertVectorIndex(selectedAnnotations, 0);
+        if (selectedAnnotations[0]->isSelectedForEditing(windowIndex)) {
+            /*
+             * Annotation is selected so we want to turn off its
+             * selection status which was done by call
+             * to deselectAllAnnotationsForEditing().
+             */
+            oneDeselectFlag = true;
+        }
+    }
+    
     deselectAllAnnotationsForEditing(windowIndex);
     
+    if (oneDeselectFlag) {
+        return;
+    }
+    
     std::set<Annotation*> uniqueAnnotationsSet;
     for (std::vector<Annotation*>::const_iterator annIter = selectedAnnotations.begin();
          annIter != selectedAnnotations.end();
@@ -454,8 +506,34 @@ std::vector<Annotation*>
 AnnotationManager::getAllAnnotations() const
 {
     std::vector<AnnotationFile*> annotationFiles;
-    m_brain->getAllAnnotationFilesIncludingSceneAnnotationFile(annotationFiles);
     
+    switch (m_userInputMode) {
+        case UserInputModeEnum::Enum::ANNOTATIONS:
+            m_brain->getAllAnnotationFilesIncludingSceneAnnotationFile(annotationFiles);
+            break;
+        case UserInputModeEnum::Enum::SAMPLES_EDITING:
+        {
+            std::vector<SamplesFile*> samplesFiles(m_brain->getAllSamplesFiles());
+            annotationFiles.insert(annotationFiles.end(),
+                                   samplesFiles.begin(),
+                                   samplesFiles.end());
+        }
+            break;
+        case UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING:
+            /*
+             * Tabs are not in files so nothing to do
+             */
+            break;
+        case UserInputModeEnum::Enum::BORDERS:
+        case UserInputModeEnum::Enum::FOCI:
+        case UserInputModeEnum::Enum::IMAGE:
+        case UserInputModeEnum::Enum::INVALID:
+        case UserInputModeEnum::Enum::VIEW:
+        case UserInputModeEnum::Enum::VOLUME_EDIT:
+            CaretAssert(0);
+            break;
+    }
+
     std::vector<Annotation*> allAnnotations;
     
     for (std::vector<AnnotationFile*>::iterator fileIter = annotationFiles.begin();
@@ -472,35 +550,60 @@ AnnotationManager::getAllAnnotations() const
                                   annotations.end());
         }
     }
-
-    EventAnnotationBarsGet barsEvent;
-    EventManager::get()->sendEvent(barsEvent.getPointer());
-    std::vector<AnnotationColorBar*> colorBars = barsEvent.getAnnotationColorBars();
-    for (std::vector<AnnotationColorBar*>::iterator iter = colorBars.begin();
-         iter != colorBars.end();
-         iter++) {
-        allAnnotations.push_back(*iter);
-    }
     
-    std::vector<AnnotationScaleBar*> scaleBars = barsEvent.getAnnotationScaleBars();
-    for (auto sb : scaleBars) {
-        allAnnotations.push_back(sb);
+    switch (m_userInputMode) {
+        case UserInputModeEnum::Enum::ANNOTATIONS:
+        {
+            /*
+             * Put color bars with annotations
+             */
+            EventAnnotationBarsGet barsEvent;
+            EventManager::get()->sendEvent(barsEvent.getPointer());
+            std::vector<AnnotationColorBar*> colorBars = barsEvent.getAnnotationColorBars();
+            for (std::vector<AnnotationColorBar*>::iterator iter = colorBars.begin();
+                 iter != colorBars.end();
+                 iter++) {
+                allAnnotations.push_back(*iter);
+            }
+            
+            /*
+             * Put scale bars with annotations
+             */
+            std::vector<AnnotationScaleBar*> scaleBars = barsEvent.getAnnotationScaleBars();
+            for (auto sb : scaleBars) {
+                allAnnotations.push_back(sb);
+            }
+            
+            EventAnnotationChartLabelGet chartLabelEvent;
+            EventManager::get()->sendEvent(chartLabelEvent.getPointer());
+            std::vector<Annotation*> chartLabels = chartLabelEvent.getAnnotationChartLabels();
+            allAnnotations.insert(allAnnotations.end(),
+                                  chartLabels.begin(),
+                                  chartLabels.end());
+        }
+            break;
+        case UserInputModeEnum::Enum::SAMPLES_EDITING:
+            break;
+        case UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING:
+        {
+            EventBrowserTabGetAll allTabsEvent;
+            EventManager::get()->sendEvent(allTabsEvent.getPointer());
+            std::vector<BrowserTabContent*> allTabs = allTabsEvent.getAllBrowserTabs();
+            for (auto tab : allTabs) {
+                allAnnotations.push_back(tab->getManualLayoutBrowserTabAnnotation());
+            }
+        }
+            break;
+        case UserInputModeEnum::Enum::BORDERS:
+        case UserInputModeEnum::Enum::FOCI:
+        case UserInputModeEnum::Enum::IMAGE:
+        case UserInputModeEnum::Enum::INVALID:
+        case UserInputModeEnum::Enum::VIEW:
+        case UserInputModeEnum::Enum::VOLUME_EDIT:
+            CaretAssert(0);
+            break;
     }
 
-    EventAnnotationChartLabelGet chartLabelEvent;
-    EventManager::get()->sendEvent(chartLabelEvent.getPointer());
-    std::vector<Annotation*> chartLabels = chartLabelEvent.getAnnotationChartLabels();
-    allAnnotations.insert(allAnnotations.end(),
-                          chartLabels.begin(),
-                          chartLabels.end());
-    
-    EventBrowserTabGetAll allTabsEvent;
-    EventManager::get()->sendEvent(allTabsEvent.getPointer());
-    std::vector<BrowserTabContent*> allTabs = allTabsEvent.getAllBrowserTabs();
-    for (auto tab : allTabs) {
-        allAnnotations.push_back(tab->getManualLayoutBrowserTabAnnotation());
-    }
-    
     return allAnnotations;
 }
 
@@ -549,9 +652,7 @@ AnnotationManager::getAnnotationEditingSelectionInformation(const int32_t window
 {
     CaretAssertArrayIndex(m_selectionInformation, BrainConstants::MAXIMUM_NUMBER_OF_BROWSER_WINDOWS, windowIndex);
     
-    EventUserInputModeGet modeEvent(windowIndex);
-    EventManager::get()->sendEvent(modeEvent.getPointer());
-    const bool tileModeFlag = (modeEvent.getUserInputMode() == UserInputModeEnum::Enum::TILE_TABS_MANUAL_LAYOUT_EDITING);
+    const bool tileModeFlag = (m_userInputMode == UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING);
 
     AnnotationEditingSelectionInformation* asi = m_selectionInformation[windowIndex];
     
@@ -639,34 +740,50 @@ AnnotationManager::getAnnotationsSelectedForEditingInSpaces(const int32_t window
  */
 void
 AnnotationManager::getAnnotationsAndFilesSelectedForEditing(const int32_t windowIndex,
-                                          std::vector<std::pair<Annotation*, AnnotationFile*> >& annotationsAndFileOut) const
+                                                            std::vector<AnnotationAndFile>& annotationsAndFileOut) const
 {
     annotationsAndFileOut.clear();
 
-    EventUserInputModeGet modeEvent(windowIndex);
-    EventManager::get()->sendEvent(modeEvent.getPointer());
-    if (modeEvent.getUserInputMode() == UserInputModeEnum::Enum::TILE_TABS_MANUAL_LAYOUT_EDITING) {
-        /* In Tile Editing mode and browser tabs are not in files */
-        return;
-    }
-    
     std::vector<AnnotationFile*> annotationFiles;
-    m_brain->getAllAnnotationFilesIncludingSceneAnnotationFile(annotationFiles);
+    switch (m_userInputMode) {
+        case UserInputModeEnum::Enum::ANNOTATIONS:
+            m_brain->getAllAnnotationFilesIncludingSceneAnnotationFile(annotationFiles);
+            break;
+        case UserInputModeEnum::Enum::SAMPLES_EDITING:
+        {
+            std::vector<SamplesFile*> samplesFiles(m_brain->getAllSamplesFiles());
+            annotationFiles.insert(annotationFiles.end(),
+                                   samplesFiles.begin(),
+                                   samplesFiles.end());
+        }
+            break;
+        case UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING:
+            /*
+             * Tabs are not in files so nothing to do
+             */
+            break;
+        case UserInputModeEnum::Enum::BORDERS:
+        case UserInputModeEnum::Enum::FOCI:
+        case UserInputModeEnum::Enum::IMAGE:
+        case UserInputModeEnum::Enum::INVALID:
+        case UserInputModeEnum::Enum::VIEW:
+        case UserInputModeEnum::Enum::VOLUME_EDIT:
+            CaretAssert(0);
+            break;
+    }
+
     
-    for (std::vector<AnnotationFile*>::iterator fileIter = annotationFiles.begin();
-         fileIter != annotationFiles.end();
-         fileIter++) {
-        AnnotationFile* file = *fileIter;
-        CaretAssert(file);
+    for (auto& af : annotationFiles) {
+        CaretAssert(af);
         
         std::vector<Annotation*> annotations;
-        file->getAllAnnotations(annotations);
+        af->getAllAnnotations(annotations);
         for (std::vector<Annotation*>::iterator annIter = annotations.begin();
              annIter != annotations.end();
              annIter++) {
             Annotation* ann = *annIter;
             if (ann->isSelectedForEditing(windowIndex)) {
-                annotationsAndFileOut.push_back(std::make_pair(ann, file));
+                annotationsAndFileOut.emplace_back(ann, af, ann->getAnnotationGroupKey());
             }
         }
     }
@@ -683,13 +800,11 @@ AnnotationManager::getAnnotationsAndFilesSelectedForEditing(const int32_t window
  */
 void
 AnnotationManager::getAnnotationsAndFilesSelectedForEditingIncludingLabels(const int32_t windowIndex,
-                                                     std::vector<std::pair<Annotation*, AnnotationFile*> >& annotationsAndFileOut) const
+                                                                           std::vector<AnnotationAndFile>& annotationsAndFileOut) const
 {
     annotationsAndFileOut.clear();
     
-    EventUserInputModeGet modeEvent(windowIndex);
-    EventManager::get()->sendEvent(modeEvent.getPointer());
-    if (modeEvent.getUserInputMode() == UserInputModeEnum::Enum::TILE_TABS_MANUAL_LAYOUT_EDITING) {
+    if (m_userInputMode == UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING) {
         /* In Tile Editing mode and browser tabs are not in files */
         return;
     }
@@ -703,7 +818,7 @@ AnnotationManager::getAnnotationsAndFilesSelectedForEditingIncludingLabels(const
     AnnotationFile* nullFile = NULL;
     for (auto cl : chartLabels) {
         if (cl->isSelectedForEditing(windowIndex)) {
-            annotationsAndFileOut.push_back(std::make_pair(cl, nullFile));
+            annotationsAndFileOut.emplace_back(cl, nullFile, cl->getAnnotationGroupKey());
         }
     }
 }
@@ -711,8 +826,6 @@ AnnotationManager::getAnnotationsAndFilesSelectedForEditingIncludingLabels(const
 /**
  * Align annotations.
  * 
- * @param userInputMode
- *     The current user input mode which MUST be ANNOTATIONS or TILE_TABS_MANUAL_LAYOUT_EDITING
  * @param arrangerInputs
  *    Inputs to algorithm that aligns the annotations.
  * @param errorMessageOut
@@ -721,12 +834,11 @@ AnnotationManager::getAnnotationsAndFilesSelectedForEditingIncludingLabels(const
  *    True if successful, false if error.
  */
 bool
-AnnotationManager::alignAnnotations(const UserInputModeEnum::Enum userInputMode,
-                                    const AnnotationArrangerInputs& arrangerInputs,
+AnnotationManager::alignAnnotations(const AnnotationArrangerInputs& arrangerInputs,
                                     const AnnotationAlignmentEnum::Enum alignment,
                                     AString& errorMessageOut)
 {
-    AnnotationArrangerExecutor arranger(userInputMode);
+    AnnotationArrangerExecutor arranger(m_userInputMode);
     
     return arranger.alignAnnotations(this,
                                      arrangerInputs,
@@ -737,8 +849,6 @@ AnnotationManager::alignAnnotations(const UserInputModeEnum::Enum userInputMode,
 /**
  * Align annotations.
  *
- * @param userInputMode
- *     The current user input mode which MUST be ANNOTATIONS or TILE_TABS_MANUAL_LAYOUT_EDITING
  * @param arrangerInputs
  *    Inputs to algorithm that aligns the annotations.
  * @param errorMessageOut
@@ -747,12 +857,11 @@ AnnotationManager::alignAnnotations(const UserInputModeEnum::Enum userInputMode,
  *    True if successful, false if error.
  */
 bool
-AnnotationManager::distributeAnnotations(const UserInputModeEnum::Enum userInputMode,
-                                         const AnnotationArrangerInputs& arrangerInputs,
+AnnotationManager::distributeAnnotations(const AnnotationArrangerInputs& arrangerInputs,
                                          const AnnotationDistributeEnum::Enum distribute,
                                          AString& errorMessageOut)
 {
-    AnnotationArrangerExecutor arranger(userInputMode);
+    AnnotationArrangerExecutor arranger(m_userInputMode);
     
     return arranger.distributeAnnotations(this,
                                      arrangerInputs,
@@ -763,8 +872,6 @@ AnnotationManager::distributeAnnotations(const UserInputModeEnum::Enum userInput
 /**
  * Apply given grouping mode valid in the given window.
  *
- * @param userInputMode
- *     The current user input mode which MUST be ANNOTATIONS or TILE_TABS_MANUAL_LAYOUT_EDITING
  * @param windowIndex
  *     Index of the window.
  * @param groupingMode
@@ -775,8 +882,7 @@ AnnotationManager::distributeAnnotations(const UserInputModeEnum::Enum userInput
  *     True if successful, else false.
  */
 bool
-AnnotationManager::applyGroupingMode(const UserInputModeEnum::Enum userInputMode,
-                                     const int32_t windowIndex,
+AnnotationManager::applyGroupingMode(const int32_t windowIndex,
                                      const AnnotationGroupingModeEnum::Enum groupingMode,
                                      AString& errorMessageOut)
 {
@@ -815,8 +921,7 @@ AnnotationManager::applyGroupingMode(const UserInputModeEnum::Enum userInputMode
             AnnotationRedoUndoCommand* command = new AnnotationRedoUndoCommand();
             command->setModeGroupingGroupAnnotations(annotationGroupKey,
                                                      annotations);
-            validFlag = applyCommandInWindow(userInputMode,
-                                             command,
+            validFlag = applyCommandInWindow(command,
                                              windowIndex,
                                              errorMessageOut);
         }
@@ -836,8 +941,7 @@ AnnotationManager::applyGroupingMode(const UserInputModeEnum::Enum userInputMode
             AnnotationRedoUndoCommand* command = new AnnotationRedoUndoCommand();
             command->setModeGroupingRegroupAnnotations(annotationGroupKey);
             
-            validFlag = applyCommandInWindow(userInputMode,
-                                             command,
+            validFlag = applyCommandInWindow(command,
                                              windowIndex,
                                              errorMessageOut);
         }
@@ -858,8 +962,7 @@ AnnotationManager::applyGroupingMode(const UserInputModeEnum::Enum userInputMode
             AnnotationRedoUndoCommand* command = new AnnotationRedoUndoCommand();
             command->setModeGroupingUngroupAnnotations(annotationGroupKey);
             
-            validFlag = applyCommandInWindow(userInputMode,
-                                             command,
+            validFlag = applyCommandInWindow(command,
                                              windowIndex,
                                              errorMessageOut);
         }
@@ -932,8 +1035,7 @@ AnnotationManager::applyStackingOrder(const std::vector<Annotation*>& annotation
                                              stackOrders,
                                              orderType);
 
-    const float resultFlag = applyCommandInWindow(UserInputModeEnum::Enum::ANNOTATIONS,
-                                                  command,
+    const float resultFlag = applyCommandInWindow(command,
                                                   windowIndex,
                                                   errorMessageOut);
     return resultFlag;
@@ -963,7 +1065,23 @@ AnnotationManager::getAnnotationsInSameSpace(const Annotation* annotation)
     }
     else {
         switch (annotation->getCoordinateSpace()) {
+            case AnnotationCoordinateSpaceEnum::MEDIA_FILE_NAME_AND_PIXEL:
+            {
+                const AString mediaFileName = annotation->getCoordinate(0)->getMediaFileName();
+                for (auto a : allAnns) {
+                    if (a == annotation) {
+                        continue;
+                    }
+                    if (a->getCoordinateSpace() == AnnotationCoordinateSpaceEnum::MEDIA_FILE_NAME_AND_PIXEL) {
+                        if (a->getCoordinate(0)->getMediaFileName() == mediaFileName) {
+                            sameSpaceAnns.push_back(a);
+                        }
+                    }
+                }
+            }
+                break;
             case AnnotationCoordinateSpaceEnum::CHART:
+            case AnnotationCoordinateSpaceEnum::HISTOLOGY:
             case AnnotationCoordinateSpaceEnum::SPACER:
             case AnnotationCoordinateSpaceEnum::STEREOTAXIC:
             case AnnotationCoordinateSpaceEnum::SURFACE:
@@ -1129,111 +1247,21 @@ AnnotationManager::toString() const
 }
 
 /**
- * @return True if there is an annotation on the clipboard.
+ * @return The annotation clipboard
  */
-bool
-AnnotationManager::isAnnotationOnClipboardValid() const
+AnnotationClipboard*
+AnnotationManager::getClipboard()
 {
-    return (m_clipboardAnnotation != NULL);
+    return m_clipboard.get();
 }
 
 /**
- * @return Pointer to annotation file on clipboard.
- *     If there is not annotation file on the clipboard,
- *     NULL is returned.
+ * @return The annotation clipboard
  */
-AnnotationFile*
-AnnotationManager::getAnnotationFileOnClipboard() const
+const AnnotationClipboard*
+AnnotationManager::getClipboard() const
 {
-    if (m_clipboardAnnotationFile != NULL) {
-        /*
-         * It is possible that the file has been destroyed.
-         * If so, invalidate the file (set it to NULL).
-         */
-        std::vector<AnnotationFile*> allAnnotationFiles;
-        m_brain->getAllAnnotationFilesIncludingSceneAnnotationFile(allAnnotationFiles);
-        
-        if (std::find(allAnnotationFiles.begin(),
-                      allAnnotationFiles.end(),
-                      m_clipboardAnnotationFile) == allAnnotationFiles.end()) {
-            m_clipboardAnnotationFile = NULL;
-        }
-    }
-    
-    return m_clipboardAnnotationFile;
-}
-
-/**
- * @return Pointer to annotation on clipboard.
- *     If there is not annotation on the clipboard,
- *     NULL is returned.
- */
-const Annotation*
-AnnotationManager::getAnnotationOnClipboard() const
-{
-    return m_clipboardAnnotation;
-}
-
-/**
- * @return A copy of the annotation on the clipboard.
- *     If there is not annotation on the clipboard,
- *     NULL is returned.
- */
-Annotation*
-AnnotationManager::getCopyOfAnnotationOnClipboard() const
-{
-    if (m_clipboardAnnotation != NULL) {
-        return m_clipboardAnnotation->clone();
-    }
-    
-    return NULL;
-}
-
-void
-AnnotationManager::copyAnnotationToClipboard(const AnnotationFile* annotationFile,
-                                             const Annotation* annotation)
-{
-    m_clipboardAnnotationFile = const_cast<AnnotationFile*>(annotationFile);
-    m_clipboardAnnotation.grabNew(annotation->clone());
-}
-
-/**
- * Get the annotation being drawn in window with the given window index.
- *
- * @param windowIndex
- *     Index of window.
- * @return
- *     Pointer to the annotation (will be NULL if no annotation is being drawn).
- */
-const Annotation*
-AnnotationManager::getAnnotationBeingDrawnInWindow(const int32_t windowIndex) const
-{
-    CaretAssertArrayIndex(m_annotationBeingDrawnInWindow, BrainConstants::MAXIMUM_NUMBER_OF_BROWSER_WINDOWS, windowIndex);
-    return m_annotationBeingDrawnInWindow[windowIndex];
-}
-
-/**
- * Set the annotation being drawn in window with the given window index.
- *
- * @param windowIndex
- *     Index of window.
- * @param annotation
- *     Pointer to the annotation (will be NULL if no annotation is being drawn).
- */
-void
-AnnotationManager::setAnnotationBeingDrawnInWindow(const int32_t windowIndex,
-                                                   const Annotation* annotation)
-{
-    CaretAssertArrayIndex(m_annotationBeingDrawnInWindow, BrainConstants::MAXIMUM_NUMBER_OF_BROWSER_WINDOWS, windowIndex);
-   
-    if (m_annotationBeingDrawnInWindow[windowIndex] != NULL) {
-        delete m_annotationBeingDrawnInWindow[windowIndex];
-        m_annotationBeingDrawnInWindow[windowIndex] = NULL;
-    }
-    
-    if (annotation != NULL) {
-        m_annotationBeingDrawnInWindow[windowIndex] = annotation->clone();
-    }
+    return m_clipboard.get();
 }
 
 /**
@@ -1253,8 +1281,33 @@ AnnotationManager::getDisplayedAnnotationFiles(EventGetDisplayedDataFiles* displ
     const std::vector<int32_t> tabIndices = displayedFilesEvent->getTabIndices();
     
     std::vector<AnnotationFile*> annotationFiles;
-    m_brain->getAllAnnotationFilesIncludingSceneAnnotationFile(annotationFiles);
-    
+    switch (m_userInputMode) {
+        case UserInputModeEnum::Enum::ANNOTATIONS:
+            m_brain->getAllAnnotationFilesIncludingSceneAnnotationFile(annotationFiles);
+            break;
+        case UserInputModeEnum::Enum::SAMPLES_EDITING:
+        {
+            std::vector<SamplesFile*> samplesFiles(m_brain->getAllSamplesFiles());
+            annotationFiles.insert(annotationFiles.end(),
+                                   samplesFiles.begin(),
+                                   samplesFiles.end());
+        }
+            break;
+        case UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING:
+            /*
+             * Tabs are not in files so nothing to do
+             */
+            break;
+        case UserInputModeEnum::Enum::BORDERS:
+        case UserInputModeEnum::Enum::FOCI:
+        case UserInputModeEnum::Enum::IMAGE:
+        case UserInputModeEnum::Enum::INVALID:
+        case UserInputModeEnum::Enum::VIEW:
+        case UserInputModeEnum::Enum::VOLUME_EDIT:
+            CaretAssert(0);
+            break;
+    }
+
     const int32_t numAnnFiles = static_cast<int32_t>(annotationFiles.size());
     for (int32_t iFile = 0; iFile < numAnnFiles; iFile++) {
         CaretAssertVectorIndex(annotationFiles, iFile);
@@ -1273,6 +1326,12 @@ AnnotationManager::getDisplayedAnnotationFiles(EventGetDisplayedDataFiles* displ
                 case AnnotationCoordinateSpaceEnum::CHART:
                     displayedFlag = true;
                     break;
+                case AnnotationCoordinateSpaceEnum::HISTOLOGY:
+                    displayedFlag = true;
+                    break;
+                case AnnotationCoordinateSpaceEnum::MEDIA_FILE_NAME_AND_PIXEL:
+                    displayedFlag = true;
+                    break;
                 case AnnotationCoordinateSpaceEnum::SPACER:
                     displayedFlag = true;
                     break;
@@ -1302,19 +1361,19 @@ AnnotationManager::getDisplayedAnnotationFiles(EventGetDisplayedDataFiles* displ
 
 /**
  * @return Pointer to the command redo undo stack
- *
- * @param userInputMode
- *     The current user input mode which MUST be ANNOTATIONS or TILE_TABS_MANUAL_LAYOUT_EDITING
  */
 CaretUndoStack*
-AnnotationManager::getCommandRedoUndoStack(const UserInputModeEnum::Enum userInputMode)
+AnnotationManager::getCommandRedoUndoStack()
 {
-    CaretUndoStack* undoStackOut(NULL);
-    switch (userInputMode) {
+    CaretUndoStack* undoStackOut(m_annotationsExceptBrowserTabsRedoUndoStack);
+    switch (m_userInputMode) {
         case UserInputModeEnum::Enum::ANNOTATIONS:
             undoStackOut = m_annotationsExceptBrowserTabsRedoUndoStack;
             break;
-        case UserInputModeEnum::Enum::TILE_TABS_MANUAL_LAYOUT_EDITING:
+        case UserInputModeEnum::Enum::SAMPLES_EDITING:
+            undoStackOut = m_samplesAnnotationsRedoUndoStack;
+            break;
+        case UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING:
             undoStackOut = m_browserTabAnnotationsRedoUndoStack;
             break;
         case UserInputModeEnum::Enum::BORDERS:
@@ -1393,8 +1452,6 @@ AnnotationManager::restoreFromScene(const SceneAttributes* sceneAttributes,
  *     Tabs displayed in the window (may or may not include selected tab)
  * @param windowIndex
  *     Index of window
- * @param userInputMode
- *     The current user input mode (browser tab always)
  * @param errorMessageOut
  *     Contains error information if expansion has error (inability to expand is NOT an error)
  * @return
@@ -1403,9 +1460,15 @@ AnnotationManager::restoreFromScene(const SceneAttributes* sceneAttributes,
 bool
 AnnotationManager::shrinkAndExpandSelectedBrowserTabAnnotation(const std::vector<BrowserTabContent*>& tabsInWindow,
                                                                const int32_t windowIndex,
-                                                               const UserInputModeEnum::Enum userInputMode,
                                                                AString& errorMessageOut)
 {
+    if (m_userInputMode != UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING) {
+        const AString txt("This method should only be called for TILE TABS LAYOUT EDITING");
+        CaretLogSevere(txt);
+        CaretAssertMessage(0, txt);
+        return false;
+    }
+
     errorMessageOut.clear();
     
     AnnotationBrowserTab* selectedTabAnnotation(NULL);
@@ -1437,8 +1500,7 @@ AnnotationManager::shrinkAndExpandSelectedBrowserTabAnnotation(const std::vector
                                       newBounds[2],
                                       newBounds[3],
                                       selectedTabAnnotation);
-            if (applyCommand(userInputMode,
-                             undoCommand,
+            if (applyCommand(undoCommand,
                              errorMessageOut)) {
                 return true;
             }
