@@ -35,6 +35,7 @@
 #include "FileInformation.h"
 #include "SceneableInterface.h"
 #include "StructureEnum.h"
+#include "UserInputModeEnum.h"
 #include "VolumeFile.h"
 
 namespace caret {
@@ -63,6 +64,7 @@ namespace caret {
     class CiftiConnectivityMatrixDenseParcelFile;
     class CiftiConnectivityMatrixParcelFile;
     class CiftiConnectivityMatrixParcelDenseFile;
+    class CiftiConnectivityMatrixParcelDynamicFile;
     class CiftiFiberOrientationFile;
     class CiftiFiberTrajectoryFile;
     class CiftiMappableDataFile;
@@ -71,21 +73,25 @@ namespace caret {
     class CiftiParcelSeriesFile;
     class CiftiParcelScalarFile;
     class CiftiScalarDataSeriesFile;
+    class CziImageFile;
     class DisplayProperties;
     class DisplayPropertiesAnnotation;
     class DisplayPropertiesAnnotationTextSubstitution;
     class DisplayPropertiesBorders;
+    class DisplayPropertiesCziImages;
     class DisplayPropertiesFiberOrientation;
     class DisplayPropertiesFoci;
     class DisplayPropertiesImages;
     class DisplayPropertiesLabels;
     class DisplayPropertiesSurface;
+    class DisplayPropertiesSamples;
     class DisplayPropertiesVolume;
     class EventDataFileRead;
     class EventDataFileReload;
     class EventDataFileReloadAll;
     class EventSpecFileReadDataFiles;
     class GapsAndMargins;
+    class HistologySlicesFile;
     class IdentificationManager;
     class ImageFile;
     class LabelFile;
@@ -93,6 +99,7 @@ namespace caret {
     class MetricDynamicConnectivityFile;
     class ModelChart;
     class ModelChartTwo;
+    class ModelHistology;
     class ModelMedia;
     class ModelSurfaceMontage;
     class ModelVolume;
@@ -101,6 +108,8 @@ namespace caret {
     class PaletteGroupStandardPalettes;
     class PaletteGroupUserCustomPalettes;
     class RgbaFile;
+    class SamplesFile;
+    class SamplesMetaDataManager;
     class SceneClassAssistant;
     class Scene;
     class SceneFile;
@@ -151,6 +160,22 @@ namespace caret {
         
         void getAnnotationTextSubstitutionFiles(std::vector<AnnotationTextSubstitutionFile*>& annSubFilesOut) const;
         
+        const std::vector<CziImageFile*> getAllCziImageFiles() const;
+        
+        int32_t getNumberOfCziImageFiles() const;
+        
+        CziImageFile* getCziImageFile(const int32_t indx);
+        
+        const CziImageFile* getCziImageFile(const int32_t indx) const;
+        
+        const std::vector<HistologySlicesFile*> getAllHistologySlicesFiles() const;
+        
+        int32_t getNumberOfHistologySlicesFiles() const;
+        
+        HistologySlicesFile* getHistologySlicesFile(const int32_t indx);
+        
+        const HistologySlicesFile* getHistologySlicesFile(const int32_t indx) const;
+
         int32_t getNumberOfFociFiles() const;
         
         FociFile* getFociFile(const int32_t indx);
@@ -169,8 +194,18 @@ namespace caret {
         
         const PaletteFile* getPaletteFile() const;
 
+        int32_t getNumberOfSamplesFiles() const;
+        
+        const SamplesFile* getSamplesFile(const int32_t indx) const;
+        
+        SamplesFile* getSamplesFile(const int32_t indx);
+        
+        std::vector<SamplesFile*> getAllSamplesFiles() const;
+        
         int32_t getNumberOfSceneFiles() const;
         
+        SceneFile* getSceneFileWithName(const AString& sceneFileName) const;
+        
         SceneFile* getSceneFile(const int32_t indx);
         
         const SceneFile* getSceneFile(const int32_t indx) const;
@@ -207,9 +242,9 @@ namespace caret {
         
         void receiveEvent(Event* event);
         
-        AnnotationManager* getAnnotationManager();
+        AnnotationManager* getAnnotationManager(const UserInputModeEnum::Enum userInputMode);
         
-        const AnnotationManager* getAnnotationManager() const;
+        const AnnotationManager* getAnnotationManager(const UserInputModeEnum::Enum userInputMode) const;
         
         ModelChart* getChartModel();
         
@@ -223,6 +258,10 @@ namespace caret {
         
         const ChartingDataManager* getChartingDataManager() const;
         
+        ModelHistology* getHistologyModel();
+        
+        const ModelHistology* getHistologyModel() const;
+        
         ModelMedia* getMediaModel();
         
         const ModelMedia* getMediaModel() const;
@@ -295,6 +334,8 @@ namespace caret {
         
         void getConnectivityParcelSeriesFiles(std::vector<CiftiParcelSeriesFile*>& connectivityParcelSeriesFilesOut) const;
         
+        void getConnectivityParcelDenseDynamicFiles(std::vector<CiftiConnectivityMatrixParcelDynamicFile*>& parcelDynamicFilesOut) const;
+        
         int32_t getNumberOfConnectivityFiberOrientationFiles() const;
         
         CiftiFiberOrientationFile* getConnectivityFiberOrientationFile(int32_t indx);
@@ -401,6 +442,10 @@ namespace caret {
         
         const DisplayPropertiesBorders* getDisplayPropertiesBorders() const;
         
+        DisplayPropertiesCziImages* getDisplayPropertiesCziImages();
+        
+        const DisplayPropertiesCziImages* getDisplayPropertiesCziImages() const;
+        
         DisplayPropertiesFiberOrientation* getDisplayPropertiesFiberOrientation();
         
         const DisplayPropertiesFiberOrientation* getDisplayPropertiesFiberOrientation() const;
@@ -417,6 +462,10 @@ namespace caret {
         
         const DisplayPropertiesSurface* getDisplayPropertiesSurface() const;
         
+        DisplayPropertiesSamples* getDisplayPropertiesSamples();
+        
+        const DisplayPropertiesSamples* getDisplayPropertiesSamples() const;
+        
         DisplayPropertiesImages* getDisplayPropertiesImages();
         
         const DisplayPropertiesImages* getDisplayPropertiesImages() const;
@@ -465,8 +514,13 @@ namespace caret {
         
         std::unique_ptr<CaretResult> getBaseDirectoryForLoadedDataFiles(AString& baseDirectoryOut) const;
         
+        std::unique_ptr<CaretResult> getBaseDirectoryForLoadedSceneAndSpecFiles(const SceneFile* sceneFile,
+                                                                                AString& baseDirectoryOut) const;
+        
         const Scene* getActiveScene() const;
         
+        SamplesMetaDataManager* getSamplesMetaDataManager() const;
+        
     private:
         /**
          * Reset the brain scene file mode
@@ -614,7 +668,16 @@ namespace caret {
                          * and exit loop
                          */
                         newDataFile->setFileName(versionFullName);
-                        newDataFile->setModified();
+                        if (newDataFile->supportsWriting()) {
+                            newDataFile->setModified();
+                        }
+                        else {
+                            /*
+                             * Cannot write file, so don't let name update
+                             * report file as modified
+                             */
+                            newDataFile->clearModified();
+                        }
                         done = true;
                     }
                 }
@@ -722,6 +785,14 @@ namespace caret {
                                                                          CaretDataFile* caretDataFile,
                                                                          const AString& filename);
         
+        CziImageFile* addReadOrReloadCziImageFile(const FileModeAddReadReload fileMode,
+                                                  CaretDataFile* caretDataFile,
+                                                  const AString& filename);
+
+        HistologySlicesFile* addReadOrReloadHistologySlicesFile(const FileModeAddReadReload fileMode,
+                                                                CaretDataFile* caretDataFile,
+                                                                const AString& filename);
+        
         FociFile* addReadOrReloadFociFile(const FileModeAddReadReload fileMode,
                                CaretDataFile* caretDataFile,
                                const AString& filename);
@@ -734,6 +805,10 @@ namespace caret {
                                      CaretDataFile* caretDataFile,
                                      const AString& filename);
         
+        SamplesFile* addReadOrReloadSamplesFile(const FileModeAddReadReload fileMode,
+                                                CaretDataFile* caretDataFile,
+                                                const AString& filename);
+
         SceneFile* addReadOrReloadSceneFile(const FileModeAddReadReload fileMode,
                                  CaretDataFile* caretDataFile,
                                  const AString& filename);
@@ -742,6 +817,8 @@ namespace caret {
         
         void initializeDenseDataSeriesFile(CiftiBrainordinateDataSeriesFile* dataSeriesFile);
         
+        void initializeParcelSeriesFile(CiftiParcelSeriesFile* parcelSeriesFile);
+        
         void initializeVolumeFile(VolumeFile* volumeFile);
         
         void updateChartModel();
@@ -752,6 +829,8 @@ namespace caret {
         
         void updateSurfaceMontageModel();
         
+        void updateHistologyModel();
+        
         void updateMediaModel();
         
         void updateBrainStructures();
@@ -776,10 +855,16 @@ namespace caret {
         
         std::vector<BorderFile*> m_borderFiles;
         
+        std::vector<CziImageFile*> m_cziImageFiles;
+        
+        std::vector<HistologySlicesFile*> m_histologySlicesFiles;
+        
         std::vector<FociFile*> m_fociFiles;
         
         std::vector<ImageFile*> m_imageFiles;
         
+        std::vector<SamplesFile*> m_samplesFiles;
+        
         std::vector<SceneFile*> m_sceneFiles;
         
         PaletteFile* m_paletteFile;
@@ -826,14 +911,21 @@ namespace caret {
         
         ModelWholeBrain* m_wholeBrainModel;
         
+        ModelHistology* m_histologyModel;
+        
         ModelMedia* m_mediaModel = NULL;
         
         ModelSurfaceMontage* m_surfaceMontageModel;
         
         ChartingDataManager* m_chartingDataManager;
         
-        AnnotationManager* m_annotationManager;
+        std::unique_ptr<AnnotationManager> m_annotationsManager;
         
+        std::unique_ptr<AnnotationManager> m_samplesAnnotationsManager;
+        
+        std::unique_ptr<AnnotationManager> m_tileTabsAnnotationsManager;
+        
+
         std::unique_ptr<ChartTwoCartesianOrientedAxesYokingManager> m_chartTwoCartesianAxesYokingManager;
         
         /** contains all display properties */
@@ -851,6 +943,8 @@ namespace caret {
          */
         DisplayPropertiesSurface* m_displayPropertiesSurface;
 
+        DisplayPropertiesSamples* m_displayPropertiesSamples;
+        
         /**
          * Display properties for image - DO NOT delete since this
          * is also in the displayProperties std::vector.
@@ -881,6 +975,12 @@ namespace caret {
          */
         DisplayPropertiesBorders* m_displayPropertiesBorders;
         
+        /**
+         * Display properties for CZI images - DO NOT delete since this
+         * is also in the displayProperties std::vector.
+         */
+        DisplayPropertiesCziImages* m_displayPropertiesCziImages;
+        
         /**
          * Display properties for fiber orientation - DO NOT delete since this
          * is also in the displayProperties std::vector.
@@ -921,6 +1021,9 @@ namespace caret {
         std::shared_ptr<PaletteGroupStandardPalettes> m_palettesStandardGroup;
         
         std::shared_ptr<PaletteGroupUserCustomPalettes> m_palettesUserCustomGroup;
+        
+        mutable std::unique_ptr<SamplesMetaDataManager> m_samplesMetaDataManager;
+        
     };
 
 } // namespace
