@@ -94,16 +94,14 @@ m_overlayIndex(overlayIndex)
     m_selectedHistogramMapIndex = -1;
     m_allHistogramMapsSelectedFlag = false;
 
+    m_lineChartSettings.reset();
+    m_previousLineChartSettings.reset();
+    
     m_selectedLineLayerMapIndex = -1;
     m_lineLayerColor.setCaretColorEnum(generateDefaultColor());
     m_lineLayerLineWidth = ChartTwoDataCartesian::getDefaultLineWidth();
     m_selectedLineChartPointIndex = 0;
     m_lineChartActiveMode = ChartTwoOverlayActiveModeEnum::OFF;
-    m_lineChartNewMeanEnabled = false;
-    m_lineChartNewMeanValue = 0.0;
-    m_lineChartNewDeviationEnabled = false;
-    m_lineChartNormalizationAbsoluteValueEnabled = false;
-    m_lineChartNewDeviationValue = 1.0;
     
     m_selectedLineChartTextOffset = CardinalDirectionEnum::AUTO;
     
@@ -130,15 +128,23 @@ m_overlayIndex(overlayIndex)
     m_sceneAssistant->add<CardinalDirectionEnum, CardinalDirectionEnum::Enum>("m_selectedLineChartTextOffset",
                                                                               &m_selectedLineChartTextOffset);
     m_sceneAssistant->add("m_lineChartNewMeanEnabled",
-                          &m_lineChartNewMeanEnabled);
+                          &m_lineChartSettings.m_newMeanEnabled);
     m_sceneAssistant->add("m_lineChartNewMeanValue",
-                          &m_lineChartNewMeanValue);
+                          &m_lineChartSettings.m_newMeanValue);
     m_sceneAssistant->add("m_lineChartNewDeviationEnabled",
-                          &m_lineChartNewDeviationEnabled);
+                          &m_lineChartSettings.m_newDeviationEnabled);
     m_sceneAssistant->add("m_lineChartNormalizationAbsoluteValueEnabled",
-                          &m_lineChartNormalizationAbsoluteValueEnabled);
+                          &m_lineChartSettings.m_absoluteValueEnabled);
     m_sceneAssistant->add("m_lineChartNewDeviationValue",
-                          &m_lineChartNewDeviationValue);
+                          &m_lineChartSettings.m_newDeviationValue);
+    m_sceneAssistant->add("m_lineChartDataOffsetEnabled",
+                          &m_lineChartSettings.m_dataOffsetEnabled);
+    m_sceneAssistant->add("m_lineChartDataOffsetValue",
+                          &m_lineChartSettings.m_dataOffsetValue);
+    m_sceneAssistant->add("m_lineChartMultiplyDeviationEnabled",
+                          &m_lineChartSettings.m_multiplyDeviationEnabled);
+    m_sceneAssistant->add("m_lineChartMultiplyDeviationValue",
+                          &m_lineChartSettings.m_multiplyDeviationValue);
 
     EventManager::get()->addEventListener(this,
                                           EventTypeEnum::EVENT_CHART_TWO_OVERLAY_VALIDATE);
@@ -410,11 +416,9 @@ ChartTwoOverlay::copyData(const ChartTwoOverlay* overlay)
     m_selectedLineChartPointIndex = overlay->m_selectedLineChartPointIndex;
     m_lineChartActiveMode = overlay->m_lineChartActiveMode;
     m_selectedLineChartTextOffset = overlay->m_selectedLineChartTextOffset;
-    m_lineChartNewMeanEnabled = overlay->m_lineChartNewMeanEnabled;
-    m_lineChartNewMeanValue = overlay->m_lineChartNewMeanValue;
-    m_lineChartNewDeviationEnabled = overlay->m_lineChartNewDeviationEnabled;
-    m_lineChartNormalizationAbsoluteValueEnabled = overlay->m_lineChartNormalizationAbsoluteValueEnabled;
-    m_lineChartNewDeviationValue   = overlay->m_lineChartNewDeviationValue;
+    
+    m_lineChartSettings = overlay->m_lineChartSettings;
+    m_previousLineChartSettings.reset();
 }
 
 /**
@@ -637,9 +641,17 @@ ChartTwoOverlay::getBounds(BoundingBox& boundingBoxOut) const
         case ChartTwoDataTypeEnum::CHART_DATA_TYPE_MATRIX:
         {
             const ChartableTwoFileMatrixChart* matrixChart = chartDelegate->getMatrixCharting();
-            validFlag = matrixChart->getMatrixChartingGraphicsPrimitive(getMatrixTriangularViewingMode(),
-                                                                        CiftiMappableDataFile::MatrixGridMode::FILLED_TEXTURE,
-                                                                        getMatrixOpacity())->getVertexBounds(boundingBoxOut);
+            {
+                GraphicsPrimitive* prim(matrixChart->getMatrixChartingGraphicsPrimitive(getMatrixTriangularViewingMode(),
+                                                                                        CiftiMappableDataFile::MatrixGridMode::FILLED_TEXTURE,
+                                                                                        getMatrixOpacity()));
+                if (prim != NULL) {
+                    validFlag = prim->getVertexBounds(boundingBoxOut);
+                }
+            }
+//            validFlag = matrixChart->getMatrixChartingGraphicsPrimitive(getMatrixTriangularViewingMode(),
+//                                                                        CiftiMappableDataFile::MatrixGridMode::FILLED_TEXTURE,
+//                                                                        getMatrixOpacity())->getVertexBounds(boundingBoxOut);
         }
             break;
     }
@@ -690,33 +702,20 @@ ChartTwoOverlay::getLineLayerChartDisplayedCartesianData()
             ChartTwoDataCartesian* cartesianLineData = layerChart->getChartMapLineForChartTwoOverlay(selectedIndex);
             CaretAssert(cartesianLineData);
             
+            m_lineChartSettings.updateFileSettings(mapFile,
+                                                   selectedIndex,
+                                                   mapFile->getNumberOfMaps(),
+                                                   cartesianLineData,
+                                                   cartesianLineData->getGraphicsPrimitive()->getNumberOfVertices());
             /*
              * Cache the data (not done yet)
              */
-            if ((m_previousLineChartSettings.m_mapFile != mapFile)
-                || (m_previousLineChartSettings.m_mapIndex != selectedIndex)
-                || (m_previousLineChartSettings.m_numberOfMaps != mapFile->getNumberOfMaps())
-                || (m_previousLineChartSettings.m_cartesianLineData != cartesianLineData)
-                || (m_previousLineChartSettings.m_numberOfCartesianVertices != cartesianLineData->getGraphicsPrimitive()->getNumberOfVertices())
-                || (m_previousLineChartSettings.m_newMean != m_lineChartNewMeanValue)
-                || (m_previousLineChartSettings.m_newDeviation != m_lineChartNewDeviationValue)
-                || (m_previousLineChartSettings.m_newMeanEnabled != m_lineChartNewMeanEnabled)
-                || (m_previousLineChartSettings.m_newDeviationEnabled != m_lineChartNewDeviationEnabled)
-                || (m_previousLineChartSettings.m_lineChartNormalizationAbsoluteValueEnabled != m_lineChartNormalizationAbsoluteValueEnabled)) {
+            if ( ! (m_lineChartSettings == m_previousLineChartSettings)) {
                 m_lineChartNormalizedCartesianData.reset();
             }
                 
-            m_previousLineChartSettings.m_mapFile = mapFile;
-            m_previousLineChartSettings.m_mapIndex  = selectedIndex;
-            m_previousLineChartSettings.m_numberOfMaps = mapFile->getNumberOfMaps();
-            m_previousLineChartSettings.m_cartesianLineData = cartesianLineData;
-            m_previousLineChartSettings.m_numberOfCartesianVertices = cartesianLineData->getGraphicsPrimitive()->getNumberOfVertices();
-            m_previousLineChartSettings.m_newMean = m_lineChartNewMeanValue;
-            m_previousLineChartSettings.m_newDeviation = m_lineChartNewDeviationValue;
-            m_previousLineChartSettings.m_newMeanEnabled = m_lineChartNewMeanEnabled;
-            m_previousLineChartSettings.m_newDeviationEnabled = m_lineChartNewDeviationEnabled;
-            m_previousLineChartSettings.m_lineChartNormalizationAbsoluteValueEnabled = m_lineChartNormalizationAbsoluteValueEnabled;
-
+            m_previousLineChartSettings = m_lineChartSettings;
+            
             if ( ! m_lineChartNormalizedCartesianData) {
                 /*
                  * Need to clone the line
@@ -733,19 +732,13 @@ ChartTwoOverlay::getLineLayerChartDisplayedCartesianData()
             }
             
             
-            if (m_lineChartNewMeanEnabled
-                || m_lineChartNewDeviationEnabled
-                || m_lineChartNormalizationAbsoluteValueEnabled) {
+            if (m_lineChartSettings.anyModificationEnabled()) {
                 /*
                  * Apply new mean and deviation to Y-components
                  */
                 bool haveNanInfFlag(false);
                 CaretAssert(m_lineChartNormalizedCartesianData->getGraphicsPrimitive());
-                m_lineChartNormalizedCartesianData->getGraphicsPrimitive()->applyNewMeanAndDeviationToYComponents(m_lineChartNewMeanEnabled,
-                                                                                                                  m_lineChartNewMeanValue,
-                                                                                                                  m_lineChartNewDeviationEnabled,
-                                                                                                                  m_lineChartNewDeviationValue,
-                                                                                                                  m_lineChartNormalizationAbsoluteValueEnabled,
+                m_lineChartNormalizedCartesianData->getGraphicsPrimitive()->applyNewMeanAndDeviationToYComponents(m_lineChartSettings,
                                                                                                                   haveNanInfFlag);
                 
                 if (haveNanInfFlag) {
@@ -1387,6 +1380,8 @@ ChartTwoOverlay::isAllMapsSupported() const
                         case DataFileTypeEnum::CONNECTIVITY_PARCEL_DENSE:
                             supportedFlag = true;
                             break;
+                        case DataFileTypeEnum::CONNECTIVITY_PARCEL_DYNAMIC:
+                            break;
                         case DataFileTypeEnum::CONNECTIVITY_PARCEL_LABEL:
                             break;
                         case DataFileTypeEnum::CONNECTIVITY_PARCEL_SCALAR:
@@ -1395,8 +1390,12 @@ ChartTwoOverlay::isAllMapsSupported() const
                             break;
                         case DataFileTypeEnum::CONNECTIVITY_SCALAR_DATA_SERIES:
                             break;
+                        case DataFileTypeEnum::CZI_IMAGE_FILE:
+                            break;
                         case DataFileTypeEnum::FOCI:
                             break;
+                        case DataFileTypeEnum::HISTOLOGY_SLICES:
+                            break;
                         case DataFileTypeEnum::IMAGE:
                             break;
                         case DataFileTypeEnum::LABEL:
@@ -1409,6 +1408,8 @@ ChartTwoOverlay::isAllMapsSupported() const
                             break;
                         case DataFileTypeEnum::RGBA:
                             break;
+                        case DataFileTypeEnum::SAMPLES:
+                            break;
                         case DataFileTypeEnum::SCENE:
                             break;
                         case DataFileTypeEnum::SPECIFICATION:
@@ -1921,7 +1922,7 @@ ChartTwoOverlay::setSelectedLineChartTextOffset(const CardinalDirectionEnum::Enu
 bool
 ChartTwoOverlay::isLineChartNewMeanEnabled() const
 {
-    return m_lineChartNewMeanEnabled;
+    return m_lineChartSettings.m_newMeanEnabled;
 }
 
 /**
@@ -1932,7 +1933,7 @@ ChartTwoOverlay::isLineChartNewMeanEnabled() const
 void
 ChartTwoOverlay::setLineChartNewMeanEnabled(const bool enabled)
 {
-    m_lineChartNewMeanEnabled = enabled;
+    m_lineChartSettings.m_newMeanEnabled = enabled;
 }
 
 /**
@@ -1941,7 +1942,7 @@ ChartTwoOverlay::setLineChartNewMeanEnabled(const bool enabled)
 float
 ChartTwoOverlay::getLineChartNewMeanValue() const
 {
-    return m_lineChartNewMeanValue;
+    return m_lineChartSettings.m_newMeanValue;
 }
 
 /**
@@ -1952,7 +1953,7 @@ ChartTwoOverlay::getLineChartNewMeanValue() const
 void
 ChartTwoOverlay::setLineChartNewMeanValue(const float value)
 {
-    m_lineChartNewMeanValue = value;
+    m_lineChartSettings.m_newMeanValue = value;
 }
 
 /**
@@ -1961,7 +1962,7 @@ ChartTwoOverlay::setLineChartNewMeanValue(const float value)
 bool
 ChartTwoOverlay::isLineChartNewDeviationEnabled() const
 {
-    return m_lineChartNewDeviationEnabled;
+    return m_lineChartSettings.m_newDeviationEnabled;
 }
 
 /**
@@ -1972,7 +1973,7 @@ ChartTwoOverlay::isLineChartNewDeviationEnabled() const
 void
 ChartTwoOverlay::setLineChartNewDeviationEnabled(const bool enabled)
 {
-    m_lineChartNewDeviationEnabled = enabled;
+    m_lineChartSettings.m_newDeviationEnabled = enabled;
 }
 
 /**
@@ -1981,7 +1982,7 @@ ChartTwoOverlay::setLineChartNewDeviationEnabled(const bool enabled)
 bool
 ChartTwoOverlay::isLineChartNormalizationAbsoluteValueEnabled() const
 {
-    return m_lineChartNormalizationAbsoluteValueEnabled;
+    return m_lineChartSettings.m_absoluteValueEnabled;
 }
 
 /**
@@ -1992,7 +1993,7 @@ ChartTwoOverlay::isLineChartNormalizationAbsoluteValueEnabled() const
 void
 ChartTwoOverlay::setLineChartNormalizationAbsoluteValueEnabled(const bool enabled)
 {
-    m_lineChartNormalizationAbsoluteValueEnabled = enabled;
+    m_lineChartSettings.m_absoluteValueEnabled = enabled;
 }
 
 /**
@@ -2001,7 +2002,7 @@ ChartTwoOverlay::setLineChartNormalizationAbsoluteValueEnabled(const bool enable
 float
 ChartTwoOverlay::getLineChartNewDeviationValue() const
 {
-    return m_lineChartNewDeviationValue;
+    return m_lineChartSettings.m_newDeviationValue;
 }
 
 /**
@@ -2012,7 +2013,89 @@ ChartTwoOverlay::getLineChartNewDeviationValue() const
 void
 ChartTwoOverlay::setLineChartNewDeviationValue(const float value)
 {
-    m_lineChartNewDeviationValue = value;
+    m_lineChartSettings.m_newDeviationValue = value;
+}
+
+
+/*
+ * @return Line chart add to mean value enabled
+ */
+bool
+ChartTwoOverlay::isLineChartDataOffsetEnabled()
+{
+    return m_lineChartSettings.m_dataOffsetEnabled;
+}
+
+/**
+ * Set line chart add to mean value enabled
+ * @param enable
+ *    New status
+ */
+void
+ChartTwoOverlay::setLineChartDataOffsetEnabled(const bool enabled)
+{
+    m_lineChartSettings.m_dataOffsetEnabled = enabled;
+}
+
+/**
+ * @return Line chart add to mean  value
+ */
+float
+ChartTwoOverlay::getLineChartDataOffsetValue() const
+{
+    return m_lineChartSettings.m_dataOffsetValue;
+}
+
+/**
+ * Set the line chart add to mean value
+ * @param value
+ *    New deviation value
+ */
+void
+ChartTwoOverlay::setLineChartDataOffsetValue(const float value)
+{
+    m_lineChartSettings.m_dataOffsetValue = value;
+}
+
+
+/*
+ * @return Line chart add to mean value enabled
+ */
+bool
+ChartTwoOverlay::isLineChartMultiplyDeviationEnabled() const
+{
+    return m_lineChartSettings.m_multiplyDeviationEnabled;
+}
+
+/**
+ * Set line chart add to mean value enabled
+ * @param enable
+ *    New status
+ */
+void
+ChartTwoOverlay::setLineChartMultiplyDeviationEnabled(const bool enabled)
+{
+    m_lineChartSettings.m_multiplyDeviationEnabled = enabled;
+}
+
+/**
+ * @return Line chart add to mean  value
+ */
+float
+ChartTwoOverlay::getLineChartMultiplyDeviationValue() const
+{
+    return m_lineChartSettings.m_multiplyDeviationValue;
+}
+
+/**
+ * Set the line chart add to mean value
+ * @param value
+ *    New deviation value
+ */
+void
+ChartTwoOverlay::setLineChartMultiplyDeviationValue(const float value)
+{
+    m_lineChartSettings.m_multiplyDeviationValue = value;
 }
 
 /**
