@@ -25,6 +25,9 @@
 #include "SessionManager.h"
 #undef __SESSION_MANAGER_DECLARE__
 
+#include <QImageReader>
+#include <QNetworkProxyFactory>
+
 #include "AnnotationBrowserTab.h"
 #include "AnnotationManager.h"
 #include "ApplicationInformation.h"
@@ -41,6 +44,7 @@
 #include "CiftiConnectivityMatrixDataFileManager.h"
 #include "CiftiFiberTrajectoryManager.h"
 #include "DataToolTipsManager.h"
+#include "DrawingViewportContentManager.h"
 #include "ElapsedTimer.h"
 #include "EventManager.h"
 #include "EventBrowserTabClose.h"
@@ -52,6 +56,7 @@
 #include "EventBrowserTabNewClone.h"
 #include "EventBrowserTabReopenAvailable.h"
 #include "EventBrowserTabReopenClosed.h"
+#include "EventBrowserTabValidate.h"
 #include "EventBrowserWindowContent.h"
 #include "EventCaretPreferencesGet.h"
 #include "EventChartTwoCartesianAxisDisplayGroup.h"
@@ -63,7 +68,7 @@
 #include "EventProgressUpdate.h"
 #include "EventRecentFilesSystemAccessMode.h"
 #include "EventSpacerTabGet.h"
-#include "ImageCaptureSettings.h"
+#include "ImageCaptureDialogSettings.h"
 #include "LogManager.h"
 #include "MapYokingGroupEnum.h"
 #include "ModelWholeBrain.h"
@@ -88,11 +93,26 @@ SessionManager::SessionManager()
 {
     m_caretPreferences = new CaretPreferences();
     
-    m_imageCaptureDialogSettings = new ImageCaptureSettings();
+    m_imageCaptureDialogSettings = new ImageCaptureDialogSettings();
 
+#if QT_VERSION >= 0x060000
+    /*
+     * Qt may reject large images with the message:
+     *    QImageIOHandler: Rejecting image as it exceeds the current allocation limit of 128 megabytes
+     *
+     * Setting the allocation limit to zero removes this limit.  However, if there is an
+     * attempt to read a corrupt file, it could cause a very large allocation of memory
+     * that could be fatal or cause other problems.
+     *
+     * This allocation limit was added in Qt 6.0
+     */
+    QImageReader::setAllocationLimit(0);
+#endif
+    
     m_ciftiConnectivityMatrixDataFileManager = new CiftiConnectivityMatrixDataFileManager();
     m_ciftiFiberTrajectoryManager = new CiftiFiberTrajectoryManager();
     m_dataToolTipsManager.reset(new DataToolTipsManager(m_caretPreferences->isShowDataToolTipsEnabled()));
+    m_drawingViewportContentManager.reset(new DrawingViewportContentManager());
     
     m_browserTabs.fill(NULL);
     
@@ -120,6 +140,7 @@ SessionManager::SessionManager()
     EventManager::get()->addEventListener(this, EventTypeEnum::EVENT_BROWSER_TAB_NEW_CLONE);
     EventManager::get()->addEventListener(this, EventTypeEnum::EVENT_BROWSER_TAB_REOPEN_AVAILBLE);
     EventManager::get()->addEventListener(this, EventTypeEnum::EVENT_BROWSER_TAB_REOPEN_CLOSED);
+    EventManager::get()->addEventListener(this, EventTypeEnum::EVENT_BROWSER_TAB_VALIDATE);
     EventManager::get()->addEventListener(this, EventTypeEnum::EVENT_BROWSER_WINDOW_CONTENT);
     EventManager::get()->addEventListener(this, EventTypeEnum::EVENT_CARET_PREFERENCES_GET);
     EventManager::get()->addEventListener(this, EventTypeEnum::EVENT_CHART_TWO_CARTEISAN_AXIS_DISPLAY_GROUP);
@@ -134,6 +155,21 @@ SessionManager::SessionManager()
     Brain* brain = new Brain(m_caretPreferences);
     m_brains.push_back(brain);
     m_movieRecorder.reset(new MovieRecorder());
+    
+    switch (ApplicationInformation::getApplicationType()) {
+        case ApplicationTypeEnum::APPLICATION_TYPE_COMMAND_LINE:
+            break;
+        case ApplicationTypeEnum::APPLICATION_TYPE_GRAPHICAL_USER_INTERFACE:
+            /*
+             * Enables the use of the platform-specific proxy settings, and only those.
+             * This should allow use of a proxy when uploading to BALSA.
+             */
+            QNetworkProxyFactory::setUseSystemConfiguration(true);
+            break;
+        case ApplicationTypeEnum::APPLICATION_TYPE_INVALID:
+            break;
+    }
+    
 }
 
 /**
@@ -465,6 +501,22 @@ SessionManager::receiveEvent(Event* event)
         }
         lastTabEvent->setEventProcessed();
     }
+    else if (event->getEventType() == EventTypeEnum::EVENT_BROWSER_TAB_VALIDATE) {
+        EventBrowserTabValidate* tabEvent = dynamic_cast<EventBrowserTabValidate*>(event);
+        CaretAssert(tabEvent);
+        tabEvent->setEventProcessed();
+        const BrowserTabContent* browserTab(tabEvent->getBrowserTabContent());
+        
+        if (browserTab != NULL) {
+            std::vector<BrowserTabContent*> activeTabs = getActiveBrowserTabs();
+            for (auto bt : activeTabs) {
+                if (bt == browserTab) {
+                    tabEvent->setValid(true);
+                    break;
+                }
+            }
+        }
+    }
     else if (event->getEventType() == EventTypeEnum::EVENT_BROWSER_WINDOW_CONTENT) {
         EventBrowserWindowContent* windowEvent =
         dynamic_cast<EventBrowserWindowContent*>(event);
@@ -827,10 +879,11 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
     /*
      * Default to user preferences for colors
      */
-    m_caretPreferences->setBackgroundAndForegroundColorsMode(BackgroundAndForegroundColorsModeEnum::USER_PREFERENCES);
+    m_caretPreferences->setBackgroundAndForegroundColorsSceneOverrideMode(CaretPreferenceValueSceneOverrideModeEnum::USER_PREFERENCES);
     m_caretPreferences->invalidateSceneDataValues();
 
     m_sceneRestoredWithChartOldFlag = false;
+    m_sceneRestoredWithMprOldFlag   = false;
     
     if (sceneClass == NULL) {
         return;
@@ -855,6 +908,7 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
         return;
     }
     
+    m_sceneRestorationInProgressFlag = true;
     
     switch (sceneAttributes->getSceneType()) {
         case SceneTypeEnum::SCENE_TYPE_FULL:
@@ -1022,6 +1076,7 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
     EventManager::get()->sendEvent(progressEvent.getPointer());
     if (progressEvent.isCancelled()) {
         resetBrains(true);
+        m_sceneRestorationInProgressFlag = false;
         return;
     }
     
@@ -1038,6 +1093,7 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
     /*
      * Restore tabs
      */
+    std::map<BrowserTabContent*, const SceneClass*> browserTabsAndScenes;
     const SceneClassArray* browserTabArray = sceneClass->getClassArray("m_browserTabs");
     const int32_t numBrowserTabClasses = browserTabArray->getNumberOfArrayElements();
     for (int32_t i = 0; i < numBrowserTabClasses; i++) {
@@ -1054,6 +1110,7 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
         CaretAssertStdArrayIndex(m_browserTabs, tabIndex);
         m_browserTabs[tabIndex] = tab;
         
+        bool checkForMprOldFlag(false);
         switch (tab->getSelectedModelType()) {
             case ModelTypeEnum::MODEL_TYPE_CHART:
                 m_sceneRestoredWithChartOldFlag = true;
@@ -1062,6 +1119,8 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
                 break;
             case ModelTypeEnum::MODEL_TYPE_INVALID:
                 break;
+            case ModelTypeEnum::MODEL_TYPE_HISTOLOGY:
+                break;
             case ModelTypeEnum::MODEL_TYPE_MULTI_MEDIA:
                 break;
             case ModelTypeEnum::MODEL_TYPE_SURFACE:
@@ -1069,10 +1128,42 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
             case ModelTypeEnum::MODEL_TYPE_SURFACE_MONTAGE:
                 break;
             case ModelTypeEnum::MODEL_TYPE_VOLUME_SLICES:
+                checkForMprOldFlag = true;
                 break;
             case ModelTypeEnum::MODEL_TYPE_WHOLE_BRAIN:
+                checkForMprOldFlag = true;
                 break;
         }
+        
+        if (checkForMprOldFlag) {
+            switch (tab->getVolumeSliceProjectionType()) {
+                case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR:
+                    m_sceneRestoredWithMprOldFlag = true;
+                    break;
+                case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR_THREE:
+                    break;
+                case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_OBLIQUE:
+                    break;
+                case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_ORTHOGONAL:
+                    break;
+            }
+        }
+        
+        browserTabsAndScenes.insert(std::make_pair(tab, browserTabClass));
+    }
+    
+    /*
+     * Part two of browser tab restoration for
+     * members that must be restored after all browser
+     * tabs are restored.
+     */
+    for (auto& tabAndScene : browserTabsAndScenes) {
+        BrowserTabContent* btc(tabAndScene.first);
+        const SceneClass* sceneClass(tabAndScene.second);
+        CaretAssert(btc);
+        CaretAssert(sceneClass);
+        btc->restoreFromScenePartTwo(sceneAttributes,
+                                     sceneClass);
     }
     
     /*
@@ -1107,6 +1198,7 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
         if (guiManagerClass->getName() != "guiManager") {
             sceneAttributes->addToErrorMessage("Top level scene class should be guiManager but it is: "
                                                + guiManagerClass->getName());
+            m_sceneRestorationInProgressFlag = false;
             return;
         }
         
@@ -1134,6 +1226,7 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
                                                          [](BrowserWindowContent* bwc) { return bwc->isValid(); });
     if (numValidBrowserWindows <= 0) {
         sceneAttributes->addToErrorMessage("Scene error, no browser window content was restored");
+        m_sceneRestorationInProgressFlag = false;
         return;
     }
     
@@ -1150,11 +1243,11 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
         colorHelper.restoreFromScene(sceneAttributes,
                                      sceneClass->getClass("backgroundAndForegroundColors"));
         if (colorHelper.wasRestoredFromScene()) {
-            m_caretPreferences->setBackgroundAndForegroundColorsMode(BackgroundAndForegroundColorsModeEnum::SCENE);
+            m_caretPreferences->setBackgroundAndForegroundColorsSceneOverrideMode(CaretPreferenceValueSceneOverrideModeEnum::SCENE);
             m_caretPreferences->setSceneBackgroundAndForegroundColors(colors);
         }
         else {
-            m_caretPreferences->setBackgroundAndForegroundColorsMode(BackgroundAndForegroundColorsModeEnum::USER_PREFERENCES);
+            m_caretPreferences->setBackgroundAndForegroundColorsSceneOverrideMode(CaretPreferenceValueSceneOverrideModeEnum::USER_PREFERENCES);
         }
     }
     
@@ -1169,6 +1262,8 @@ SessionManager::restoreFromScene(const SceneAttributes* sceneAttributes,
                  + " seconds");
     timer.reset();
     
+    m_sceneRestorationInProgressFlag = false;
+    
     progressEvent.setProgress(PROGRESS_RESTORING_GUI,
                               "Restoring Graphical User Interface");
     EventManager::get()->sendEvent(progressEvent.getPointer());
@@ -1202,7 +1297,7 @@ SessionManager::savePreferencesToScene(const SceneAttributes* /*sceneAttributes*
     for (auto scv : sceneDataValues) {
         if (scv->isSavedToScenes()) {
             sceneClass->addString(scv->getName(),
-                                  scv->getPreferenceValue().toString());
+                                  scv->getValue().toString());
         }
     }
     
@@ -1327,7 +1422,7 @@ SessionManager::getDataToolTipsManager() const
 /**
  * @return Image capture settings for image capture dialog.
  */
-ImageCaptureSettings*
+ImageCaptureDialogSettings*
 SessionManager::getImageCaptureDialogSettings()
 {
     return m_imageCaptureDialogSettings;
@@ -1336,7 +1431,7 @@ SessionManager::getImageCaptureDialogSettings()
 /**
  * @return Image capture settings for image capture dialog (const method)
  */
-const ImageCaptureSettings*
+const ImageCaptureDialogSettings*
 SessionManager::getImageCaptureDialogSettings() const
 {
     return m_imageCaptureDialogSettings;
@@ -1437,7 +1532,7 @@ SessionManager::createNewBrowserTab()
         }
         
         CaretAssert(m_brains[0]);
-        AnnotationManager* annMan = m_brains[0]->getAnnotationManager();
+        AnnotationManager* annMan = m_brains[0]->getAnnotationManager(UserInputModeEnum::Enum::TILE_TABS_LAYOUT_EDITING);
         AString errorMessage;
         const bool resultFlag = annMan->moveTabOrWindowAnnotationToFront(newTab->getManualLayoutBrowserTabAnnotation(),
                                                                          errorMessage);
@@ -1621,4 +1716,30 @@ SessionManager::resetSceneWithChartOld()
     m_sceneRestoredWithChartOldFlag = false;
 }
 
+/**
+ * @return True if a scene was loaded that contains volume with MPR old
+ */
+bool
+SessionManager::hasSceneWithMprOld() const
+{
+    if (m_sceneRestorationInProgressFlag) {
+        /*
+         * Need to have MPR Old valid while browser tabs are being restored.
+         * Otherwise, the tab will not allow MPR Old and a scene that contains
+         * MPR Old will get changed to Ortho.
+         */
+        return true;
+    }
+    
+    return m_sceneRestoredWithMprOldFlag;
+}
+
+/**
+ * Reset the scene contains volume with MPR old
+ */
+void
+SessionManager::resetSceneWithMprOld()
+{
+    m_sceneRestoredWithMprOldFlag = false;
+}
 
