@@ -32,6 +32,7 @@
 #include "SceneEnumeratedType.h"
 #include "SessionManager.h"
 #include "VolumeFile.h"
+#include "VolumeMprSettings.h"
 
 using namespace caret;
 
@@ -51,25 +52,8 @@ const static VolumeSliceInterpolationEdgeEffectsMaskingEnum::Enum defaultVolumeS
 VolumeSliceSettings::VolumeSliceSettings()
 : CaretObject()
 {
-    CaretPreferences* prefs = SessionManager::get()->getCaretPreferences();
-    m_sliceViewPlane         = VolumeSliceViewPlaneEnum::AXIAL;
-    m_slicePlanesAllViewLayout = prefs->getVolumeAllSlicePlanesLayout();
-    m_sliceDrawingType       = VolumeSliceDrawingTypeEnum::VOLUME_SLICE_DRAW_SINGLE;
-    m_sliceProjectionType    = VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_ORTHOGONAL;
-    m_volumeSliceInterpolationEdgeEffectsMaskingType = defaultVolumeSliceInterpolationEdgeMaskType;
-    
-    m_montageNumberOfColumns = 6;
-    m_montageNumberOfRows    = 4;
-    m_montageSliceSpacing    = 5;
-    
-    m_sliceCoordinateAxial = 0.0;
-    m_sliceCoordinateCoronal = 0.0;
-    m_sliceCoordinateParasagittal = 0.0;
-    m_sliceEnabledAxial = true;
-    m_sliceEnabledCoronal = true;
-    m_sliceEnabledParasagittal = true;
-    m_initializedFlag = false;
-    
+    m_mprSettings.reset(new VolumeMprSettings());
+    reset();
     
     m_sceneAssistant = new SceneClassAssistant();
     m_sceneAssistant->add<VolumeSliceViewPlaneEnum,VolumeSliceViewPlaneEnum::Enum>("m_sliceViewPlane",
@@ -88,13 +72,16 @@ VolumeSliceSettings::VolumeSliceSettings()
                           &m_montageNumberOfRows);
     m_sceneAssistant->add("m_montageSliceSpacing",
                           &m_montageSliceSpacing);
-    
+    m_sceneAssistant->add<VolumeMontageSliceOrderModeEnum, VolumeMontageSliceOrderModeEnum::Enum>("m_montageSliceOrderMode",
+                                                                                                  &m_montageSliceOrderMode);
+
     m_sceneAssistant->add("m_sliceCoordinateAxial", &m_sliceCoordinateAxial);
     m_sceneAssistant->add("m_sliceCoordinateCoronal", &m_sliceCoordinateCoronal);
     m_sceneAssistant->add("m_sliceCoordinateParasagittal", &m_sliceCoordinateParasagittal);
     m_sceneAssistant->add("m_sliceEnabledAxial", &m_sliceEnabledAxial);
     m_sceneAssistant->add("m_sliceEnabledCoronal", &m_sliceEnabledCoronal);
     m_sceneAssistant->add("m_sliceEnabledParasagittal", &m_sliceEnabledParasagittal);
+    m_sceneAssistant->add("m_mprSettings", "VolumeMprSettings", m_mprSettings.get());
 }
 
 /**
@@ -150,6 +137,7 @@ VolumeSliceSettings::copyHelperVolumeSliceSettings(const VolumeSliceSettings& ob
     m_montageNumberOfColumns = obj.m_montageNumberOfColumns;
     m_montageNumberOfRows    = obj.m_montageNumberOfRows;
     m_montageSliceSpacing    = obj.m_montageSliceSpacing;
+    m_montageSliceOrderMode  = obj.m_montageSliceOrderMode;
 
     m_sliceCoordinateParasagittal = obj.m_sliceCoordinateParasagittal;
     m_sliceCoordinateCoronal      = obj.m_sliceCoordinateCoronal;
@@ -157,9 +145,29 @@ VolumeSliceSettings::copyHelperVolumeSliceSettings(const VolumeSliceSettings& ob
     m_sliceEnabledParasagittal = obj.m_sliceEnabledParasagittal;
     m_sliceEnabledCoronal      = obj.m_sliceEnabledCoronal;
     m_sliceEnabledAxial        = obj.m_sliceEnabledAxial;
+    
+    *m_mprSettings = *obj.m_mprSettings;
+    
     m_initializedFlag = true;
 }
 
+/**
+ * Copy the slice settings from the other instance for yoking.  A few members are not copied for yoking.
+ * @param volumeSliceSettings
+ *    The slice settings
+ */
+void
+VolumeSliceSettings::copyToMeForYoking(const VolumeSliceSettings& volumeSliceSettings)
+{
+    const VolumeSliceViewPlaneEnum::Enum sliceViewPlane(m_sliceViewPlane);
+    const VolumeSliceDrawingTypeEnum::Enum sliceDrawingType = m_sliceDrawingType;
+    
+    copyHelperVolumeSliceSettings(volumeSliceSettings);
+    
+    m_sliceViewPlane = sliceViewPlane;
+    m_sliceDrawingType = sliceDrawingType;
+}
+
 /**
  * Get a description of this object's content.
  * @return String describing this object's content.
@@ -192,7 +200,9 @@ VolumeSliceSettings::getDescriptionOfContent(const ModelTypeEnum::Enum modelType
             break;
         case ModelTypeEnum::MODEL_TYPE_INVALID:
             break;
-        case  ModelTypeEnum::MODEL_TYPE_MULTI_MEDIA:
+        case ModelTypeEnum::MODEL_TYPE_HISTOLOGY:
+            break;
+        case ModelTypeEnum::MODEL_TYPE_MULTI_MEDIA:
             break;
         case ModelTypeEnum::MODEL_TYPE_SURFACE:
             break;
@@ -250,9 +260,6 @@ VolumeSliceSettings::getDescriptionOfContent(const ModelTypeEnum::Enum modelType
     descriptionOut.popIndentation();
 }
 
-
-
-
 /**
  * @return The slice view plane.
  *
@@ -357,6 +364,26 @@ void
 VolumeSliceSettings::setSliceProjectionType(const VolumeSliceProjectionTypeEnum::Enum sliceProjectionType)
 {
     m_sliceProjectionType = sliceProjectionType;
+    
+    switch (m_sliceProjectionType) {
+        case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR:
+        case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR_THREE:
+            /*
+             * Switch to ALL view for MPR if NOT in MONTAGE
+             */
+            switch (m_sliceDrawingType) {
+                case VolumeSliceDrawingTypeEnum::VOLUME_SLICE_DRAW_MONTAGE:
+                    break;
+                case VolumeSliceDrawingTypeEnum::VOLUME_SLICE_DRAW_SINGLE:
+                    setSliceViewPlane(VolumeSliceViewPlaneEnum::ALL);
+                    break;
+            }
+            break;
+        case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_OBLIQUE:
+            break;
+        case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_ORTHOGONAL:
+            break;
+    }
 }
 
 
@@ -422,12 +449,23 @@ VolumeSliceSettings::setMontageSliceSpacing(const int32_t montageSliceSpacing)
 }
 
 /**
- * Set the selected slices to the origin.
+ * @return The montage slice order mode
+ */
+VolumeMontageSliceOrderModeEnum::Enum
+VolumeSliceSettings::getMontageSliceOrderMode() const
+{
+    return m_montageSliceOrderMode;
+}
+
+/**
+ * Set the montage slice direction mode
+ * @param montageSliceOrderMode
+ *    The montage slice order mode
  */
 void
-VolumeSliceSettings::setSlicesToOrigin()
+VolumeSliceSettings::setMontageSliceOrderMode(const VolumeMontageSliceOrderModeEnum::Enum montageSliceOrderMode)
 {
-    selectSlicesAtOrigin();
+    m_montageSliceOrderMode = montageSliceOrderMode;
 }
 
 /**
@@ -436,53 +474,66 @@ VolumeSliceSettings::setSlicesToOrigin()
 void
 VolumeSliceSettings::reset()
 {
-    m_sliceCoordinateAxial        = 0.0;
-    m_sliceCoordinateCoronal      = 0.0;
-    m_sliceCoordinateParasagittal = 0.0;
+    CaretPreferences* prefs = SessionManager::get()->getCaretPreferences();
+    m_sliceViewPlane         = VolumeSliceViewPlaneEnum::AXIAL;
+    m_slicePlanesAllViewLayout = prefs->getVolumeAllSlicePlanesLayout();
+    m_sliceDrawingType       = VolumeSliceDrawingTypeEnum::VOLUME_SLICE_DRAW_SINGLE;
+    m_sliceProjectionType    = VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_ORTHOGONAL;
+    m_volumeSliceInterpolationEdgeEffectsMaskingType = defaultVolumeSliceInterpolationEdgeMaskType;
     
-    m_sliceEnabledAxial        = true;
-    m_sliceEnabledCoronal      = true;
+    m_montageNumberOfColumns = 6;
+    m_montageNumberOfRows    = 4;
+    m_montageSliceSpacing    = 5;
+    m_montageSliceOrderMode  = VolumeMontageSliceOrderModeEnum::WORKBENCH;
+
+    m_sliceCoordinateAxial = 0.0;
+    m_sliceCoordinateCoronal = 0.0;
+    m_sliceCoordinateParasagittal = 0.0;
+    m_sliceEnabledAxial = true;
+    m_sliceEnabledCoronal = true;
     m_sliceEnabledParasagittal = true;
+    m_initializedFlag = false;
+    
+    CaretAssert(m_mprSettings);
+    m_mprSettings->reset();
     
     m_initializedFlag = false;
 }
 
 /**
- * Update the slices coordinates so that they are valid for
- * the given VolumeFile.
- * @param volumeFile
- *   File for which slice coordinates are made valid.
+ * Set the slice indices so that they are at the origin.  However, if the coordinate (0, 0, 0) is outside
+ * of the volume, select coordinate at the middle of the volume.
+ * @param volumeInterface
+ *    The underlay volume (may be NULL)
  */
 void
-VolumeSliceSettings::updateForVolumeFile(const VolumeMappableInterface* volumeFile)
-{
-    if (volumeFile == NULL) {
-        reset();
-        return;
-    }
-    
-    if (m_initializedFlag == false) {
-        m_initializedFlag = true;
-        selectSlicesAtOrigin();
-    }
-    
-    /*
-     * These calls will make the slices valid
-     */
-    getSliceIndexParasagittal(volumeFile);
-    getSliceIndexCoronal(volumeFile);
-    getSliceIndexAxial(volumeFile);
-}
-
-/**
- * Set the slice indices so that they are at the origin.
- */
-void
-VolumeSliceSettings::selectSlicesAtOrigin()
+VolumeSliceSettings::selectSlicesAtOrigin(const VolumeMappableInterface* volumeInterface)
 {
     m_sliceCoordinateAxial        = 0.0;
     m_sliceCoordinateCoronal      = 0.0;
     m_sliceCoordinateParasagittal = 0.0;
+    
+    /*
+     * If (0, 0, 0) is not within the volume
+     * set selected slices to "middle" of the volume.
+     */
+    if (volumeInterface != NULL) {
+        int64_t indexI(0), indexJ(0), indexK(0);
+        volumeInterface->enclosingVoxel(0.0, 0.0, 0.0, indexI, indexJ, indexK);
+        if ( ! volumeInterface->indexValid(indexI, indexJ, indexK)) {
+            int64_t dimI, dimJ, dimK, dimTime, dimCompontents;
+            volumeInterface->getDimensions(dimI, dimJ, dimK, dimTime, dimCompontents);
+            if ((dimI > 1) && (dimJ > 1) && (dimK > 1)) {
+                indexI = dimI / 2;
+                indexJ = dimJ / 2;
+                indexK = dimK / 2;
+                if (volumeInterface->indexValid(indexI, indexJ, indexK)) {
+                    volumeInterface->indexToSpace((float)indexI, (float)indexJ, (float)indexK,
+                                                  m_sliceCoordinateParasagittal, m_sliceCoordinateCoronal, m_sliceCoordinateAxial);
+                }
+            }
+        }
+    }
 }
 
 /**
@@ -879,6 +930,24 @@ VolumeSliceSettings::setSliceAxialEnabled(const bool sliceEnabledAxial)
     m_sliceEnabledAxial = sliceEnabledAxial;
 }
 
+/**
+ * @return The MPR settings
+ */
+VolumeMprSettings*
+VolumeSliceSettings::getMprSettings()
+{
+    return m_mprSettings.get();
+}
+
+/**
+ * @return the MPR settings (const)
+ */
+const VolumeMprSettings*
+VolumeSliceSettings::getMprSettings() const
+{
+    return m_mprSettings.get();
+}
+
 /**
  * Save information specific to this type of model to the scene.
  *
@@ -896,7 +965,7 @@ VolumeSliceSettings::saveToScene(const SceneAttributes* sceneAttributes,
 {
     SceneClass* sceneClass = new SceneClass(instanceName,
                                             "VolumeSliceSettings",
-                                            2);
+                                            3);  // 3 -> new MPR modes including average
     m_sceneAssistant->saveMembers(sceneAttributes,
                                   sceneClass);
     
@@ -957,12 +1026,78 @@ VolumeSliceSettings::restoreFromScene(const SceneAttributes* sceneAttributes,
         }
     }
 
+    if (sceneClass->getVersionNumber() < 3) {
+        /*
+         * For scenes before all view layout, use GRID so that the
+         * older scenes display correctly
+         */
+        if (sceneClass->getObjectWithName("m_slicePlanesAllViewLayout") == NULL) {
+            m_slicePlanesAllViewLayout = VolumeSliceViewAllPlanesLayoutEnum::GRID_LAYOUT;
+        }
+        
+        /*
+         * Intensity mode was available early in Intensity mode development then
+         * moved to volume slice projection type.
+         */
+        const AString oldMprIntensityMode(sceneClass->getEnumeratedTypeValueAsString("m_mprIntensityProjectionMode"));
+        if ( ! oldMprIntensityMode.isEmpty()) {
+            if (oldMprIntensityMode == "MAXIMUM") {
+                m_sliceProjectionType = VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR;
+                m_mprSettings->setViewMode(VolumeMprViewModeEnum::MAXIMUM_INTENSITY_PROJECTION);
+            }
+            else if (oldMprIntensityMode == "MINIMUM") {
+                m_sliceProjectionType = VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR;
+                m_mprSettings->setViewMode(VolumeMprViewModeEnum::MINIMUM_INTENSITY_PROJECTION);
+            }
+        }
+        
+        /*
+         * MPR Neurological and Radiological were combined into VOLUME_SLICE_PROJECTION_MPR
+         * and MPR orientation was added
+         */
+        const AString oldSliceProjectionType(sceneClass->getEnumeratedTypeValueAsString("m_sliceProjectionType"));
+        if ( ! oldSliceProjectionType.isEmpty()) {
+            if (oldSliceProjectionType == "VOLUME_SLICE_PROJECTION_MPR_NEUROLOGICAL") {
+                m_sliceProjectionType = VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR;
+                m_mprSettings->setOrientationMode(VolumeMprOrientationModeEnum::NEUROLOGICAL);
+            }
+            else if (oldSliceProjectionType == "VOLUME_SLICE_PROJECTION_MPR_RADIOLOGICAL") {
+                m_sliceProjectionType = VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR;
+                m_mprSettings->setOrientationMode(VolumeMprOrientationModeEnum::RADIOLOGICAL);
+            }
+            else if (oldSliceProjectionType == "VOLUME_SLICE_PROJECTION_MPR") {
+                m_sliceProjectionType = VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR;
+                m_mprSettings->setViewMode(VolumeMprViewModeEnum::MULTI_PLANAR_RECONSTRUCTION);
+            }
+            else if (oldSliceProjectionType == "VOLUME_SLICE_PROJECTION_MPR_MAXIMUM_INTENSITY") {
+                m_sliceProjectionType = VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR;
+                m_mprSettings->setViewMode(VolumeMprViewModeEnum::MAXIMUM_INTENSITY_PROJECTION);
+            }
+            else if (oldSliceProjectionType == "VOLUME_SLICE_PROJECTION_MPR_MINIMUM_INTENSITY") {
+                m_sliceProjectionType = VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR;
+                m_mprSettings->setViewMode(VolumeMprViewModeEnum::MINIMUM_INTENSITY_PROJECTION);
+            }
+        }
+        
+        /*
+         * old mpr orientation moved to VolumeMprSettings
+         */
+        const AString oldMprOrientation(sceneClass->getEnumeratedTypeValueAsString("m_mprOrientationMode"));
+        if ( ! oldMprOrientation.isEmpty()) {
+            if (oldMprOrientation == "NEUROLOGICAL") {
+                m_mprSettings->setOrientationMode(VolumeMprOrientationModeEnum::NEUROLOGICAL);
+            }
+            else if (oldMprOrientation == "RADIOLOGICAL") {
+                m_mprSettings->setOrientationMode(VolumeMprOrientationModeEnum::RADIOLOGICAL);
+            }
+        }
+    }
+    
     /*
-     * For scenes before all view layout, use GRID so that the
-     * older scenes display correctly
+     * Scene may have been created before slice order mode was added
      */
-    if (sceneClass->getObjectWithName("m_slicePlanesAllViewLayout") == NULL) {
-        m_slicePlanesAllViewLayout = VolumeSliceViewAllPlanesLayoutEnum::GRID_LAYOUT;
+    if (sceneClass->getObjectWithName("m_montageSliceOrderMode") == NULL) {
+        m_montageSliceOrderMode = VolumeMontageSliceOrderModeEnum::WORKBENCH;
     }
     
     /*
