@@ -23,6 +23,7 @@
 #include "ChartTwoDataCartesian.h"
 #undef __CHART_TWO_DATA_CARTESIAN_DECLARE__
 
+#include <cmath>
 #include <limits>
 
 #include <QTextStream>
@@ -32,6 +33,8 @@
 #include "ChartPoint.h"
 #include "GraphicsPrimitiveV3f.h"
 #include "MapFileDataSelector.h"
+#include "MathFunctions.h"
+#include "Matrix4x4Interface.h"
 #include "SceneClass.h"
 #include "SceneClassAssistant.h"
 #include "ScenePrimitiveArray.h"
@@ -76,6 +79,8 @@ m_graphicsPrimitiveType(graphicsPrimitiveType)
         case ChartTwoDataTypeEnum::CHART_DATA_TYPE_HISTOGRAM:
             CaretAssert(0);
             break;
+        case ChartTwoDataTypeEnum::CHART_DATA_TYPE_LINE_LAYER:
+            break;
         case ChartTwoDataTypeEnum::CHART_DATA_TYPE_LINE_SERIES:
             break;
         case ChartTwoDataTypeEnum::CHART_DATA_TYPE_MATRIX:
@@ -101,7 +106,6 @@ ChartTwoDataCartesian::initializeMembersChartTwoDataCartesian()
     m_mapFileDataSelector = std::unique_ptr<MapFileDataSelector>(new MapFileDataSelector());
     
     m_selectionStatus   = true;
-    m_color             = CaretColorEnum::RED;
     m_lineWidth         = getDefaultLineWidth();
     m_timeStartInSecondsAxisX = 0.0;
     m_timeStepInSecondsAxisX  = 1.0;
@@ -112,6 +116,7 @@ ChartTwoDataCartesian::initializeMembersChartTwoDataCartesian()
     CaretColorEnum::getColorEnumsNoBlackOrWhite(colorEnums);
     const int32_t numCaretColors = static_cast<int32_t>(colorEnums.size());
     
+    CaretColorEnum::Enum defaultColor = CaretColorEnum::RED;
     bool colorFound = false;
     while ( ! colorFound) {
         ChartTwoDataCartesian::caretColorIndex++;
@@ -126,11 +131,11 @@ ChartTwoDataCartesian::initializeMembersChartTwoDataCartesian()
             /* do not use white */
         }
         else {
-            m_color = colorEnums[ChartTwoDataCartesian::caretColorIndex];
+            defaultColor = colorEnums[ChartTwoDataCartesian::caretColorIndex];
             colorFound = true;
         }
     }
-    setColor(m_color);
+    setColorEnum(defaultColor);
     
     m_sceneAssistant = new SceneClassAssistant();
     
@@ -140,8 +145,6 @@ ChartTwoDataCartesian::initializeMembersChartTwoDataCartesian()
                                                                 &m_dataAxisUnitsX);
     m_sceneAssistant->add<CaretUnitsTypeEnum, CaretUnitsTypeEnum::Enum>("m_dataAxisUnitsY",
                                                                 &m_dataAxisUnitsY);
-    m_sceneAssistant->add<CaretColorEnum, CaretColorEnum::Enum>("m_color",
-                                                                &m_color);
     m_sceneAssistant->add("m_lineWidth",
                           &m_lineWidth);
     m_sceneAssistant->add("m_timeStartInSecondsAxisX",
@@ -151,6 +154,10 @@ ChartTwoDataCartesian::initializeMembersChartTwoDataCartesian()
     m_sceneAssistant->add("m_mapFileDataSelector",
                           "MapFileDataSelector",
                           m_mapFileDataSelector.get());
+    m_sceneAssistant->add("m_selectedPointIndex",
+                          &m_selectedPointIndex);
+    m_sceneAssistant->add("m_selectedPointDisplayed",
+                          &m_selectedPointDisplayed);
 }
 
 /**
@@ -159,15 +166,14 @@ ChartTwoDataCartesian::initializeMembersChartTwoDataCartesian()
 std::unique_ptr<GraphicsPrimitiveV3f>
 ChartTwoDataCartesian::createGraphicsPrimitive()
 {
-    float rgba[4];
-    CaretColorEnum::toRGBAFloat(m_color, rgba);
+    std::array<uint8_t, 4> rgba = m_caretColor.getRGBA();
     
     /*
      * Note: LINES (line segments) are used so that individual segments can be identified.
      * Cannot use line strip since it is identified as a single item.
      */
     return std::unique_ptr<GraphicsPrimitiveV3f>(GraphicsPrimitive::newPrimitiveV3f(m_graphicsPrimitiveType,
-                                                                                    rgba));
+                                                                                    rgba.data()));
 }
 
 /**
@@ -204,6 +210,26 @@ ChartTwoDataCartesian::clone() const
     return cloneCopy;
 }
 
+/**
+ * At times a copy of chart data will be needed BUT it must be
+ * the proper subclass so copy constructor and assignment operator
+ * will no function when this abstract, base class is used.  Each
+ * subclass will override this method so that the returned class
+ * is of the proper type.
+ *
+ * @param matrix
+ *    Data points are transformed using this matrix
+ * @return Copy of this instance that is the actual subclass
+ */
+ChartTwoDataCartesian*
+ChartTwoDataCartesian::clone(const Matrix4x4Interface& matrix) const
+{
+    ChartTwoDataCartesian* cloneCopy = new ChartTwoDataCartesian(*this);
+    GraphicsPrimitiveV3f* primitive = cloneCopy->getGraphicsPrimitive();
+    primitive->transformVerticesFloatXYZ(matrix);
+    return cloneCopy;
+}
+
 /**
  * Copy constructor.
  * @param obj
@@ -252,10 +278,13 @@ ChartTwoDataCartesian::copyHelperChartTwoDataCartesian(const ChartTwoDataCartesi
 
     m_graphicsPrimitive.reset(dynamic_cast<GraphicsPrimitiveV3f*>(obj.m_graphicsPrimitive->clone()));
     
-    m_color             = obj.m_color;
-    m_lineWidth         = obj.m_lineWidth;
+    m_caretColor              = obj.m_caretColor;
+    m_lineWidth               = obj.m_lineWidth;
     m_timeStartInSecondsAxisX = obj.m_timeStartInSecondsAxisX;
     m_timeStepInSecondsAxisX  = obj.m_timeStepInSecondsAxisX;
+    
+    m_selectedPointIndex      = obj.m_selectedPointIndex;
+    m_selectedPointDisplayed  = obj.m_selectedPointDisplayed;
 }
 
 /**
@@ -288,16 +317,6 @@ void
 ChartTwoDataCartesian::setSelected(const bool selectionStatus)
 {
     m_selectionStatus = selectionStatus;
-    
-    /*
-     * When selection status is true,
-     * notify parent.
-     */
-    //    if (m_selectionStatus[tabIndex]) {
-    //        if (m_parentChartModel != NULL) {
-    //            m_parentChartModel->childChartTwoDataSelectionChanged(this);
-    //        }
-    //    }
 }
 
 
@@ -311,11 +330,35 @@ ChartTwoDataCartesian::setSelected(const bool selectionStatus)
  */
 void
 ChartTwoDataCartesian::addPoint(const float x,
-                                  const float y)
+                                const float y)
 {
     m_graphicsPrimitive->addVertex(x, y);
 }
 
+/**
+ * Get the coordinates of the point at the given index
+ * @param pointIndex
+ *    Index of the point
+ * @param xyzOut
+ *    Output containing XYZ of point
+ */
+void
+ChartTwoDataCartesian::getPointXYZ(const int32_t pointIndex,
+                                   float xyzOut[3]) const
+{
+    if ((pointIndex >= 0)
+        && (pointIndex < m_graphicsPrimitive->getNumberOfVertices())) {
+        m_graphicsPrimitive->getVertexFloatXYZ(pointIndex,
+                                               xyzOut);
+    }
+    else {
+        xyzOut[0] = 0.0;
+        xyzOut[1] = 0.0;
+        xyzOut[2] = 0.0;
+    }
+}
+
+
 /**
  * Get a bounds box for the cartesian data.
  *
@@ -395,12 +438,21 @@ ChartTwoDataCartesian::getDataAxisUnitsY()
 }
 
 /**
- * @return Color for chart
+ * @return Color enum for chart
  */
 CaretColorEnum::Enum
+ChartTwoDataCartesian::getColorEnum() const
+{
+    return m_caretColor.getCaretColorEnum();
+}
+
+/**
+ * @return Color for chart
+ */
+CaretColor
 ChartTwoDataCartesian::getColor() const
 {
-    return m_color;
+    return m_caretColor;
 }
 
 /**
@@ -410,17 +462,29 @@ ChartTwoDataCartesian::getColor() const
  *    New color for chart.
  */
 void
-ChartTwoDataCartesian::setColor(const CaretColorEnum::Enum color)
+ChartTwoDataCartesian::setColor(const CaretColor& color)
 {
-    m_color = color;
+    m_caretColor = color;
     
     if (m_graphicsPrimitive != NULL) {
-        float rgba[4];
-        CaretColorEnum::toRGBAFloat(m_color, rgba);
-        m_graphicsPrimitive->replaceAllVertexSolidFloatRGBA(rgba);
+        m_graphicsPrimitive->replaceAllVertexSolidByteRGBA(m_caretColor.getRGBA().data());
     }
 }
 
+/**
+ * Set the color for the chart with a color enum
+ *
+ * @param colorEnum
+ *    New color for chart.
+ */
+void
+ChartTwoDataCartesian::setColorEnum(const CaretColorEnum::Enum colorEnum)
+{
+    CaretColor cc;
+    cc.setCaretColorEnum(colorEnum);
+    setColor(cc);
+}
+
 /**
  * @return The line width.
  */
@@ -444,6 +508,157 @@ ChartTwoDataCartesian::setLineWidth(const float lineWidth)
                                       m_lineWidth);
 }
 
+/**
+ * @return Index of line segment containing X.  Index is of point at start of line segment.
+ * Negative if X is not within range of line.
+ *
+ * WARNING: Points MUST be ordered in ascending order by the X-coordinate.  If not,
+ * behavior is undefined.
+ *
+ * @param x
+ *    The X-coordinate
+ */
+int32_t
+ChartTwoDataCartesian::getLineSegmentIndexContainingX(const float x) const
+{
+    int32_t segmentIndex(-1);
+    
+    const float numLineSegments = m_graphicsPrimitive->getNumberOfVertices() - 1;
+    if (numLineSegments >= 1) {
+        /*
+         * Verify X is within range of the endpoints
+         */
+        float leftXYZ[3];
+        m_graphicsPrimitive->getVertexFloatXYZ(0, leftXYZ);
+        float rightXYZ[3];
+        m_graphicsPrimitive->getVertexFloatXYZ(numLineSegments, rightXYZ);
+        if ((x < leftXYZ[0])
+            || (x > rightXYZ[0])) {
+            return segmentIndex;
+        }
+
+        int32_t left(0);
+        int32_t right(numLineSegments);
+        while (left <= right) {
+            const int32_t middle = left + (right - left) / 2;
+            
+            float p1[3], p2[3];
+            m_graphicsPrimitive->getVertexFloatXYZ(middle, p1);
+            m_graphicsPrimitive->getVertexFloatXYZ(middle + 1, p2);
+            
+            if ((x >= p1[0])
+                && (x <= p2[0])) {
+                segmentIndex = middle;
+                break;
+            }
+            else {
+                if (x > p2[0]) {
+                    left = middle + 1;
+                }
+                else {
+                    right = middle;
+                }
+            }
+        }
+
+#ifdef VERIFY_FLAG
+        /*
+         * This is a slow linear search, used only in debug
+         * mode to verify binary search is correct
+         */
+        int32_t linearIndex(-1);
+        for (int32_t i = 0; i < numLineSegments; i++) {
+            float p1[3], p2[3];
+            m_graphicsPrimitive->getVertexFloatXYZ(i, p1);
+            m_graphicsPrimitive->getVertexFloatXYZ(i + 1, p2);
+            if ((x >= p1[0])
+                && (x <= p2[0])) {
+                linearIndex = i;
+            }
+        }
+        CaretAssert(segmentIndex == linearIndex);
+#endif // VERIFY_FLAG
+    }
+
+    return segmentIndex;
+}
+
+/**
+ * @return The vertical distance from the line to the given X, Y coordinates.  A negative
+ * value is returned if the X-coordinate is not within the line's range of X-coordinates.
+ * @param x
+ *    The X-coordinate
+ * @param y
+ *    The Y-coordinate
+ */
+bool
+ChartTwoDataCartesian::getVerticalDistanceToXY(const float x,
+                                               const float y,
+                                               float& distanceOut,
+                                               int32_t& pointIndexOut,
+                                               float chartXYZOut[3]) const
+{
+    distanceOut   = std::numeric_limits<float>::max();
+    pointIndexOut = -1;
+    const int32_t leftIndex = getLineSegmentIndexContainingX(x);
+    
+    if (leftIndex >= 0) {
+        const int32_t rightIndex(leftIndex + 1);
+        const float xyz[3] { x, y, 0.0f };
+
+        float p1[3], p2[3];
+        m_graphicsPrimitive->getVertexFloatXYZ(leftIndex, p1);
+        m_graphicsPrimitive->getVertexFloatXYZ(rightIndex, p2);
+        p1[2] = 0.0;
+        p2[2] = 0.0;
+        const float dist1(MathFunctions::distance3D(xyz, p1));
+        const float dist2(MathFunctions::distance3D(xyz, p2));
+        
+        const float dx = p2[0] - p1[0];
+        if (dx != 0.0) {
+            /*
+             * Vertical distance from point to the line segment
+             */
+            const float dy = p2[1] - p1[1];
+            const float m  = dy / dx;
+            const float b  = p1[1] - (m * p1[0]);
+            const float yOnSegment  = m * x + b;
+            distanceOut = std::fabs(yOnSegment - y);
+            if (dist1 < dist2) {
+                pointIndexOut = leftIndex;
+            }
+            else {
+                pointIndexOut = rightIndex;
+            }
+            
+            chartXYZOut[0] = x;
+            chartXYZOut[1] = yOnSegment;
+            chartXYZOut[2] = p1[2];
+        }
+        else {
+            /*
+             * Vertical line so use nearest point in line
+             */
+            if (dist1 < dist2) {
+                pointIndexOut = leftIndex;
+                distanceOut   = dist1;
+                chartXYZOut[0] = p1[0];
+                chartXYZOut[1] = p1[1];
+                chartXYZOut[2] = p1[2];
+            }
+            else {
+                pointIndexOut = rightIndex;
+                distanceOut   = dist2;
+                chartXYZOut[0] = p2[0];
+                chartXYZOut[1] = p2[1];
+                chartXYZOut[2] = p2[2];
+            }
+        }
+    }
+    
+    return (pointIndexOut >= 0);
+}
+
 /**
  * Save information specific to this type of model to the scene.
  *
@@ -464,9 +679,12 @@ ChartTwoDataCartesian::saveToScene(const SceneAttributes* sceneAttributes,
                                             1);
     m_sceneAssistant->saveMembers(sceneAttributes,
                                   sceneClass);
-    
-//    chartDataCartesian->addClass(m_mapFileDataSelector->saveToScene(sceneAttributes,
-//                                                            "m_mapFileDataSelector"));
+
+    /*
+     * Note: For line layer charts, color is from the chart overlay not this color
+     */
+    sceneClass->addString("m_caretColor",
+                          m_caretColor.encodeInXML());
     
     const std::vector<float>& xyz = m_graphicsPrimitive->getFloatXYZ();
     const int32_t numXYZ = static_cast<int32_t>(xyz.size());
@@ -501,7 +719,25 @@ ChartTwoDataCartesian::restoreFromScene(const SceneAttributes* sceneAttributes,
     
     m_sceneAssistant->restoreMembers(sceneAttributes, sceneClass);
     
-//    m_mapFileDataSelector->restoreFromScene(sceneAttributes, chartDataCartesian->getClass("m_mapFileDataSelector"));
+    /*
+     * m_caretColor (instance of CaretColor) replaced
+     * m_color (instance CaretColorEnum)
+     * Note: For line layer charts, color is from the chart overlay not this color
+     */
+    const QString caretColorText = sceneClass->getStringValue("m_caretColor", "");
+    if ( ! caretColorText.isEmpty()) {
+        AString errorMessage;
+        if ( ! m_caretColor.decodeFromXML(caretColorText,
+                                          errorMessage)) {
+            sceneAttributes->addToErrorMessage(errorMessage);
+        }
+    }
+    else {
+        const CaretColorEnum::Enum color = sceneClass->getEnumeratedTypeValue<CaretColorEnum,CaretColorEnum::Enum>("m_color",
+                                                                                                                   CaretColorEnum::BLUE);
+        m_caretColor.setCaretColorEnum(color);
+    }
+    
     
     const ScenePrimitiveArray* xyzArray = sceneClass->getPrimitiveArray("xyz");
     if (xyzArray != NULL) {
