@@ -27,21 +27,21 @@
 #include "ProgramParameters.h"
 #include "CommandException.h"
 #include "ProgramParametersException.h"
+#include "CaretPointer.h"
 
 #include <vector>
 #include <set>
 
 namespace caret {
 
-    class CommandParser : public CommandOperation, OperationParserInterface
+    class CommandParser : public CommandOperation
     {
         int m_minIndent, m_maxIndent, m_indentIncrement, m_maxWidth;
-        AString m_provenance, m_parentProvenance, m_workingDir;
         bool m_doProvenance, m_ciftiScale, m_volumeScale;
         double m_ciftiMin, m_ciftiMax, m_volumeMin, m_volumeMax;
         int16_t m_ciftiDType, m_volumeDType;
-        const static AString PROVENANCE_NAME, PARENT_PROVENANCE_NAME, PROGRAM_PROVENANCE_NAME, CWD_PROVENANCE_NAME;//TODO: put this elsewhere?
-        std::map<AString, const CiftiFile*> m_inputCiftiOnDiskMap;
+        std::map<AString, const CiftiParameter*> m_inputCiftiOnDiskMap;
+        CaretPointer<AutoOperationInterface> m_autoOper;
         struct OutputAssoc
         {//how the output is stored is up to the parser, in the GUI it should load into memory without writing to disk
             AString m_fileName;
@@ -56,9 +56,8 @@ namespace caret {
         void parseComponent(ParameterComponent* myComponent, ProgramParameters& parameters, std::vector<OutputAssoc>& outAssociation, bool debug = false);
         bool parseOption(const AString& mySwitch, ParameterComponent* myComponent, ProgramParameters& parameters, std::vector<OutputAssoc>& outAssociation, bool debug);
         void parseRemainingOptions(ParameterComponent* myAlgParams, ProgramParameters& parameters, std::vector<OutputAssoc>& outAssociation, bool debug);
-        void provenanceBeforeOperation(const std::vector<OutputAssoc>& outAssociation);
-        void provenanceAfterOperation(const std::vector<OutputAssoc>& outAssociation);
-        void makeOnDiskOutputs(const std::vector<OutputAssoc>& outAssociation);//ensures on-disk inputs aren't used as on-disk outputs, keeping outputs in-memory when needed
+        void provenanceAfterOperation(const std::vector<OutputAssoc>& outAssociation, ProvenanceHelper& provHelp);
+        void checkOnDiskOutputCollision(const std::vector<OutputAssoc>& outAssociation);//ensures on-disk inputs aren't used as on-disk outputs, keeping outputs in-memory when needed
         void writeOutput(const std::vector<OutputAssoc>& outAssociation);
         AString getIndentString(int desired);
         void addHelpComponent(AString& info, ParameterComponent* myComponent, int curIndent);
@@ -74,14 +73,11 @@ namespace caret {
     public:
         CommandParser(AutoOperationInterface* myAutoOper);
         void disableProvenance();
-        void setCiftiOutputDTypeAndScale(const int16_t& dtype, const double& minVal, const double& maxVal);
-        void setCiftiOutputDTypeNoScale(const int16_t& dtype);
-        void setVolumeOutputDTypeAndScale(const int16_t& dtype, const double& minVal, const double& maxVal);
-        void setVolumeOutputDTypeNoScale(const int16_t& dtype);
         void executeOperation(ProgramParameters& parameters);
         void showParsedOperation(ProgramParameters& parameters);
         AString doCompletion(ProgramParameters& parameters, const bool& useExtGlob);
         AString getHelpInformation(const AString& programName);
+        std::vector<AString> getCompatibilitySwitches() const;
         bool takesParameters();
     };
 
