@@ -68,6 +68,8 @@ namespace caret {
         
         QVariant getPreferenceValue() const;
         
+        QVariant getSceneValue() const;
+        
         QVariant getValue(/*const ValueType valueType*/) const;
         
         void setValue(const QVariant& value);
@@ -78,6 +80,10 @@ namespace caret {
 
         bool isSavedToScenes() const;
         
+        bool isPreferenceValueActive() const;
+        
+        bool isSceneValueActive() const;
+        
         // ADD_NEW_METHODS_HERE
 
     private:
