@@ -41,6 +41,7 @@
 
 #include "CaretAssert.h"
 #include "CaretLogger.h"
+#include "Plane.h"
 
 using namespace caret;
 using namespace std;
@@ -1772,6 +1773,80 @@ MathFunctions::distanceToLine3D(
     return dist;
 }
 
+/**
+ * Find the the point 'pointOnLineOut' nearest to 'point' that  is on the line formed  by p1 and p2.
+ * p1 and p2 are points on the line and the line is assumed to extend infinitely.
+ *
+ * @param p1 - First coordinate in line.
+ * @param p2 - Second coordinate in line.
+ * @param point - coordinate for which distance to line is sought.
+ * @param pointOnLineOut - Point on line nearest to 'point'.
+ * @param p1ToPointOnLineNormalizedDistanceOut - 'Normalized' distance from 'p1' to to 'pointOnLineOut'
+ * @param distanceFromPointToPointOnLine - Distance from 'point' to 'pointOnLineOut'
+ * @return Distance from point to the line (p1, p2).
+ *
+ */
+void
+MathFunctions::nearestPointOnLine3D(const float p1[3],
+                                    const float p2[3],
+                                    const float point[3],
+                                    float pointOnLineOut[3],
+                                    float& p1ToPointOnLineNormalizedDistanceOut,
+                                    float& distanceFromPointToPointOnLine)
+{
+    /*
+     * Distance of 'point' to the line (one leg of triangle)
+     */
+    const float legOneLength(distanceToLine3D(p1, p2, point));
+    
+    /*
+     * Distance of 'point' to 'p1' (the hypotnuse)
+     */
+    const float hypotnuseLength(MathFunctions::distance3D(point, p1));
+    
+    /*
+     * A triangle is formed by 'point', 'p1', and the nearest
+     * point on the line.  The hypotnuse is 'p1' to 'point' and
+     * we know that distance.  We know the distance of the leg
+     * formed by 'point' and 'nearest point on line'.  The other
+     * leg is from 'p1' to 'nearest point on line' and we will
+     * now calculate it.
+     *
+     * hypotnuse = sqrt(legOne*legOne + legTwo*legTwo)
+     */
+    const float squaredLegLength((hypotnuseLength * hypotnuseLength)
+                                 - (legOneLength * legOneLength));
+    const float legTwoLength(squaredLegLength > 0.0
+                             ? std::sqrt(squaredLegLength)
+                             : 0.0f);
+    
+    /*
+     * legTwoLength is distance from p1 to nearest point on line
+     * Use it with length of line to find the normalized distance
+     * from 'p1' to the 'nearest point on the line'
+     */
+    const float lineLength(MathFunctions::distance3D(p1, p2));
+    const float normalizedDistance(legTwoLength / lineLength);
+    
+    /*
+     * Vector 'p1' to 'p2'
+     */
+    float p1ToP2Vector[3];
+    MathFunctions::subtractVectors(p2, p1, p1ToP2Vector);
+    
+    /*
+     * Point on the line !
+     */
+    pointOnLineOut[0] = p1[0] + p1ToP2Vector[0] * normalizedDistance;
+    pointOnLineOut[1] = p1[1] + p1ToP2Vector[1] * normalizedDistance;
+    pointOnLineOut[2] = p1[2] + p1ToP2Vector[2] * normalizedDistance;
+    
+    p1ToPointOnLineNormalizedDistanceOut = normalizedDistance;
+    
+    distanceFromPointToPointOnLine = MathFunctions::distance3D(point,
+                                                               pointOnLineOut);
+}
+
 /**
  * Determine if two arrays are equal, same number of elements and
  * corresponding elements equal.
@@ -2735,3 +2810,79 @@ MathFunctions::compareValuesEqual(const float* data,
     return true;
 }
 
+/**
+ * @return Area of a 2D polygon computed using the "Shoelace Formula".
+ * The polygon may be concave.
+ * https://en.wikipedia.org/wiki/Shoelace_formula
+ * @param xy
+ *    The XY-coordinates
+ */
+float
+MathFunctions::polygonArea(const std::vector<Vector3D>& xy)
+{
+    double area2(0.0);
+    const int32_t num(xy.size());
+    if (num >= 3) {
+        for (int32_t i = 0; i < num; i++) {
+            const int32_t iNext((i == (num - 1))
+                                ? 0
+                                : i + 1);
+            CaretAssertVectorIndex(xy, i);
+            CaretAssertVectorIndex(xy, iNext);
+            const Vector3D& xyOne = xy[i];
+            const Vector3D& xyTwo = xy[iNext];
+            
+            /*
+             * Note: Determinate is double the signed area
+             */
+            const double det((xyOne[0] * xyTwo[1])
+                           - (xyOne[1] * xyTwo[0]));
+            area2 += det;
+        }
+    }
+    else {
+        CaretLogSevere("Polygon contains fewer than three vertices="
+                       + AString::number(num));
+    }
+    
+    /*
+     * Note: Area will be negative if polygons are clockwise-oriented
+     * so always use positive area
+     */
+    const float area(std::fabs(area2 / 2.0));
+    
+    return area;
+}
+
+/**
+ * @return True if the given points are coplanar.
+ * @param xyz
+ *    The points
+ * Note: If there are three or fewer points, true is always returned.
+ */
+bool
+MathFunctions::arePointsCoplanar(const std::vector<Vector3D>& xyz)
+{
+    const int32_t numPoints(xyz.size());
+    if (numPoints <= 3) {
+        return true;
+    }
+    
+    CaretAssertVectorIndex(xyz, 2);
+    Plane plane(xyz[0],
+                xyz[1],
+                xyz[2]);
+    
+    if (plane.isValidPlane()) {
+        const float tolerance(0.01);
+        for (int32_t i = 3; i < numPoints; i++) {
+            CaretAssertVectorIndex(xyz, i);
+            if (plane.absoluteDistanceToPlane(xyz[i]) > tolerance) {
+                return false;
+            }
+        }
+    }
+    
+    return true;
+}
+
