@@ -38,7 +38,7 @@
 
 
 #include "CaretObject.h"
-
+#include "Vector3D.h"
 
 #include <stdint.h>
 
@@ -292,6 +292,13 @@ public:
                     const float p2[3],
                     const float point[3]);
 
+    static void nearestPointOnLine3D(const float p1[3],
+                                     const float p2[3],
+                                     const float point[3],
+                                     float pointOnLineOut[3],
+                                     float& p1ToPointOnLineNormalizedDistanceOut,
+                                     float& distanceFromPointToPointOnLine);
+    
     static bool arraysEqual(
                     const float a[],
                     const float b[],
@@ -438,6 +445,10 @@ public:
                                    double v[3],
                                    const double extraSpacePixels);
     
+    static float polygonArea(const std::vector<Vector3D>& xy);
+    
+    static bool arePointsCoplanar(const std::vector<Vector3D>& xyz);
+    
 };
 
 } // namespace
