@@ -50,6 +50,8 @@
 #include "EventManager.h"
 #include "EventTileTabsGridConfigurationModification.h"
 #include "GiftiMetaData.h"
+#include "GiftiMetaDataXmlElements.h"
+#include "HistologySpaceKey.h"
 #include "SceneClass.h"
 #include "SceneClassAssistant.h"
 
@@ -67,13 +69,9 @@ using namespace caret;
  * Constructor for annotation file that saves annotations to a file.
  */
 AnnotationFile::AnnotationFile()
-: CaretDataFile(DataFileTypeEnum::ANNOTATION),
-EventListenerInterface(),
- DataFileContentCopyMoveInterface(),
- DisplayGroupAndTabItemInterface(),
-m_fileSubType(ANNOTATION_FILE_SAVE_TO_FILE)
+: AnnotationFile(DataFileTypeEnum::ANNOTATION,
+                 ANNOTATION_FILE_SAVE_TO_FILE)
 {
-    initializeAnnotationFile();
 }
 
 /**
@@ -87,9 +85,35 @@ m_fileSubType(ANNOTATION_FILE_SAVE_TO_FILE)
  *     Type of saving of annotations.
  */
 AnnotationFile::AnnotationFile(const AnnotationFileSubType fileSubType)
-: CaretDataFile(DataFileTypeEnum::ANNOTATION),
+: AnnotationFile(DataFileTypeEnum::ANNOTATION,
+                 fileSubType)
+{
+}
+
+/**
+ * Constructor for annotation file used by other constructors and subclasses.
+ * @param dataFileType
+ *    Type of data file
+ * @param fileSubType
+ *     Type of saving of annotations.
+ */
+AnnotationFile::AnnotationFile(const DataFileTypeEnum::Enum dataFileType,
+                               const AnnotationFileSubType fileSubType)
+: CaretDataFile(dataFileType),
+EventListenerInterface(),
+DataFileContentCopyMoveInterface(),
+DisplayGroupAndTabItemInterface(),
 m_fileSubType(fileSubType)
 {
+    switch (dataFileType) {
+        case DataFileTypeEnum::ANNOTATION:
+        case DataFileTypeEnum::SAMPLES:
+            break;
+        default:
+            CaretAssertMessage(0, "Data File Type is neither ANNOTATION nor SAMPLE");
+            break;
+    }
+    
     initializeAnnotationFile();
 }
 
@@ -136,6 +160,8 @@ AnnotationFile::clear()
             break;
         case ANNOTATION_FILE_DUMMY_FOR_DRAWING:
             break;
+        case SAMPLES_FILE_SAVE_TO_FILE:
+            break;
     }
 }
 
@@ -252,9 +278,17 @@ AnnotationFile::getSpaceAnnotationGroup(const Annotation* annotation)
     SpacerTabIndex annotationSpacerTabIndex;
     
     int32_t annotationTabOrWindowIndex = -1;
+    AString annotationMediaFileName;
+    HistologySpaceKey histologySpaceKey;
     switch (annotationSpace) {
         case AnnotationCoordinateSpaceEnum::CHART:
             break;
+        case AnnotationCoordinateSpaceEnum::HISTOLOGY:
+            histologySpaceKey = annotation->getCoordinate(0)->getHistologySpaceKey();
+            break;
+        case AnnotationCoordinateSpaceEnum::MEDIA_FILE_NAME_AND_PIXEL:
+            annotationMediaFileName = annotation->getCoordinate(0)->getMediaFileName();
+            break;
         case AnnotationCoordinateSpaceEnum::SPACER:
             annotationSpacerTabIndex = annotation->getSpacerTabIndex();
             break;
@@ -284,6 +318,16 @@ AnnotationFile::getSpaceAnnotationGroup(const Annotation* annotation)
                     case AnnotationCoordinateSpaceEnum::SURFACE:
                         return group;
                         break;
+                    case AnnotationCoordinateSpaceEnum::HISTOLOGY:
+                        if (histologySpaceKey == group->getHistologySpaceKey()) {
+                            return group;
+                        }
+                        break;
+                    case AnnotationCoordinateSpaceEnum::MEDIA_FILE_NAME_AND_PIXEL:
+                        if (annotationMediaFileName == group->getMediaFileName()) {
+                            return group;
+                        }
+                        break;
                     case AnnotationCoordinateSpaceEnum::SPACER:
                         if (annotationSpacerTabIndex == group->getSpacerTabIndex()) {
                             return group;
@@ -312,6 +356,10 @@ AnnotationFile::getSpaceAnnotationGroup(const Annotation* annotation)
             CaretAssert((annotationTabOrWindowIndex >= 0)
                         && (annotationTabOrWindowIndex < BrainConstants::MAXIMUM_NUMBER_OF_BROWSER_TABS));
             break;
+        case AnnotationCoordinateSpaceEnum::HISTOLOGY:
+            break;
+        case AnnotationCoordinateSpaceEnum::MEDIA_FILE_NAME_AND_PIXEL:
+            break;
         case AnnotationCoordinateSpaceEnum::SPACER:
             break;
         case AnnotationCoordinateSpaceEnum::VIEWPORT:
@@ -328,7 +376,9 @@ AnnotationFile::getSpaceAnnotationGroup(const Annotation* annotation)
                                                  generateUniqueKey(),
                                                  annotationSpace,
                                                  annotationTabOrWindowIndex,
-                                                 annotationSpacerTabIndex);
+                                                 annotationSpacerTabIndex,
+                                                 annotationMediaFileName,
+                                                 histologySpaceKey);
     group->setItemParent(this);
     m_annotationGroups.push_back(QSharedPointer<AnnotationGroup>(group));
     
@@ -369,6 +419,8 @@ AnnotationFile::receiveEvent(Event* event)
              */
             return;
             break;
+        case SAMPLES_FILE_SAVE_TO_FILE:
+            break;
     }
     
     if (event->getEventType() == EventTypeEnum::EVENT_ANNOTATION_ADD_TO_REMOVE_FROM_FILE) {
@@ -618,6 +670,12 @@ void
 AnnotationFile::addAnnotationPrivate(Annotation* annotation,
                                      const int32_t uniqueKey)
 {
+    AString message;
+    const bool validFlag(annotation->validate(message));
+    if ( ! validFlag) {
+        CaretLogSevere(message);
+    }
+    
     if (annotation->getType() == AnnotationTypeEnum::TEXT) {
         AnnotationPointSizeText* pointSizeAnnotation = dynamic_cast<AnnotationPointSizeText*>(annotation);
         if (pointSizeAnnotation != NULL) {
@@ -697,6 +755,12 @@ AnnotationFile::addAnnotationDuringFileVersionOneReading(Annotation* annotation)
  *     Coordinate space of the group's annotaitons.
  * @param tabOrWindowIndex
  *     Tab or window index for groups in tab or window space.
+ * @param spacerTabIndex
+ *     Index of spacer tab
+ * @param mediaFileName
+ *     Name of media file
+ * @param histologySpaceKey
+ *    The histology space key
  * @param uniqueKey
  *     Unique key for the annotation group.
  * @param annotations
@@ -709,6 +773,8 @@ AnnotationFile::addAnnotationGroupDuringFileReading(const AnnotationGroupTypeEnu
                                                     const AnnotationCoordinateSpaceEnum::Enum coordinateSpace,
                                                     const int32_t tabOrWindowIndex,
                                                     const SpacerTabIndex& spacerTabIndex,
+                                                    const AString& mediaFileName,
+                                                    const HistologySpaceKey& histologySpaceKey,
                                                     const int32_t uniqueKey,
                                                     const std::vector<Annotation*>& annotations)
 {
@@ -725,6 +791,13 @@ AnnotationFile::addAnnotationGroupDuringFileReading(const AnnotationGroupTypeEnu
     switch (coordinateSpace) {
         case AnnotationCoordinateSpaceEnum::CHART:
             break;
+        case AnnotationCoordinateSpaceEnum::HISTOLOGY:
+            break;
+        case AnnotationCoordinateSpaceEnum::MEDIA_FILE_NAME_AND_PIXEL:
+            if (mediaFileName.isEmpty()) {
+                throw DataFileException("Media file name is empty and not allowed for annotation group while reading annotation file.");
+            }
+            break;
         case AnnotationCoordinateSpaceEnum::SPACER:
             if ( ! spacerTabIndex.isValid()) {
                 throw DataFileException("Invalid spacer tab index for group while reading annotation file: "
@@ -784,6 +857,24 @@ AnnotationFile::addAnnotationGroupDuringFileReading(const AnnotationGroupTypeEnu
                                                     + AnnotationCoordinateSpaceEnum::toGuiName(coordinateSpace)
                                                     + ".  Only one space group for each space is allowed.");
                             break;
+                        case AnnotationCoordinateSpaceEnum::HISTOLOGY:
+                            if (histologySpaceKey == group->getHistologySpaceKey()) {
+                                throw DataFileException("There is more than one annotation space group with space "
+                                                        + AnnotationCoordinateSpaceEnum::toGuiName(coordinateSpace)
+                                                        + " with histology space key "
+                                                        + histologySpaceKey.toString()
+                                                        + ".  Only one space group for each space is allowed.");
+                            }
+                            break;
+                        case AnnotationCoordinateSpaceEnum::MEDIA_FILE_NAME_AND_PIXEL:
+                            if (mediaFileName == group->getMediaFileName()) {
+                                throw DataFileException("There is more than one annotation space group with space "
+                                                        + AnnotationCoordinateSpaceEnum::toGuiName(coordinateSpace)
+                                                        + " with media file "
+                                                        + mediaFileName
+                                                        + ".  Only one space group for each space is allowed.");
+                            }
+                            break;
                         case AnnotationCoordinateSpaceEnum::SPACER:
                             if (spacerTabIndex == group->getSpacerTabIndex()) {
                                 throw DataFileException("There is more than one annotation space group with space "
@@ -825,7 +916,9 @@ AnnotationFile::addAnnotationGroupDuringFileReading(const AnnotationGroupTypeEnu
                                                  uniqueKey,
                                                  coordinateSpace,
                                                  tabOrWindowIndex,
-                                                 spacerTabIndex);
+                                                 spacerTabIndex,
+                                                 mediaFileName,
+                                                 histologySpaceKey);
     for (std::vector<Annotation*>::const_iterator annIter = annotations.begin();
          annIter != annotations.end();
          annIter++) {
@@ -948,6 +1041,12 @@ AnnotationFile::removeAnnotationPrivate(Annotation* annotation,
                 m_annotationGroups.erase(groupIter);
             }
             
+            removedAnnotationPointer->setDeselectedForEditing();
+            AnnotationPolyhedron* polyhedron(removedAnnotationPointer->castToPolyhedron());
+            if (polyhedron != NULL) {
+                Annotation::unlockPolyhedronInAnyWindow(polyhedron);
+            }
+            
             setModified();
             return true;
         }
@@ -995,6 +1094,8 @@ AnnotationFile::cloneAnnotationsFromTabToTab(const int32_t fromTabIndex,
             case AnnotationCoordinateSpaceEnum::SPACER:
                 break;
             case AnnotationCoordinateSpaceEnum::CHART:
+            case AnnotationCoordinateSpaceEnum::HISTOLOGY:
+            case AnnotationCoordinateSpaceEnum::MEDIA_FILE_NAME_AND_PIXEL:
             case AnnotationCoordinateSpaceEnum::STEREOTAXIC:
             case AnnotationCoordinateSpaceEnum::SURFACE:
                 group->copySelections(fromTabIndex,
@@ -1292,7 +1393,9 @@ AnnotationFile::processGroupingAnnotations(EventAnnotationGrouping* groupingEven
                                                  generateUniqueKey(),
                                                  spaceGroup->getCoordinateSpace(),
                                                  spaceGroup->getTabOrWindowIndex(),
-                                                 spaceGroup->getSpacerTabIndex());
+                                                 spaceGroup->getSpacerTabIndex(),
+                                                 spaceGroup->getMediaFileName(),
+                                                 spaceGroup->getHistologySpaceKey());
     
     for (std::vector<QSharedPointer<Annotation> >::iterator annPtrIter = movedAnnotations.begin();
          annPtrIter != movedAnnotations.end();
@@ -1445,7 +1548,9 @@ AnnotationFile::processRegroupingAnnotations(EventAnnotationGrouping* groupingEv
                                                          reuseUniqueKeyOrGenerateNewUniqueKey(userGroupUniqueKey),
                                                          spaceGroup->getCoordinateSpace(),
                                                          spaceGroup->getTabOrWindowIndex(),
-                                                         spaceGroup->getSpacerTabIndex());
+                                                         spaceGroup->getSpacerTabIndex(),
+                                                         spaceGroup->getMediaFileName(),
+                                                         spaceGroup->getHistologySpaceKey());
             
             bool allValidFlag = true;
             std::vector<QSharedPointer<Annotation> > movedAnnotations;
@@ -1707,6 +1812,7 @@ AnnotationFile::updateUniqueKeysAfterReadingFile()
     m_uniqueKeyGenerator = maximumKeyFound;
 }
 
+
 /**
  * Read the data file.
  *
@@ -1744,18 +1850,20 @@ AnnotationFile::readFile(const AString& filename)
 void
 AnnotationFile::writeFile(const AString& filename)
 {
-    /*
-     * JWH, 11 Sep 2019
-     * WB-866 removed the ".annot" extension for the annotation file.
-     * It is possible that a user may have a disk annotation file in
-     * multiple scenes.  If this message caused the user to change
-     * the file extension from ".annot" to ".wb_annot", it could break
-     * other scenes if they are not updated.
-     * So, continue avoiding a log message if ".annot" extension is present.
-     */
-    if (!(filename.endsWith(".annot") || filename.endsWith(".wb_annot")))
-    {
-        CaretLogWarning("annotation file '" + filename + "' should be saved ending in .annot");
+    if (getDataFileType() != DataFileTypeEnum::SAMPLES) {
+        /*
+         * JWH, 11 Sep 2019
+         * WB-866 removed the ".annot" extension for the annotation file.
+         * It is possible that a user may have a disk annotation file in
+         * multiple scenes.  If this message caused the user to change
+         * the file extension from ".annot" to ".wb_annot", it could break
+         * other scenes if they are not updated.
+         * So, continue avoiding a log message if ".annot" extension is present.
+         */
+        if (!(filename.endsWith(".annot") || filename.endsWith(".wb_annot")))
+        {
+            CaretLogWarning("annotation file '" + filename + "' should be saved ending in .annot");
+        }
     }
     checkFileWritability(filename);
     
@@ -1795,6 +1903,7 @@ AnnotationFile::saveFileDataToScene(const SceneAttributes* sceneAttributes,
                     AnnotationFileXmlWriter writer;
                     QString fileContentInString;
                     writer.writeFileToString(this,
+                                             sceneAttributes->getSceneFileName(),
                                              fileContentInString);
                     sceneClass->addString("AnnotationFileContent",
                                           fileContentInString);
@@ -1806,6 +1915,8 @@ AnnotationFile::saveFileDataToScene(const SceneAttributes* sceneAttributes,
             break;
         case ANNOTATION_FILE_DUMMY_FOR_DRAWING:
             break;
+        case SAMPLES_FILE_SAVE_TO_FILE:
+            break;
     }
     
     /*
@@ -1851,6 +1962,7 @@ AnnotationFile::restoreFileDataFromScene(const SceneAttributes* sceneAttributes,
                 try {
                     AnnotationFileXmlReader reader;
                     reader.readFileFromString(fileContentInString,
+                                              sceneAttributes->getSceneFileName(),
                                               this);
                     updateUniqueKeysAfterReadingFile();
                     clearModified();
@@ -1863,6 +1975,8 @@ AnnotationFile::restoreFileDataFromScene(const SceneAttributes* sceneAttributes,
             break;
         case ANNOTATION_FILE_DUMMY_FOR_DRAWING:
             break;
+        case SAMPLES_FILE_SAVE_TO_FILE:
+            break;
     }
     
     /*
@@ -1975,7 +2089,9 @@ AnnotationFile::appendContentFromDataFile(const DataFileContentCopyMoveParameter
                                                 generateUniqueKey(),
                                                 groupToCopy->getCoordinateSpace(),
                                                 groupToCopy->getTabOrWindowIndex(),
-                                                groupToCopy->getSpacerTabIndex());
+                                                groupToCopy->getSpacerTabIndex(),
+                                                groupToCopy->getMediaFileName(),
+                                                groupToCopy->getHistologySpaceKey());
                     group->setItemParent(this);
                     m_annotationGroups.push_back(QSharedPointer<AnnotationGroup>(group));
                     break;
