@@ -103,6 +103,9 @@ CiftiMappableConnectivityMatrixDataFile::clearPrivate()
     if (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC) {
         m_chartLoadingDimension = ChartMatrixLoadingDimensionEnum::CHART_MATRIX_LOADING_BY_COLUMN;
     }
+    if (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_PARCEL_DYNAMIC) {
+        m_chartLoadingDimension = ChartMatrixLoadingDimensionEnum::CHART_MATRIX_LOADING_BY_COLUMN;
+    }
 }
 
 /**
@@ -340,34 +343,33 @@ CiftiMappableConnectivityMatrixDataFile::getRowColumnIndicesForNodesWhenLoading(
  *     Indices of the row.
  * @param columnIndices
  *     Indices of the column.
- * @param rowAverageOut
- *     Average values for rows.
- * @param columnAverageOut
- *     Average value for columns.
+ * @param dataAverageOut
+ *     Average values for data.
+ * @return True if data was loaded, else false.
  */
-void
+bool
 CiftiMappableConnectivityMatrixDataFile::getRowColumnAverageForIndices(const std::vector<int64_t>& rowIndices,
                                                                        const std::vector<int64_t>& columnIndices,
-                                                                       std::vector<float>& rowAverageOut,
-                                                                       std::vector<float>& columnAverageOut)
+                                                                       std::vector<float>& dataAverageOut)
 {
-    columnAverageOut.clear();
-    rowAverageOut.clear();
+    std::fill(dataAverageOut.begin(),
+              dataAverageOut.end(),
+              0.0);
     
-    int64_t dataLength = 0;
+    const int64_t dataLength(dataAverageOut.size());
     std::vector<int64_t> indices;
     
     bool doRowsFlag = false;
     if (! rowIndices.empty()) {
-        dataLength = m_ciftiFile->getNumberOfColumns();
         indices    = rowIndices;
         doRowsFlag = true;
     }
     else if ( ! columnIndices.empty()) {
-        dataLength = m_ciftiFile->getNumberOfRows();
         indices    = columnIndices;
     }
     
+    bool dataWasLoadedFlag(false);
+    
     const int64_t numIndices = static_cast<int64_t>(indices.size());
     if (numIndices > 0) {
         std::vector<double> sum(dataLength, 0.0);
@@ -377,10 +379,10 @@ CiftiMappableConnectivityMatrixDataFile::getRowColumnAverageForIndices(const std
              iter != indices.end();
              iter++) {
             if (doRowsFlag) {
-                getDataForRow(&data[0], *iter);
+                getProcessedDataForRow(data, *iter);
             }
             else {
-                getDataForColumn(&data[0], *iter);
+                getProcessedDataForColumn(&data[0], *iter);
             }
             
             for (int64_t i = 0; i < dataLength; i++) {
@@ -389,23 +391,19 @@ CiftiMappableConnectivityMatrixDataFile::getRowColumnAverageForIndices(const std
                 sum[i] += data[i];
             }
         }
-
-        CaretAssert(dataLength > 0);
+        
         std::vector<float> average(dataLength);
-        const float floatNumIndices = numIndices; //dataLength;
+        const float floatNumIndices = numIndices;
         for (int64_t i = 0; i < dataLength; i++) {
-            CaretAssertVectorIndex(average, i);
             CaretAssertVectorIndex(sum, i);
-            average[i] = sum[i] / floatNumIndices;
-        }
-
-        if (doRowsFlag) {
-            rowAverageOut = average;
-        }
-        else {
-            columnAverageOut = average;
+            CaretAssertVectorIndex(dataAverageOut, i);
+            dataAverageOut[i] = sum[i] / floatNumIndices;
         }
+        
+        dataWasLoadedFlag = true;
     }
+    
+    return dataWasLoadedFlag;
 }
 
 /**
@@ -462,7 +460,8 @@ CiftiMappableConnectivityMatrixDataFile::getRowColumnIndexForVoxelAtCoordinateWh
     }
     
     int64_t ijk[3];
-    if (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC) {
+    if ((getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC)
+        || (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_PARCEL_DYNAMIC)) {
         enclosingVoxel(xyz[0], xyz[1], xyz[2], ijk[0], ijk[1], ijk[2]);
     }
     else {
@@ -509,7 +508,8 @@ CiftiMappableConnectivityMatrixDataFile::getRowColumnIndexForVoxelIndexWhenLoadi
     /*
      * Get the mapping type
      */
-    const bool indexValidFlag = ((getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC)
+    const bool indexValidFlag = (((getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC)
+                                  || (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_PARCEL_DYNAMIC))
                                  ? indexValid(ijk[0], ijk[1], ijk[2])
                                  : indexValidForDataLoading(ijk[0], ijk[1], ijk[2]));
     if (indexValidFlag) {
@@ -630,9 +630,9 @@ CiftiMappableConnectivityMatrixDataFile::getProcessedDataForColumn(float* dataOu
  * @param index of the row.
  */
 void
-CiftiMappableConnectivityMatrixDataFile::getProcessedDataForRow(float* dataOut, const int64_t& index) const
+CiftiMappableConnectivityMatrixDataFile::getProcessedDataForRow(std::vector<float>& dataOut, const int64_t& index) const
 {
-    m_ciftiFile->getRow(dataOut,
+    m_ciftiFile->getRow(&dataOut[0],
                         index);
 }
 
@@ -679,7 +679,7 @@ CiftiMappableConnectivityMatrixDataFile::loadDataForRowIndex(const int64_t rowIn
             CaretAssert((rowIndex >= 0) && (rowIndex < m_ciftiFile->getNumberOfRows()));
             m_loadedRowData.resize(dataCount);
             
-            getProcessedDataForRow(&m_loadedRowData[0],
+            getProcessedDataForRow(m_loadedRowData,
                                    rowIndex);
             
             CaretLogFine("Read row " + AString::number(rowIndex + CIFTI_FILE_ROW_COLUMN_INDEX_BASE_FOR_GUI));
@@ -804,7 +804,8 @@ CiftiMappableConnectivityMatrixDataFile::loadMapDataForSurfaceNode(const int32_t
         
         if (rowIndex >= 0) {
             int64_t dataCount = m_ciftiFile->getNumberOfColumns();
-            if (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC) {
+            if ((getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC)
+                || (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_PARCEL_DYNAMIC)) {
                 /* 
                  * Dense dynamic is special case where number of rows equals number of brainordinates.
                  * Number of columns is number of time points
@@ -828,8 +829,8 @@ CiftiMappableConnectivityMatrixDataFile::loadMapDataForSurfaceNode(const int32_t
                                    + StructureEnum::toGuiName(structure));
                 CaretAssert((rowIndex >= 0) && (rowIndex < m_ciftiFile->getNumberOfRows()));
                 m_loadedRowData.resize(dataCount);
-                getProcessedDataForRow(&m_loadedRowData[0],
-                                    rowIndex);
+                getProcessedDataForRow(m_loadedRowData,
+                                       rowIndex);
                 
                 CaretLogFine("Read row for vertex " + AString::number(nodeIndex));
                 
@@ -883,7 +884,7 @@ CiftiMappableConnectivityMatrixDataFile::loadMapDataForSurfaceNode(const int32_t
     }
     catch (DataFileException& e) {
         m_connectivityDataLoaded->reset();
-        throw e;
+        throw DataFileException(getFileNameNoPath() + ": " + e.whatString());
     }
     
     updateForChangeInMapDataWithMapIndex(0);
@@ -950,32 +951,33 @@ CiftiMappableConnectivityMatrixDataFile::loadMapAverageDataForSurfaceNodes(const
                                            nodeIndices,
                                            rowIndices,
                                            columnIndices);
-    if (rowIndices.empty()
-        && columnIndices.empty()) {
-        return;
+
+    int64_t dataCount = m_ciftiFile->getNumberOfColumns();
+    if ((getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC)
+        || (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_PARCEL_DYNAMIC)) {
+        /*
+         * Dense dynamic is special case where number of rows equals number of brainordinates.
+         * Number of columns is number of time points
+         */
+        dataCount = m_ciftiFile->getNumberOfRows();
     }
+
+    m_loadedRowData.resize(dataCount);
     
-    std::vector<float> rowAverage, columnAverage;
-    getRowColumnAverageForIndices(rowIndices,
-                                  columnIndices,
-                                  rowAverage,
-                                  columnAverage);
+    std::vector<float> dataAverage(m_loadedRowData.size());
+    const bool dataWasLoadedFlag(getRowColumnAverageForIndices(rowIndices,
+                                                               columnIndices,
+                                                               dataAverage));
 
     /*
      * Update the viewed data
      */
-    bool dataWasLoaded = false;
-    if ( ! rowAverage.empty()) {
-        processRowAverageData(rowAverage);
-        m_loadedRowData = rowAverage;
-        dataWasLoaded = true;
+    if (dataWasLoadedFlag) {
+        processRowAverageData(dataAverage);
+        m_loadedRowData = dataAverage;
     }
-    else if ( ! columnAverage.empty()) {
-        m_loadedRowData = columnAverage;
-        dataWasLoaded = true;
-    }
-    
-    if (dataWasLoaded) {
+        
+    if (dataWasLoadedFlag) {
         m_rowLoadedTextForMapName = ("Structure: "
                                      + StructureEnum::toName(structure)
                                      + ", Averaged Vertex Count: "
@@ -986,13 +988,13 @@ CiftiMappableConnectivityMatrixDataFile::loadMapAverageDataForSurfaceNodes(const
                             + AString::number(numberOfNodeIndices));
     }
     
-    if (dataWasLoaded == false) {
+    if ( ! dataWasLoadedFlag) {
         CaretLogFine("FAILED to read data for vertex average" + AString::fromNumbers(nodeIndices, ","));
     }
 
     updateForChangeInMapDataWithMapIndex(0);
 
-    if (dataWasLoaded) {
+    if (dataWasLoadedFlag) {
         m_connectivityDataLoaded->setSurfaceAverageNodeLoading(structure,
                                                                 surfaceNumberOfNodes,
                                                                 nodeIndices);
@@ -1058,7 +1060,8 @@ CiftiMappableConnectivityMatrixDataFile::loadMapDataForVoxelAtCoordinate(const i
     
     if (rowIndex >= 0) {
         int64_t dataCount = m_ciftiFile->getNumberOfColumns();
-        if (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC) {
+        if ((getDataFileType() == DataFileTypeEnum::CONNECTIVITY_DENSE_DYNAMIC)
+            || (getDataFileType() == DataFileTypeEnum::CONNECTIVITY_PARCEL_DYNAMIC)) {
             /*
              * Dense dynamic is special case where number of rows equals number of brainordinates.
              * Number of columns is number of time points
@@ -1068,7 +1071,7 @@ CiftiMappableConnectivityMatrixDataFile::loadMapDataForVoxelAtCoordinate(const i
         if (dataCount > 0) {
             m_loadedRowData.resize(dataCount);
             CaretAssert((rowIndex >= 0) && (rowIndex < m_ciftiFile->getNumberOfRows()));
-            getProcessedDataForRow(&m_loadedRowData[0],
+            getProcessedDataForRow(m_loadedRowData,
                                    rowIndex);
             
             m_rowLoadedTextForMapName = ("Row: "
@@ -1232,31 +1235,17 @@ CiftiMappableConnectivityMatrixDataFile::loadMapAverageDataForVoxelIndices(const
         return false;
     }
 
-    std::vector<float> rowAverage, columnAverage;
-    getRowColumnAverageForIndices(rowIndices,
-                                  columnIndices,
-                                  rowAverage,
-                                  columnAverage);
-    
-    bool dataWasLoadedFlag = false;
-    if ( ! rowAverage.empty()) {
-        processRowAverageData(rowAverage);
-        m_loadedRowData = rowAverage;
-        dataWasLoadedFlag = true;
+    std::vector<float> dataAverage(m_loadedRowData.size());
+    const bool dataWasLoadedFlag(getRowColumnAverageForIndices(rowIndices,
+                                                               columnIndices,
+                                                               dataAverage));
+
+    if (dataWasLoadedFlag) {
+        processRowAverageData(dataAverage);
+        m_loadedRowData = dataAverage;
     }
-    else if ( ! columnAverage.empty()) {
-        m_loadedRowData = columnAverage;
-        dataWasLoadedFlag = true;
-    }
-//    if (userCancelled) {
-//        m_loadedRowData.clear();
-//        m_loadedRowData.resize(dataCount, 0.0);
-//    }
+
     if (dataWasLoadedFlag) {
-//        progressEvent.setProgress(numberOfVoxelIndices - 1,
-//                                  "Averaging voxel data");
-//        EventManager::get()->sendEvent(progressEvent.getPointer());
-        
         const int32_t numberOfVoxelIndices = static_cast<int32_t>(voxelIndices.size());
         m_rowLoadedTextForMapName = ("Averaged Voxel Count: "
                                      + AString::number(numberOfVoxelIndices));
@@ -1382,7 +1371,7 @@ CiftiMappableConnectivityMatrixDataFile::setChartMatrixLoadingDimension(const Ch
             m_dataMappingAccessMethod      = DATA_ACCESS_FILE_COLUMNS_OR_XML_ALONG_ROW;
             break;
     }
-    
+
     initializeAfterReading(getFileName());
     
     resetLoadedRowDataToEmpty();
@@ -1467,87 +1456,92 @@ CiftiMappableConnectivityMatrixDataFile::restoreFileDataFromScene(const SceneAtt
     
     setMapDataLoadingEnabled(mapIndex, true);
     
-    switch (m_connectivityDataLoaded->getMode()) {
-        case ConnectivityDataLoaded::MODE_NONE:
-            setLoadedRowDataToAllZeros();
-            break;
-        case ConnectivityDataLoaded::MODE_ROW:
-        {
-            int64_t rowIndex;
-            int64_t columnIndex;
-            m_connectivityDataLoaded->getRowColumnLoading(rowIndex,
-                                                          columnIndex);
-            loadDataForRowIndex(rowIndex);
+    try {
+        switch (m_connectivityDataLoaded->getMode()) {
+            case ConnectivityDataLoaded::MODE_NONE:
+                setLoadedRowDataToAllZeros();
+                break;
+            case ConnectivityDataLoaded::MODE_ROW:
+            {
+                int64_t rowIndex;
+                int64_t columnIndex;
+                m_connectivityDataLoaded->getRowColumnLoading(rowIndex,
+                                                              columnIndex);
+                loadDataForRowIndex(rowIndex);
+            }
+                break;
+            case ConnectivityDataLoaded::MODE_COLUMN:
+            {
+                int64_t rowIndex;
+                int64_t columnIndex;
+                m_connectivityDataLoaded->getRowColumnLoading(rowIndex,
+                                                              columnIndex);
+                loadDataForColumnIndex(columnIndex);
+            }
+                break;
+            case ConnectivityDataLoaded::MODE_SURFACE_NODE:
+            {
+                StructureEnum::Enum structure;
+                int32_t surfaceNumberOfNodes;
+                int32_t surfaceNodeIndex;
+                int64_t rowIndex;
+                int64_t columnIndex;
+                m_connectivityDataLoaded->getSurfaceNodeLoading(structure,
+                                                                surfaceNumberOfNodes,
+                                                                surfaceNodeIndex,
+                                                                rowIndex,
+                                                                columnIndex);
+                loadMapDataForSurfaceNode(mapIndex,
+                                          surfaceNumberOfNodes,
+                                          structure,
+                                          surfaceNodeIndex,
+                                          rowIndex,
+                                          columnIndex);
+            }
+                break;
+            case ConnectivityDataLoaded::MODE_SURFACE_NODE_AVERAGE:
+            {
+                StructureEnum::Enum structure;
+                int32_t surfaceNumberOfNodes;
+                std::vector<int32_t> surfaceNodeIndices;
+                m_connectivityDataLoaded->getSurfaceAverageNodeLoading(structure,
+                                                                       surfaceNumberOfNodes,
+                                                                       surfaceNodeIndices);
+                loadMapAverageDataForSurfaceNodes(mapIndex,
+                                                  surfaceNumberOfNodes,
+                                                  structure,
+                                                  surfaceNodeIndices);
+            }
+                break;
+            case ConnectivityDataLoaded::MODE_VOXEL_XYZ:
+            {
+                float volumeXYZ[3];
+                int64_t rowIndex;
+                int64_t columnIndex;
+                m_connectivityDataLoaded->getVolumeXYZLoading(volumeXYZ,
+                                                              rowIndex,
+                                                              columnIndex);
+                loadMapDataForVoxelAtCoordinate(mapIndex,
+                                                volumeXYZ,
+                                                rowIndex,
+                                                columnIndex);
+            }
+                break;
+            case ConnectivityDataLoaded::MODE_VOXEL_IJK_AVERAGE:
+            {
+                int64_t volumeDimensionsIJK[3];
+                std::vector<VoxelIJK> voxelIndicesIJK;
+                m_connectivityDataLoaded->getVolumeAverageVoxelLoading(volumeDimensionsIJK,
+                                                                       voxelIndicesIJK);
+                loadMapAverageDataForVoxelIndices(mapIndex,
+                                                  volumeDimensionsIJK,
+                                                  voxelIndicesIJK);
+            }
+                break;
         }
-            break;
-        case ConnectivityDataLoaded::MODE_COLUMN:
-        {
-            int64_t rowIndex;
-            int64_t columnIndex;
-            m_connectivityDataLoaded->getRowColumnLoading(rowIndex,
-                                                          columnIndex);
-            loadDataForColumnIndex(columnIndex);
-        }
-            break;
-        case ConnectivityDataLoaded::MODE_SURFACE_NODE:
-        {
-            StructureEnum::Enum structure;
-            int32_t surfaceNumberOfNodes;
-            int32_t surfaceNodeIndex;
-            int64_t rowIndex;
-            int64_t columnIndex;
-            m_connectivityDataLoaded->getSurfaceNodeLoading(structure,
-                                                            surfaceNumberOfNodes,
-                                                            surfaceNodeIndex,
-                                                            rowIndex,
-                                                            columnIndex);
-            loadMapDataForSurfaceNode(mapIndex,
-                                      surfaceNumberOfNodes,
-                                      structure,
-                                      surfaceNodeIndex,
-                                      rowIndex,
-                                      columnIndex);
-        }
-            break;
-        case ConnectivityDataLoaded::MODE_SURFACE_NODE_AVERAGE:
-        {
-            StructureEnum::Enum structure;
-            int32_t surfaceNumberOfNodes;
-            std::vector<int32_t> surfaceNodeIndices;
-            m_connectivityDataLoaded->getSurfaceAverageNodeLoading(structure,
-                                                                   surfaceNumberOfNodes,
-                                                                   surfaceNodeIndices);
-            loadMapAverageDataForSurfaceNodes(mapIndex,
-                                              surfaceNumberOfNodes,
-                                              structure,
-                                              surfaceNodeIndices);
-        }
-            break;
-        case ConnectivityDataLoaded::MODE_VOXEL_XYZ:
-        {
-            float volumeXYZ[3];
-            int64_t rowIndex;
-            int64_t columnIndex;
-            m_connectivityDataLoaded->getVolumeXYZLoading(volumeXYZ,
-                                                          rowIndex,
-                                                          columnIndex);
-            loadMapDataForVoxelAtCoordinate(mapIndex,
-                                            volumeXYZ,
-                                            rowIndex,
-                                            columnIndex);
-        }
-            break;
-        case ConnectivityDataLoaded::MODE_VOXEL_IJK_AVERAGE:
-        {
-            int64_t volumeDimensionsIJK[3];
-            std::vector<VoxelIJK> voxelIndicesIJK;
-            m_connectivityDataLoaded->getVolumeAverageVoxelLoading(volumeDimensionsIJK,
-                                                                   voxelIndicesIJK);
-            loadMapAverageDataForVoxelIndices(mapIndex,
-                                              volumeDimensionsIJK,
-                                              voxelIndicesIJK);
-        }
-            break;
+    }
+    catch (const DataFileException& dfe) {
+        sceneAttributes->addToErrorMessage(dfe.whatString());
     }
     
     setMapDataLoadingEnabled(mapIndex,
