@@ -32,6 +32,8 @@
 #include "EventBrowserTabIndicesGetAll.h"
 #include "EventManager.h"
 #include "EventTypeEnum.h"
+#include "HistologySlicesFile.h"
+#include "MediaFile.h"
 
 using namespace caret;
 
@@ -103,11 +105,101 @@ EventMapYokingValidation::addMapYokedFile(const CaretMappableDataFile* caretMapF
         return;
     }
  
-    m_yokedFileInfo.insert(YokedFileInfo(NULL,
+    AnnotationTextSubstitutionFile* nullAnnTextSubsFile(NULL);
+    HistologySlicesFile* nullHistologySlicesFile(NULL);
+    MediaFile* nullMediaFile(NULL);
+    m_yokedFileInfo.insert(YokedFileInfo(nullAnnTextSubsFile,
                                          caretMapFile,
+                                         nullHistologySlicesFile,
+                                         nullMediaFile,
                                          tabIndex));
 }
 
+/**
+ * Add a histology slices file, if it is yoked to the same yoking group, so that it
+ * may be used in the compatibility test.
+ *
+ * @param histologySlicesFile
+ *     The histology file.
+ * @param mapYokingGroup
+ *     Yoking group status of the file
+ * @param tabIndex
+ *     Index of tab in which the file is displayed.
+ */
+void
+EventMapYokingValidation::addHistologySlicesYokedFile(const HistologySlicesFile* histologySlicesFile,
+                                                      const MapYokingGroupEnum::Enum mapYokingGroup,
+                                                      const int32_t tabIndex)
+{
+    CaretAssert(histologySlicesFile);
+    
+    if (mapYokingGroup == MapYokingGroupEnum::MAP_YOKING_GROUP_OFF) {
+        return;
+    }
+    
+    if (mapYokingGroup != m_mapYokingGroup) {
+        return;
+    }
+    
+    if (std::find(m_validTabIndices.begin(),
+                  m_validTabIndices.end(),
+                  tabIndex) == m_validTabIndices.end()) {
+        return;
+    }
+    
+    AnnotationTextSubstitutionFile* nullAnnTextSubsFile(NULL);
+    CaretMappableDataFile* nullMapFile(NULL);
+    MediaFile* nullMediaFile(NULL);
+    m_yokedFileInfo.insert(YokedFileInfo(nullAnnTextSubsFile,
+                                         nullMapFile,
+                                         histologySlicesFile,
+                                         nullMediaFile,
+                                         tabIndex));
+    
+}
+/**
+ * Add a media file, if it is yoked to the same yoking group, so that it
+ * may be used in the compatibility test.
+ *
+ * @param mediaFile
+ *     The media file.
+ * @param mapYokingGroup
+ *     Yoking group status of the file
+ * @param tabIndex
+ *     Index of tab in which the file is displayed.
+ */
+void
+EventMapYokingValidation::addMediaYokedFile(const MediaFile* mediaFile,
+                                            const MapYokingGroupEnum::Enum mapYokingGroup,
+                                            const int32_t tabIndex)
+{
+    CaretAssert(mediaFile);
+    
+    if (mapYokingGroup == MapYokingGroupEnum::MAP_YOKING_GROUP_OFF) {
+        return;
+    }
+    
+    if (mapYokingGroup != m_mapYokingGroup) {
+        return;
+    }
+    
+    if (std::find(m_validTabIndices.begin(),
+                  m_validTabIndices.end(),
+                  tabIndex) == m_validTabIndices.end()) {
+        return;
+    }
+    
+    AnnotationTextSubstitutionFile* nullAnnTextSubsFile(NULL);
+    CaretMappableDataFile* nullMapFile(NULL);
+    HistologySlicesFile* nullHistologySlicesFile(NULL);
+    m_yokedFileInfo.insert(YokedFileInfo(nullAnnTextSubsFile,
+                                         nullMapFile,
+                                         nullHistologySlicesFile,
+                                         mediaFile,
+                                         tabIndex));
+
+}
+
 /**
  * Add a annotation text substitution file, if it is yoked to the same yoking group, 
  * so that it may be used in the compatibility test.
@@ -131,8 +223,13 @@ EventMapYokingValidation::addAnnotationTextSubstitutionFile(const AnnotationText
         return;
     }
     
+    CaretMappableDataFile* nullMapFile(NULL);
+    HistologySlicesFile* nullHistologySlicesFile(NULL);
+    MediaFile* nullMediaFile(NULL);
     m_yokedFileInfo.insert(YokedFileInfo(annTextSubFile,
-                                         NULL,
+                                         nullMapFile,
+                                         nullHistologySlicesFile,
+                                         nullMediaFile,
                                          -1));
 }
 
@@ -168,8 +265,13 @@ EventMapYokingValidation::addMapYokedFileAllTabs(const CaretMappableDataFile* ca
             continue;
         }
         
-        m_yokedFileInfo.insert(YokedFileInfo(NULL,
+        AnnotationTextSubstitutionFile* nullAnnTextSubsFile(NULL);
+        HistologySlicesFile* nullHistologySlicesFile(NULL);
+        MediaFile* nullMediaFile(NULL);
+        m_yokedFileInfo.insert(YokedFileInfo(nullAnnTextSubsFile,
                                              caretMapFile,
+                                             nullHistologySlicesFile,
+                                             nullMediaFile,
                                              iTab));
     }
 }
@@ -190,6 +292,10 @@ EventMapYokingValidation::getMapYokingGroup() const
  *     The annotation text substitution file.
  * @param caretMapFile
  *     The map file.
+ * @param histologySlicesFile
+ *     The histology slices file
+ * @param mediaFile
+ *     The media file
  * @param numberOfYokedFilesOut
  *     Number of files, excluding the given file, currently yoked 
  *     to this yoking group.
@@ -201,6 +307,8 @@ EventMapYokingValidation::getMapYokingGroup() const
 bool
 EventMapYokingValidation::validateCompatibility(const AnnotationTextSubstitutionFile* annTextSubFile,
                                                 const CaretMappableDataFile* caretMapFile,
+                                                const HistologySlicesFile* histologySlicesFile,
+                                                const MediaFile* mediaFile,
                                                 int32_t& numberOfYokedFilesOut,
                                                 AString& messageOut) const
 {
@@ -222,6 +330,18 @@ EventMapYokingValidation::validateCompatibility(const AnnotationTextSubstitution
         message = (AString::number(numberOfMaps)
                    + " maps in ");
     }
+    else if (histologySlicesFile != NULL) {
+        filename     = histologySlicesFile->getFileNameNoPath();
+        numberOfMaps = histologySlicesFile->getNumberOfHistologySlices();
+        message = (AString::number(numberOfMaps)
+                   + " slices in ");
+    }
+    else if (mediaFile != NULL) {
+        filename     = mediaFile->getFileName();
+        numberOfMaps = mediaFile->getNumberOfFrames();
+        message = (AString::number(numberOfMaps)
+                   + " frames in ");
+    }
     else {
         CaretAssert(0);
     }
@@ -257,14 +377,22 @@ EventMapYokingValidation::validateCompatibility(const AnnotationTextSubstitution
  *     The annotation text substitution file.
  * @param caretMapFile
  *     The map file.
+ * @param histologySlicesFile
+ *    The histology slices file
+ * @param mediaFile
+ *     The media file
  * @param tabIndex
  *     Index of tab in which the file is displayed.
  */
 EventMapYokingValidation::YokedFileInfo::YokedFileInfo(const AnnotationTextSubstitutionFile* annTextSubFile,
                                                        const CaretMappableDataFile* caretMapFile,
+                                                       const HistologySlicesFile* histologySlicesFile,
+                                                       const MediaFile* mediaFile,
                                                        const int32_t tabIndex)
 : m_annTextSubFile(annTextSubFile),
 m_mapFile(caretMapFile),
+m_histologySlicesFile(histologySlicesFile),
+m_mediaFile(mediaFile),
 m_tabIndex(tabIndex)
 {
     if (m_annTextSubFile != NULL) {
@@ -283,6 +411,22 @@ m_tabIndex(tabIndex)
                       + " file: "
                       + caretMapFile->getFileNameNoPath());
     }
+    else if (m_histologySlicesFile != NULL) {
+        m_numberOfMaps = m_histologySlicesFile->getNumberOfHistologySlices();
+        m_infoText     = (AString::number(m_numberOfMaps)
+                          + " slices in tab "
+                          + AString::number(tabIndex + 1)
+                          + " file: "
+                          + caretMapFile->getFileNameNoPath());
+    }
+    else if (m_mediaFile != NULL) {
+        m_numberOfMaps = m_mediaFile->getNumberOfFrames();
+        m_infoText = (AString::number(m_numberOfMaps)
+                      + " maps in tab "
+                      + AString::number(tabIndex + 1)
+                      + " file: "
+                      + m_mediaFile->getFileNameNoPath());
+    }
     else {
         CaretAssert(0);
     }
