@@ -1683,6 +1683,29 @@ PaletteFile::addDefaultPalettes()
         addPalette(posNeg);
     }
     
+    /*
+     * Special palette name that actually maps the
+     * volume's first three maps an RGB volume
+     */
+    if (this->getPaletteByName(Palette::SPECIAL_RGB_VOLUME_PALETTE_NAME) == NULL) {
+        Palette rgbVolumePalette;
+        rgbVolumePalette.setName(Palette::SPECIAL_RGB_VOLUME_PALETTE_NAME);
+        
+        const AString redName("RGB_Volume_RED");
+        const AString greenName("RGB_Volume_GREEN");
+        const AString blueName("RGB_Volume_BLUE");
+        
+        this->addColor(redName,  255,   0,   0);
+        this->addColor(greenName,  0, 255,   0);
+        this->addColor(blueName,   0,   0, 255);
+        
+        rgbVolumePalette.addScalarAndColor(1.0f,    blueName);
+        rgbVolumePalette.addScalarAndColor(0.333f,  greenName);
+        rgbVolumePalette.addScalarAndColor(-0.333f, redName);
+        
+        addPalette(rgbVolumePalette);
+    }
+    
     if (modifiedStatus == false) {
         this->clearModified();//this clears modified status on all members, to match our status
     }
@@ -1807,6 +1830,8 @@ PaletteFile::setDefaultPaletteColorMapping(PaletteColorMapping* paletteColorMapp
             break;
         case DataFileTypeEnum::CONNECTIVITY_PARCEL_DENSE:
             break;
+        case DataFileTypeEnum::CONNECTIVITY_PARCEL_DYNAMIC:
+            break;
         case DataFileTypeEnum::CONNECTIVITY_PARCEL_LABEL:
             break;
         case DataFileTypeEnum::CONNECTIVITY_PARCEL_SCALAR:
@@ -1826,9 +1851,15 @@ PaletteFile::setDefaultPaletteColorMapping(PaletteColorMapping* paletteColorMapp
             break;
         case DataFileTypeEnum::CONNECTIVITY_SCALAR_DATA_SERIES:
             break;
+        case DataFileTypeEnum::CZI_IMAGE_FILE:
+            invalid = true;
+            break;
         case DataFileTypeEnum::FOCI:
             invalid = true;
             break;
+        case DataFileTypeEnum::HISTOLOGY_SLICES:
+            invalid = true;
+            break;
         case DataFileTypeEnum::IMAGE:
             invalid = true;
             break;
@@ -1846,6 +1877,9 @@ PaletteFile::setDefaultPaletteColorMapping(PaletteColorMapping* paletteColorMapp
         case DataFileTypeEnum::RGBA:
             invalid = true;
             break;
+        case DataFileTypeEnum::SAMPLES:
+            invalid = true;
+            break;
         case DataFileTypeEnum::SCENE:
             invalid = true;
             break;
