@@ -65,7 +65,7 @@ using namespace caret;
  *
  * @param surfaceFile
  *     The surface file.
- * @param plane
+ * @param intersectionPlane
  *     Plane intersected with the surface.
  * @param caretColor
  *     Solid coloring or, if value is CUSTOM, use the vertex coloring
@@ -75,16 +75,58 @@ using namespace caret;
  *     Thickness for the contour as a percentage of viewport height.
  */
 SurfacePlaneIntersectionToContour::SurfacePlaneIntersectionToContour(const SurfaceFile* surfaceFile,
-                                                                     const Plane& plane,
+                                                                     const Plane& intersectionPlane,
                                                                      const CaretColorEnum::Enum caretColor,
                                                                      const float* vertexColoringRGBA,
-                                                                     const float contourThicknessPercentOfViewportHeight)
+                                                                     const float opacity,
+                                                                     const float contourThicknessPercentOfViewportHeight,
+                                                                     const DrawingLineType drawingLineType)
+: SurfacePlaneIntersectionToContour(surfaceFile,
+                                    intersectionPlane,
+                                    intersectionPlane,
+                                    caretColor,
+                                    vertexColoringRGBA,
+                                    opacity,
+                                    contourThicknessPercentOfViewportHeight,
+                                    drawingLineType)
+{
+}
+
+/**
+ * Constructor.
+ *
+ * @param surfaceFile
+ *     The surface file.
+ * @param intersectionPlane
+ *     Plane intersected with the surface.
+ * @param drawOnPlane
+ *     Intersected points are projected to this plane
+ * @param caretColor
+ *     Solid coloring or, if value is CUSTOM, use the vertex coloring
+ * @param vertexColoringRGBA
+ *     The per-vertex coloring if 'caretColor' is CUSTOM
+ * @param opacity
+ *     Opacity for drawing
+ * @param contourThicknessPercentOfViewportHeight
+ *     Thickness for the contour as a percentage of viewport height.
+ */
+SurfacePlaneIntersectionToContour::SurfacePlaneIntersectionToContour(const SurfaceFile* surfaceFile,
+                                                                     const Plane& intersectionPlane,
+                                                                     const Plane& drawOnPlane,
+                                                                     const CaretColorEnum::Enum caretColor,
+                                                                     const float* vertexColoringRGBA,
+                                                                     const float opacity,
+                                                                     const float contourThicknessPercentOfViewportHeight,
+                                                                     const DrawingLineType drawingLineType)
 : CaretObject(),
 m_surfaceFile(surfaceFile),
-m_plane(plane),
+m_intersectionPlane(intersectionPlane),
+m_drawOnPlane(drawOnPlane),
 m_caretColor(caretColor),
 m_vertexColoringRGBA(vertexColoringRGBA),
-m_contourThicknessPercentOfViewportHeight(contourThicknessPercentOfViewportHeight)
+m_opacity(opacity),
+m_contourThicknessPercentOfViewportHeight(contourThicknessPercentOfViewportHeight),
+m_drawingLineType(drawingLineType)
 {
     CaretAssert(m_surfaceFile);
     
@@ -120,8 +162,11 @@ SurfacePlaneIntersectionToContour::createContours(std::vector<GraphicsPrimitive*
         if (m_surfaceFile->getNumberOfNodes() <= 2) {
             throw CaretException("Surface has an invalid number of vertices.");
         }
-        if ( ! m_plane.isValidPlane()) {
-            throw CaretException("Plane is invalid.");
+        if ( ! m_intersectionPlane.isValidPlane()) {
+            throw CaretException("Intersection plane is invalid.");
+        }
+        if ( ! m_drawOnPlane.isValidPlane()) {
+            throw CaretException("Draw on plane is invalid.");
         }
         
         m_topologyHelper = m_surfaceFile->getTopologyHelper(true);
@@ -176,7 +221,7 @@ SurfacePlaneIntersectionToContour::prepareVertices()
     CaretAssert(m_surfaceFile);
     
     float planeNormalVector[3];
-    m_plane.getNormalVector(planeNormalVector);
+    m_intersectionPlane.getNormalVector(planeNormalVector);
     const float abovePlaneOffset[3] = { planeNormalVector[0] * epsilon, planeNormalVector[1] * epsilon, planeNormalVector[2] * epsilon };
     
     const float* surfaceXYZ = m_surfaceFile->getCoordinateData();
@@ -190,14 +235,14 @@ SurfacePlaneIntersectionToContour::prepareVertices()
         const int32_t i3 = i * 3;
         std::array<float, 3> xyz = {{ surfaceXYZ[i3], surfaceXYZ[i3 + 1], surfaceXYZ[i3 + 2] }};
         
-        const float signedDistanceToPlane = m_plane.signedDistanceToPlane(xyz.data());
+        const float signedDistanceToPlane = m_intersectionPlane.signedDistanceToPlane(xyz.data());
         if ((signedDistanceToPlane < epsilon)
             && (signedDistanceToPlane > -epsilon)) {
             /*
              * Point is on or nearly on the plane so move it away from the plane
              */
             float projectedXYZ[3];
-            m_plane.projectPointToPlane(xyz.data(), projectedXYZ);
+            m_intersectionPlane.projectPointToPlane(xyz.data(), projectedXYZ);
             
             if (signedDistanceToPlane >= 0) {
                 xyz[0] = projectedXYZ[0] + abovePlaneOffset[0];
@@ -253,7 +298,7 @@ SurfacePlaneIntersectionToContour::prepareEdges()
                                                    : indexOne);
             
             std::array<float, 3> intersectionXYZ;
-            const bool validFlag = m_plane.lineSegmentIntersectPlane(m_vertices[belowPlaneVertexIndex]->m_xyz.data(),
+            const bool validFlag = m_intersectionPlane.lineSegmentIntersectPlane(m_vertices[belowPlaneVertexIndex]->m_xyz.data(),
                                                                      m_vertices[abovePlaneVertexIndex]->m_xyz.data(),
                                                                      intersectionXYZ.data());
             if (validFlag) {
@@ -335,7 +380,16 @@ SurfacePlaneIntersectionToContour::generateContourFromEdge(IntersectionEdge* sta
     
     const std::vector<TopologyTileInfo>& allTileInfo = m_topologyHelper->getTileInfo();
     
-    std::unique_ptr<GraphicsPrimitiveV3fC4f> primitive(GraphicsPrimitive::newPrimitiveV3fC4f(GraphicsPrimitive::PrimitiveType::POLYGONAL_LINE_LOOP_BEVEL_JOIN));
+    std::unique_ptr<GraphicsPrimitiveV3fC4f> primitive;
+    switch (m_drawingLineType) {
+        case OPENGL_LINES:
+            primitive.reset(GraphicsPrimitive::newPrimitiveV3fC4f(GraphicsPrimitive::PrimitiveType::OPENGL_LINE_LOOP));
+            break;
+        case POLYGONAL_LINES:
+            primitive.reset(GraphicsPrimitive::newPrimitiveV3fC4f(GraphicsPrimitive::PrimitiveType::POLYGONAL_LINE_LOOP_BEVEL_JOIN));
+            break;
+    }
+    CaretAssert(primitive.get());
     primitive->setLineWidth(GraphicsPrimitive::LineWidthType::PERCENTAGE_VIEWPORT_HEIGHT,
                             m_contourThicknessPercentOfViewportHeight);
     primitive->reserveForNumberOfVertices(m_numberOfIntersectingEdges + 5);
@@ -346,6 +400,12 @@ SurfacePlaneIntersectionToContour::generateContourFromEdge(IntersectionEdge* sta
         std::cout << "Start: " << startingEdge->toString() << std::endl;
     }
     
+    float alphaValue(1.0);
+    if ((m_opacity > 0.0)
+        && (m_opacity <= 1.0)) {
+        alphaValue = m_opacity;
+    }
+    
     while (edge != NULL) {
         edge->m_processedFlag = true;
         
@@ -401,17 +461,26 @@ SurfacePlaneIntersectionToContour::generateContourFromEdge(IntersectionEdge* sta
             }
         }
         
-        primitive->addVertex(edge->m_intersectionXYZ.data(), colorRGBA.data());
+        colorRGBA[3] = alphaValue;
         
+        Vector3D xyzOne;
+        m_drawOnPlane.projectPointToPlane(edge->m_intersectionXYZ.data(),
+                                          xyzOne);
+        primitive->addVertex(xyzOne,
+                             colorRGBA.data());
+
         if (startingEdge->hasMatchingTriangle(edge)) {
             if (primitive->getNumberOfVertices() > 3) {
+                Vector3D xyzTwo;
+                m_drawOnPlane.projectPointToPlane(startingEdge->m_intersectionXYZ.data(),
+                                                  xyzTwo);
                 if (m_debugFlag) {
-                    primitive->addVertex(startingEdge->m_intersectionXYZ.data(),
+                    primitive->addVertex(xyzTwo,
                                          startDebugRgba.data());
                     std::cout << "    Closed contour" << std::endl;
                 }
                 else {
-                    primitive->addVertex(startingEdge->m_intersectionXYZ.data(),
+                    primitive->addVertex(xyzTwo,
                                          colorRGBA.data());
                 }
             }
