@@ -29,7 +29,9 @@
 #include "GiftiLabel.h"
 #include "GroupAndNameHierarchyItem.h"
 #include "NodeAndVoxelColoring.h"
+#include "Palette.h"
 #include "VolumeFile.h"
+#include "VoxelColorUpdate.h"
 
 #include <cmath>
 
@@ -89,21 +91,26 @@ VolumeFileVoxelColorizer::~VolumeFileVoxelColorizer()
  *     Index of map.
  */
 void
-VolumeFileVoxelColorizer::assignVoxelColorsForMap(const int32_t mapIndex)
+VolumeFileVoxelColorizer::assignVoxelColorsForMap(const int32_t mapIndex) const
 {
     CaretAssertVectorIndex(m_mapRGBA, mapIndex);
     
+    CaretAssertVectorIndex(m_mapColoringValid, mapIndex);
+    if ( ! m_mapColoringValid[mapIndex]) {
+        clearVoxelColoringForMap(mapIndex);
+    }
+    
     ElapsedTimer timer;
     timer.start();
     
     /*
-     * Pointer to map's data 
+     * Pointer to map's data
      */
     const float* mapDataPointer = m_volumeFile->getFrame(mapIndex);
     
     VolumeFile* thresholdVolume = NULL;
     int32_t thresholdVolumeMapIndex   = -1;
-
+    
     if (m_volumeFile->isMappedWithPalette()) {
         switch (m_volumeFile->getMapPaletteColorMapping(mapIndex)->getThresholdType()) {
             case PaletteThresholdTypeEnum::THRESHOLD_TYPE_FILE:
@@ -165,7 +172,9 @@ VolumeFileVoxelColorizer::assignVoxelColorsForMap(const int32_t mapIndex)
         }
     }
     
-    switch (m_volumeFile->getType()) {
+    const SubvolumeAttributes::VolumeType volumeType(m_volumeFile->getType());
+        
+    switch (volumeType) {
         case SubvolumeAttributes::UNKNOWN:
         case SubvolumeAttributes::ANATOMY:
         case SubvolumeAttributes::FUNCTIONAL:
@@ -233,6 +242,27 @@ VolumeFileVoxelColorizer::assignVoxelColorsForMap(const int32_t mapIndex)
             }
         }
             break;
+        case SubvolumeAttributes::RGB_WORKBENCH:
+            if (m_volumeFile->getNumberOfMaps() >= 3) {
+                /*
+                 * Use first 3 maps as RGB components
+                 */
+                const float* alphaComponents(NULL);
+                const uint8_t thresholdRGB[3] = { 5, 5, 5 };
+                NodeAndVoxelColoring::colorScalarsWithRGBA(m_volumeFile->getFrame(0),
+                                                           m_volumeFile->getFrame(1),
+                                                           m_volumeFile->getFrame(2),
+                                                           alphaComponents,
+                                                           m_voxelCountPerMap,
+                                                           thresholdRGB,
+                                                           m_mapRGBA[mapIndex]);
+                m_mapColoringValid[mapIndex] = true;
+            }
+            else {
+                CaretLogSevere("An RGB_WORKBENCH volume must contain at least 3 maps: "
+                               + m_volumeFile->getFileNameNoPath());
+            }
+            break;
         case SubvolumeAttributes::SEGMENTATION:
             break;
         case SubvolumeAttributes::VECTOR:
@@ -291,6 +321,11 @@ VolumeFileVoxelColorizer::getVoxelColorsForSliceInMap(const int32_t mapIndex,
     CaretAssert(sliceIndex >= 0);
     CaretAssert(rgbaOut);
     
+    CaretAssertVectorIndex(m_mapColoringValid, mapIndex);
+    if ( ! m_mapColoringValid[mapIndex]) {
+        assignVoxelColorsForMap(mapIndex);
+    }
+    
     int64_t iStart = 0;
     int64_t iEnd   = m_dimI - 1;
     int64_t jStart = 0;
@@ -413,6 +448,11 @@ VolumeFileVoxelColorizer::getVoxelColorsForSliceInMap(const int32_t mapIndex,
                                     const int32_t tabIndex,
                                     uint8_t* rgbaOut) const
 {
+    CaretAssertVectorIndex(m_mapColoringValid, mapIndex);
+    if ( ! m_mapColoringValid[mapIndex]) {
+        assignVoxelColorsForMap(mapIndex);
+    }
+
     /*
      * Pointer to maps RGBA values
      */
@@ -522,6 +562,11 @@ VolumeFileVoxelColorizer::getVoxelColorsForSubSliceInMap(const int32_t mapIndex,
     CaretAssert(sliceIndex >= 0);
     CaretAssert(rgbaOut);
     
+    CaretAssertVectorIndex(m_mapColoringValid, mapIndex);
+    if ( ! m_mapColoringValid[mapIndex]) {
+        assignVoxelColorsForMap(mapIndex);
+    }
+
     VolumeSpace::OrientTypes orient[3];
     m_volumeFile->getOrientation(orient);
     int orient2dim[3];
@@ -648,7 +693,46 @@ VolumeFileVoxelColorizer::getVoxelColorsForSubSliceInMap(const int32_t mapIndex,
 }
 
 /**
- * Get the RGBA color components for voxel.
+ * Get the RGBA color components for voxel in a map
+ *
+ * @param i
+ *    Parasaggital index
+ * @param j
+ *    Coronal index
+ * @param k
+ *    Axial index
+ * @param mapIndex
+ *    Index of map.
+ * @param rgbaOut
+ *    Contains voxel coloring on exit.
+ */
+void
+VolumeFileVoxelColorizer::getVoxelColorInMap(const int64_t i,
+                                             const int64_t j,
+                                             const int64_t k,
+                                             const int64_t mapIndex,
+                                             uint8_t rgbaOut[4]) const
+{
+    CaretAssertVectorIndex(m_mapColoringValid, mapIndex);
+    if ( ! m_mapColoringValid[mapIndex]) {
+        assignVoxelColorsForMap(mapIndex);
+    }
+    
+    /*
+     * Pointer to maps RGBA values
+     */
+    CaretAssertVectorIndex(m_mapRGBA, mapIndex);
+    const uint8_t* mapRGBA = m_mapRGBA[mapIndex];
+    const int64_t rgbaOffset = getRgbaOffsetForVoxelIndex(i, j, k);
+    CaretAssertArrayIndex(mapRGBA, m_mapRGBACount, rgbaOffset);
+    rgbaOut[0] = mapRGBA[rgbaOffset];
+    rgbaOut[1] = mapRGBA[rgbaOffset+1];
+    rgbaOut[2] = mapRGBA[rgbaOffset+2];
+    rgbaOut[3] = mapRGBA[rgbaOffset+3];
+}
+
+/**
+ * Get the RGBA color components for voxel with display group and tab.
  *
  * @param i
  *    Parasaggital index
@@ -674,18 +758,28 @@ VolumeFileVoxelColorizer::getVoxelColorInMap(const int64_t i,
                                              const int32_t tabIndex,
                                              uint8_t rgbaOut[4]) const
 {
-    /*
-     * Pointer to maps RGBA values
-     */
-    CaretAssertVectorIndex(m_mapRGBA, mapIndex);
-    const uint8_t* mapRGBA = m_mapRGBA[mapIndex];
-    const int64_t rgbaOffset = getRgbaOffsetForVoxelIndex(i, j, k);
-    CaretAssertArrayIndex(mapRGBA, m_mapRGBACount, rgbaOffset);
-    rgbaOut[0] = mapRGBA[rgbaOffset];
-    rgbaOut[1] = mapRGBA[rgbaOffset+1];
-    rgbaOut[2] = mapRGBA[rgbaOffset+2];
-    uint8_t alpha = mapRGBA[rgbaOffset+3];
+//    CaretAssertVectorIndex(m_mapColoringValid, mapIndex);
+//    if ( ! m_mapColoringValid[mapIndex]) {
+//        assignVoxelColorsForMap(mapIndex);
+//    }
+//
+//    /*
+//     * Pointer to maps RGBA values
+//     */
+//    CaretAssertVectorIndex(m_mapRGBA, mapIndex);
+//    const uint8_t* mapRGBA = m_mapRGBA[mapIndex];
+//    const int64_t rgbaOffset = getRgbaOffsetForVoxelIndex(i, j, k);
+//    CaretAssertArrayIndex(mapRGBA, m_mapRGBACount, rgbaOffset);
+//    rgbaOut[0] = mapRGBA[rgbaOffset];
+//    rgbaOut[1] = mapRGBA[rgbaOffset+1];
+//    rgbaOut[2] = mapRGBA[rgbaOffset+2];
+//    uint8_t alpha = mapRGBA[rgbaOffset+3];
+
+    getVoxelColorInMap(i, j, k,
+                       mapIndex,
+                       rgbaOut);
     
+    uint8_t alpha(rgbaOut[3]);
     if (alpha > 0) {
         if (m_volumeFile->isMappedWithLabelTable()) {
             const GiftiLabelTable* labelTable = m_volumeFile->getMapLabelTable(mapIndex);
@@ -720,7 +814,7 @@ VolumeFileVoxelColorizer::getVoxelColorInMap(const int64_t i,
  *    Index of map.
  */
 void
-VolumeFileVoxelColorizer::clearVoxelColoringForMap(const int64_t mapIndex)
+VolumeFileVoxelColorizer::clearVoxelColoringForMap(const int64_t mapIndex) const
 {
     CaretAssertVectorIndex(m_mapRGBA, mapIndex);
     uint8_t* mapRGBA = m_mapRGBA[mapIndex];
@@ -733,3 +827,34 @@ VolumeFileVoxelColorizer::clearVoxelColoringForMap(const int64_t mapIndex)
     m_mapColoringValid[mapIndex] = false;
 }
 
+/**
+ * Update the voxel coloring for the given voxels in the given map with the given RGBA coloring.
+ * This method is used by voxel editing to avoid recoloring all voxels in the volume
+ * @param voxelColorUpdate
+ *    Color update information
+ */
+void
+VolumeFileVoxelColorizer::updateVoxelColorsInMap(const VoxelColorUpdate& voxelColorUpdate)
+{
+    const int32_t mapIndex(voxelColorUpdate.getMapIndex());
+    CaretAssertVectorIndex(m_mapColoringValid, mapIndex);
+    
+    if (m_mapColoringValid[mapIndex]) {
+        CaretAssertVectorIndex(m_mapRGBA, mapIndex);
+        uint8_t* mapRGBA = m_mapRGBA[mapIndex];
+        
+        const std::array<uint8_t, 4> rgba(voxelColorUpdate.getRGBA());
+        const int32_t numVoxels(voxelColorUpdate.getNumberOfVoxels());
+        for (int32_t i = 0; i < numVoxels; i++) {
+            const VoxelIJK& ijk(voxelColorUpdate.getVoxel(i));
+            const int64_t rgbaOffset = getRgbaOffsetForVoxelIndex(ijk.m_ijk);
+            CaretAssertArrayIndex(mapRGBA, m_mapRGBACount, rgbaOffset);
+            
+            mapRGBA[rgbaOffset]   = rgba[0];
+            mapRGBA[rgbaOffset+1] = rgba[1];
+            mapRGBA[rgbaOffset+2] = rgba[2];
+            mapRGBA[rgbaOffset+3] = rgba[3];
+        }
+    }
+}
+
