@@ -207,7 +207,7 @@ namespace caret {
         void spaceToIndex(const float& coordIn1, const float& coordIn2, const float& coordIn3, float& indexOut1, float& indexOut2, float& indexOut3) const;
 
         ///returns integer index triplet of voxel whose center is closest to the coordinate triplet
-        void enclosingVoxel(const float* coordIn, int64_t* indexOut) const;
+        void enclosingVoxel(const float* coordIn, int64_t* indexOut) const override;
         ///returns integer index triplet of voxel whose center is closest to the three coordinates
         void enclosingVoxel(const float& coordIn1, const float& coordIn2, const float& coordIn3, int64_t* indexOut) const;
         ///returns integer indexes of voxel whose center is closest to the coordinate triplet
@@ -353,7 +353,7 @@ namespace caret {
             return m_storage.getIndex(indexIn[0], indexIn[1], indexIn[2], brickIndex, component);
         }
 
-        inline bool indexValid(const int64_t* indexIn, const int64_t brickIndex = 0, const int64_t component = 0) const
+        inline bool indexValid(const int64_t* indexIn, const int64_t brickIndex = 0, const int64_t component = 0) const override
         {
             return m_storage.indexValid(indexIn[0], indexIn[1], indexIn[2], brickIndex, component);
         }
