@@ -26,6 +26,7 @@
 #undef __ANNOTATION_TEXT_ALIGNMENT_WIDGET_DECLARE__
 
 #include <QAction>
+#include <QActionGroup>
 #include <QGridLayout>
 #include <QHBoxLayout>
 #include <QImage>
@@ -41,7 +42,7 @@
 #include "AnnotationText.h"
 #include "Brain.h"
 #include "CaretAssert.h"
-#include "EventGraphicsUpdateAllWindows.h"
+#include "EventGraphicsPaintSoonAllWindows.h"
 #include "EventManager.h"
 #include "GuiManager.h"
 #include "MathFunctions.h"
@@ -59,15 +60,19 @@ using namespace caret;
 
 /**
  * Constructor.
- * 
+ *
+ * @param userInputMode
+ *     The user input mode
  * @param browserWindowIndex
  *     Index of browser window.
  * @param parent
  *     The parent widget.
  */
-AnnotationTextAlignmentWidget::AnnotationTextAlignmentWidget(const int32_t browserWindowIndex,
+AnnotationTextAlignmentWidget::AnnotationTextAlignmentWidget(const UserInputModeEnum::Enum userInputMode,
+                                                             const int32_t browserWindowIndex,
                                                              QWidget* parent)
 : QWidget(parent),
+m_userInputMode(userInputMode),
 m_browserWindowIndex(browserWindowIndex)
 {
     m_smallLayoutFlag = true;
@@ -303,16 +308,15 @@ AnnotationTextAlignmentWidget::horizontalAlignmentActionSelected(QAction* action
                                              m_annotations.end());
         undoCommand->setModeTextAlignmentHorizontal(actionAlign,
                                                     annotations);
-        AnnotationManager* annMan = GuiManager::get()->getBrain()->getAnnotationManager();
+        AnnotationManager* annMan = GuiManager::get()->getBrain()->getAnnotationManager(m_userInputMode);
         AString errorMessage;
-        if ( ! annMan->applyCommand(UserInputModeEnum::Enum::ANNOTATIONS,
-                                    undoCommand,
+        if ( ! annMan->applyCommand(undoCommand,
                                     errorMessage)) {
             WuQMessageBox::errorOk(this,
                                    errorMessage);
         }
         EventManager::get()->sendSimpleEvent(EventTypeEnum::EVENT_ANNOTATION_TOOLBAR_UPDATE);
-        EventManager::get()->sendEvent(EventGraphicsUpdateAllWindows().getPointer());
+        EventManager::get()->sendEvent(EventGraphicsPaintSoonAllWindows().getPointer());
         
         AnnotationText::setUserDefaultHorizontalAlignment(actionAlign);
     }
@@ -338,16 +342,15 @@ AnnotationTextAlignmentWidget::verticalAlignmentActionSelected(QAction* action)
                                              m_annotations.end());
         undoCommand->setModeTextAlignmentVertical(actionAlign,
                                                   annotations);
-        AnnotationManager* annMan = GuiManager::get()->getBrain()->getAnnotationManager();
+        AnnotationManager* annMan = GuiManager::get()->getBrain()->getAnnotationManager(m_userInputMode);
         AString errorMessage;
-        if ( ! annMan->applyCommand(UserInputModeEnum::Enum::ANNOTATIONS,
-                                    undoCommand,
+        if ( ! annMan->applyCommand(undoCommand,
                                     errorMessage)) {
             WuQMessageBox::errorOk(this,
                                    errorMessage);
         }
         EventManager::get()->sendSimpleEvent(EventTypeEnum::EVENT_ANNOTATION_TOOLBAR_UPDATE);
-        EventManager::get()->sendEvent(EventGraphicsUpdateAllWindows().getPointer());
+        EventManager::get()->sendEvent(EventGraphicsPaintSoonAllWindows().getPointer());
         
         AnnotationText::setUserDefaultVerticalAlignment(actionAlign);
     }
