@@ -23,17 +23,23 @@
 #include "BrainBrowserWindowToolBarOrientation.h"
 #undef __BRAIN_BROWSER_WINDOW_TOOL_BAR_ORIENTATION_DECLARE__
 
-#include "CaretAssert.h"
 using namespace caret;
+#include "CaretAssert.h"
 
 #include <QAction>
 #include <QGridLayout>
+#include <QStackedLayout>
 #include <QToolButton>
 #include <QVBoxLayout>
 
 #include "BrainBrowserWindowToolBar.h"
 #include "BrowserTabContent.h"
+#include "CaretUndoStack.h"
+#include "EventGraphicsPaintNowAllWindows.h"
+#include "EventGraphicsPaintSoonAllWindows.h"
+#include "EventManager.h"
 #include "Model.h"
+#include "ModelHistology.h"
 #include "ModelMedia.h"
 #include "ModelSurface.h"
 #include "ModelSurfaceMontage.h"
@@ -41,7 +47,9 @@ using namespace caret;
 #include "ModelWholeBrain.h"
 #include "Surface.h"
 #include "StructureEnum.h"
+#include "ViewingTransformations.h"
 #include "WuQMacroManager.h"
+#include "WuQMessageBox.h"
 #include "WuQtUtilities.h"
 
     
@@ -205,7 +213,7 @@ BrainBrowserWindowToolBarOrientation::BrainBrowserWindowToolBarOrientation(const
     macroManager->addMacroSupportToObject(this->orientationAnteriorPosteriorToolButtonAction,
                                           "Select anterior/posterior orientation");
     
-    this->orientationResetToolButtonAction = WuQtUtilities::createAction("R\nE\nS\nE\nT",
+    this->orientationResetToolButtonAction = WuQtUtilities::createAction("Reset",
                                                                          "Reset the view to lateral and remove any panning or zooming",
                                                                          this,
                                                                          this,
@@ -270,28 +278,113 @@ BrainBrowserWindowToolBarOrientation::BrainBrowserWindowToolBarOrientation(const
     
     this->orientationCustomViewSelectToolButton = new QToolButton();
     this->orientationCustomViewSelectToolButton->setDefaultAction(getParentToolBar()->customViewAction);
-    this->orientationCustomViewSelectToolButton->setSizePolicy(QSizePolicy::Minimum,
-                                                               QSizePolicy::Fixed);
     WuQtUtilities::setToolButtonStyleForQt5Mac(this->orientationCustomViewSelectToolButton);
+        
+    m_singleViewWidget = new QWidget();
+    QGridLayout* singleViewLayout = new QGridLayout(m_singleViewWidget);
+    singleViewLayout->setHorizontalSpacing(0);
+    singleViewLayout->setVerticalSpacing(0);
+    singleViewLayout->setContentsMargins(0, 0, 0, 0);
+    singleViewLayout->addWidget(this->orientationLeftOrLateralToolButton, 0, 0);
+    singleViewLayout->addWidget(this->orientationDorsalToolButton, 0, 1);
+    singleViewLayout->addWidget(this->orientationAnteriorToolButton, 0, 2);
+    singleViewLayout->addWidget(this->orientationRightOrMedialToolButton, 1, 0);
+    singleViewLayout->addWidget(this->orientationVentralToolButton, 1, 1);
+    singleViewLayout->addWidget(this->orientationPosteriorToolButton, 1, 2);
+
+    m_dualViewWidget = new QWidget();
+    QGridLayout* dualViewLayout = new QGridLayout(m_dualViewWidget);
+    dualViewLayout->setHorizontalSpacing(0);
+    dualViewLayout->setVerticalSpacing(0);
+    dualViewLayout->setContentsMargins(0, 0, 0, 0);
+    dualViewLayout->addWidget(this->orientationLateralMedialToolButton, 0, 0);
+    dualViewLayout->addWidget(this->orientationDorsalVentralToolButton, 0, 1);
+    dualViewLayout->addWidget(this->orientationAnteriorPosteriorToolButton, 1, 0, 1, 2, Qt::AlignHCenter);
+
+    m_emptyViewWidget = new QWidget();
     
-    QGridLayout* buttonGridLayout = new QGridLayout();
-    buttonGridLayout->setColumnStretch(3, 100);
-    WuQtUtilities::setLayoutSpacingAndMargins(buttonGridLayout, 0, 0);
-    buttonGridLayout->addWidget(this->orientationLeftOrLateralToolButton,      0, 0);
-    buttonGridLayout->addWidget(this->orientationRightOrMedialToolButton,     0, 1);
-    buttonGridLayout->addWidget(this->orientationDorsalToolButton,    1, 0);
-    buttonGridLayout->addWidget(this->orientationVentralToolButton,   1, 1);
-    buttonGridLayout->addWidget(this->orientationAnteriorToolButton,  2, 0);
-    buttonGridLayout->addWidget(this->orientationPosteriorToolButton, 2, 1);
-    buttonGridLayout->addWidget(this->orientationLateralMedialToolButton, 0, 2);
-    buttonGridLayout->addWidget(this->orientationDorsalVentralToolButton, 1, 2);
-    buttonGridLayout->addWidget(this->orientationAnteriorPosteriorToolButton, 2, 2);
-    buttonGridLayout->addWidget(this->orientationCustomViewSelectToolButton, 3, 0, 1, 5, Qt::AlignHCenter);
-    buttonGridLayout->addWidget(orientationResetToolButton, 0, 4, 3, 1);
+    m_singleDualViewLayout = new QStackedLayout();
+    m_singleDualViewLayout->addWidget(m_singleViewWidget);
+    m_singleDualViewLayout->addWidget(m_dualViewWidget);
+    m_singleDualViewLayout->addWidget(m_emptyViewWidget);
     
+    /*
+     * Redo and Undo
+     */
+    QIcon redoIcon;
+    const bool redoIconValid(WuQtUtilities::loadIcon(":/ToolBar/redo.png",
+                                                     redoIcon));
+    QIcon undoIcon;
+    const bool undoIconValid(WuQtUtilities::loadIcon(":/ToolBar/undo.png",
+                                                     undoIcon));
+
+    m_redoAction = new QAction();
+    if (redoIconValid) {
+        m_redoAction->setIcon(redoIcon);
+    }
+    else {
+        m_redoAction->setText("R");
+    }
+    m_redoAction->setToolTip("Redo change in view");
+    QObject::connect(m_redoAction, &QAction::triggered,
+                     this, &BrainBrowserWindowToolBarOrientation::redoActionTriggered);
+    QToolButton* redoToolButton = new QToolButton();
+    redoToolButton->setDefaultAction(m_redoAction);
+    WuQtUtilities::setToolButtonStyleForQt5Mac(redoToolButton);
+    m_redoAction->setObjectName(objectNamePrefix + ":Redo");
+    WuQMacroManager::instance()->addMacroSupportToObject(m_redoAction, "Redo Image View");
+    
+    m_undoAction = new QAction();
+    if (undoIconValid) {
+        m_undoAction->setIcon(undoIcon);
+    }
+    else {
+        m_undoAction->setText("U");
+    }
+    m_undoAction->setToolTip("Undo change in view");
+    QObject::connect(m_undoAction, &QAction::triggered,
+                     this, &BrainBrowserWindowToolBarOrientation::undoActionTriggered);
+    QToolButton* undoToolButton = new QToolButton();
+    undoToolButton->setDefaultAction(m_undoAction);
+    WuQtUtilities::setToolButtonStyleForQt5Mac(undoToolButton);
+    m_undoAction->setObjectName(objectNamePrefix + ":Undo");
+    WuQMacroManager::instance()->addMacroSupportToObject(m_undoAction, "Undo Image View");
+
+    /*
+     * Select region
+     */
+    QIcon selectRegionIcon;
+    const bool selectRegionIconValid(WuQtUtilities::loadIcon(":/ToolBar/select-region.png",
+                                                             selectRegionIcon));
+    m_selectRegionAction = new QAction();
+    if (selectRegionIconValid) {
+        m_selectRegionAction->setIcon(selectRegionIcon);
+    }
+    else {
+        m_selectRegionAction->setText("SR");
+    }
+    m_selectRegionAction->setToolTip("<html>Select region by dragging mouse to form a rectangle</html>");
+    m_selectRegionAction->setCheckable(true);
+    QObject::connect(m_selectRegionAction, &QAction::triggered,
+                     this, &BrainBrowserWindowToolBarOrientation::selectRegionActionTriggered);
+    QToolButton* selectRegionToolButton(new QToolButton());
+    selectRegionToolButton->setDefaultAction(m_selectRegionAction);
+    WuQtUtilities::setToolButtonStyleForQt5Mac(selectRegionToolButton);
+    m_selectRegionAction->setObjectName(objectNamePrefix + ":SelectRegion");
+    WuQMacroManager::instance()->addMacroSupportToObject(m_selectRegionAction, "Selection Region");
+    
+    QHBoxLayout* redoUndoLayout(new QHBoxLayout());
+    WuQtUtilities::setLayoutSpacingAndMargins(redoUndoLayout, 0, 0);
+    redoUndoLayout->addWidget(redoToolButton);
+    redoUndoLayout->addWidget(undoToolButton);
+    redoUndoLayout->addWidget(selectRegionToolButton);
+
     QVBoxLayout* layout = new QVBoxLayout(this);
     WuQtUtilities::setLayoutSpacingAndMargins(layout, 0, 0);
-    layout->addLayout(buttonGridLayout);
+    layout->addLayout(m_singleDualViewLayout, 0);
+    layout->addWidget(this->orientationCustomViewSelectToolButton, 0, Qt::AlignHCenter);
+    layout->addWidget(orientationResetToolButton, 0, Qt::AlignHCenter);
+    layout->addLayout(redoUndoLayout);
     
     addToWidgetGroup(this->orientationLeftOrLateralToolButtonAction);
     addToWidgetGroup(this->orientationRightOrMedialToolButtonAction);
@@ -366,12 +459,14 @@ BrainBrowserWindowToolBarOrientation::~BrainBrowserWindowToolBarOrientation()
 void
 BrainBrowserWindowToolBarOrientation::updateContent(BrowserTabContent* browserTabContent)
 {
+    m_browserTabContent = browserTabContent;
     const int32_t tabIndex = browserTabContent->getTabNumber();
     
     blockAllSignals(true);
     
     const Model* mdc = getParentToolBar()->getDisplayedModel();
     if (mdc != NULL) {
+        const ModelHistology* mh = dynamic_cast<const ModelHistology*>(mdc);
         const ModelMedia* mdm    = dynamic_cast<const ModelMedia*>(mdc);
         const ModelSurface* mdcs = dynamic_cast<const ModelSurface*>(mdc);
         const ModelSurfaceMontage* mdcsm = dynamic_cast<const ModelSurfaceMontage*>(mdc);
@@ -430,6 +525,9 @@ BrainBrowserWindowToolBarOrientation::updateContent(BrowserTabContent* browserTa
             leftRightFlag = true;
             showSingleViewOrientationButtons = true;
         }
+        else if (mh != NULL) {
+            /* nothing */
+        }
         else if (mdm != NULL) {
             /* nothing */
         }
@@ -496,26 +594,78 @@ BrainBrowserWindowToolBarOrientation::updateContent(BrowserTabContent* browserTa
          * Reset button remains on the right and it looks weird.  So,
          * display them but disable them when a flat map montage.
          */
-        this->orientationLateralMedialToolButton->setVisible(showDualViewOrientationButtons);
-        this->orientationDorsalVentralToolButton->setVisible(showDualViewOrientationButtons);
-        this->orientationAnteriorPosteriorToolButton->setVisible(showDualViewOrientationButtons);
-        
         this->orientationLateralMedialToolButton->setEnabled(enableDualViewOrientationButtons);
         this->orientationDorsalVentralToolButton->setEnabled(enableDualViewOrientationButtons);
         this->orientationAnteriorPosteriorToolButton->setEnabled(enableDualViewOrientationButtons);
-        
-        
-        this->orientationLeftOrLateralToolButton->setVisible(showSingleViewOrientationButtons);
-        this->orientationRightOrMedialToolButton->setVisible(showSingleViewOrientationButtons);
-        this->orientationDorsalToolButton->setVisible(showSingleViewOrientationButtons);
-        this->orientationVentralToolButton->setVisible(showSingleViewOrientationButtons);
-        this->orientationAnteriorToolButton->setVisible(showSingleViewOrientationButtons);
-        this->orientationPosteriorToolButton->setVisible(showSingleViewOrientationButtons);
+
+        if (showDualViewOrientationButtons) {
+            m_singleDualViewLayout->setCurrentWidget(m_dualViewWidget);
+        }
+        else if (showSingleViewOrientationButtons) {
+            m_singleDualViewLayout->setCurrentWidget(m_singleViewWidget);
+        }
+        else {
+            m_singleDualViewLayout->setCurrentWidget(m_emptyViewWidget);
+        }
     }
     
+    m_redoAction->setEnabled(false);
+    m_undoAction->setEnabled(false);
+    
+    if (browserTabContent != NULL) {
+        CaretUndoStack* undoStack = getUndoStack();
+        if (undoStack != NULL) {
+            m_redoAction->setEnabled(undoStack->canRedo());
+            m_redoAction->setToolTip("Redo " + undoStack->redoText());
+            
+            m_undoAction->setEnabled(undoStack->canUndo());
+            m_undoAction->setToolTip("Undo " + undoStack->undoText());
+        }
+    }
+    
+    updateRegionSelectionAction();
+    
     blockAllSignals(false);
 }
 
+void
+BrainBrowserWindowToolBarOrientation::updateRegionSelectionAction()
+{
+    if (m_browserTabContent != NULL) {
+        const std::vector<MouseLeftDragModeEnum::Enum> mouseDragModes(m_browserTabContent->getSupportedMouseLeftDragModes());
+        bool enableSelectRegionFlag(false);
+        for (const auto mdm : mouseDragModes) {
+            switch (mdm) {
+                case MouseLeftDragModeEnum::INVALID:
+                    CaretAssert(0);
+                    break;
+                case MouseLeftDragModeEnum::DEFAULT:
+                    break;
+                case MouseLeftDragModeEnum::REGION_SELECTION:
+                    enableSelectRegionFlag = true;
+                    break;
+            }
+        }
+        m_selectRegionAction->setEnabled(enableSelectRegionFlag);
+        
+        switch (m_browserTabContent->getMouseLeftDragMode()) {
+            case MouseLeftDragModeEnum::INVALID:
+                CaretAssert(0);
+                break;
+            case MouseLeftDragModeEnum::DEFAULT:
+                m_selectRegionAction->setChecked(false);
+                break;
+            case MouseLeftDragModeEnum::REGION_SELECTION:
+                m_selectRegionAction->setChecked(true);
+                break;
+        }
+    }
+    else {
+        m_selectRegionAction->setEnabled(false);
+    }
+    
+}
+
 /**
  * Called when orientation left or lateral button is pressed.
  */
@@ -595,6 +745,9 @@ BrainBrowserWindowToolBarOrientation::orientationResetToolButtonTriggered(bool /
     if (mdc != NULL) {
         getParentToolBar()->updateVolumeIndicesWidget(btc);
         getParentToolBar()->updateGraphicsWindowAndYokedWindows();
+        if (btc->isMediaDisplayed()) {
+            EventManager::get()->sendEvent(EventGraphicsPaintNowAllWindows().getPointer());
+        }
     }
 }
 
@@ -630,3 +783,73 @@ BrainBrowserWindowToolBarOrientation::orientationAnteriorPosteriorToolButtonTrig
     btc->anteriorView();
     this->updateGraphicsWindowAndYokedWindows();
 }
+
+/**
+ * Gets called when the redo action is triggered
+ */
+void
+BrainBrowserWindowToolBarOrientation::redoActionTriggered()
+{
+    CaretUndoStack* undoStack = getUndoStack();
+    AString errorMessage;
+    if ( ! undoStack->redo(errorMessage)) {
+        WuQMessageBox::errorOk(this,
+                               errorMessage);
+    }
+    
+    updateGraphicsWindowAndYokedWindows();
+    updateContent(m_browserTabContent);
+}
+
+/**
+ * Gets called when the undo action is triggered
+ */
+void
+BrainBrowserWindowToolBarOrientation::undoActionTriggered()
+{
+    CaretUndoStack* undoStack = getUndoStack();
+    AString errorMessage;
+    if ( ! undoStack->undo(errorMessage)) {
+        WuQMessageBox::errorOk(this,
+                               errorMessage);
+    }
+    
+    updateGraphicsWindowAndYokedWindows();
+    updateContent(m_browserTabContent);
+}
+
+/**
+ * Gets called when the select region action is triggered
+ * @param checked
+ *    New checked status
+ */
+void
+BrainBrowserWindowToolBarOrientation::selectRegionActionTriggered(const bool checked)
+{
+    if (m_browserTabContent != NULL) {
+        if (checked) {
+            m_browserTabContent->setMouseLeftDragMode(MouseLeftDragModeEnum::REGION_SELECTION);
+        }
+        else {
+            m_browserTabContent->setMouseLeftDragMode(MouseLeftDragModeEnum::DEFAULT);
+        }
+    }
+    updateRegionSelectionAction();
+}
+
+/**
+ * @return Undo stack for this tab or NULL if not valid
+ */
+CaretUndoStack*
+BrainBrowserWindowToolBarOrientation::getUndoStack()
+{
+    CaretUndoStack* undoStack(NULL);
+    if (m_browserTabContent != NULL) {
+        ViewingTransformations* viewingTransform(m_browserTabContent->getViewingTransformation());
+        if (viewingTransform != NULL) {
+            undoStack = viewingTransform->getRedoUndoStack();
+        }
+    }
+    return undoStack;
+}
+
