@@ -43,6 +43,7 @@ namespace caret {
     public:
         BrainBrowserWindowToolBarTab(const int32_t browserWindowIndex,
                                      QToolButton* toolBarLockWindowAndAllTabAspectRatioButton,
+                                     QToolButton* toolBarUndoUnlockWindowAndAllTabAspectRatioButton,
                                      BrainBrowserWindowToolBar* parentToolBar,
                                      const QString& objectNamePrefix);
         
@@ -87,8 +88,6 @@ namespace caret {
         
         BrainBrowserWindowToolBar* m_parentToolBar;
         
-        QToolButton* m_lockWindowAndAllTabAspectButton;
-        
         QAction* m_lightingAction;
         
         QLabel* m_macroRecordingLabel;
