@@ -35,7 +35,7 @@
 #include "BrowserTabContent.h"
 #include "CaretAssert.h"
 #include "CiftiBrainordinateLabelFile.h"
-#include "EventGraphicsUpdateAllWindows.h"
+#include "EventGraphicsPaintSoonAllWindows.h"
 #include "EventManager.h"
 #include "EventSurfaceColoringInvalidate.h"
 #include "EventUserInterfaceUpdate.h"
@@ -181,7 +181,7 @@ GroupAndNameHierarchyViewController::updateGraphics()
     if (m_selectionInvalidatesSurfaceNodeColoring) {
         EventManager::get()->sendEvent(EventSurfaceColoringInvalidate().getPointer());
     }
-    EventManager::get()->sendEvent(EventGraphicsUpdateAllWindows().getPointer());
+    EventManager::get()->sendEvent(EventGraphicsPaintSoonAllWindows().getPointer());
 }
 
 
