@@ -31,6 +31,10 @@ namespace caret {
     class ChartTwoOverlay;
     class ChartableMatrixSeriesInterface;
     class EnumComboBoxTemplate;
+    class HistologyOverlay;
+    class HistologySlicesFile;
+    class MediaFile;
+    class MediaOverlay;
     class Overlay;
     
     class MapYokingGroupComboBox : public WuQWidget {
@@ -58,6 +62,10 @@ namespace caret {
         
         void validateYokingChange(ChartTwoOverlay* chartOverlay);
         
+        void validateYokingChange(HistologyOverlay* histologyOverlay);
+        
+        void validateYokingChange(MediaOverlay* mediaOverlay);
+        
         void validateYokingChange(AnnotationTextSubstitutionFile* annTextSubFile);
         
         // ADD_NEW_METHODS_HERE
@@ -78,8 +86,10 @@ namespace caret {
 
         MapYokingGroupComboBox& operator=(const MapYokingGroupComboBox&);
         
-        YokeValidationResult validateYoking(AnnotationTextSubstitutionFile* annTextSubFile,
-                                            CaretMappableDataFile* selectedFile,
+        YokeValidationResult validateYoking(AnnotationTextSubstitutionFile* selectedAnnTextSubFile,
+                                            CaretMappableDataFile* selectedMapFile,
+                                            HistologySlicesFile* selectedHistologySlicesFile,
+                                            MediaFile* selectedMediaFile,
                                             int32_t& selectedMapIndexInOut,
                                             bool& selectionStatusInOut);
         
