@@ -40,8 +40,8 @@
 #include "AnnotationColorBar.h"
 #include "CaretMappableDataFile.h"
 #include "EventDataFileReload.h"
-#include "EventGraphicsUpdateAllWindows.h"
-#include "EventGraphicsUpdateOneWindow.h"
+#include "EventGraphicsPaintSoonAllWindows.h"
+#include "EventGraphicsPaintSoonOneWindow.h"
 #include "EventManager.h"
 #include "EventMapYokingSelectMap.h"
 #include "EventOverlaySettingsEditorDialogRequest.h"
@@ -98,12 +98,12 @@ OverlayViewController::OverlayViewController(const Qt::Orientation orientation,
     m_constructionReloadFileAction = NULL;
     
     int minComboBoxWidth = 200;
-    int maxComboBoxWidth = 100000; //400;
+    int maxComboBoxWidth = 100000;
     if (orientation == Qt::Horizontal) {
         minComboBoxWidth = 50;
         maxComboBoxWidth = 100000;
     }
-    const QComboBox::SizeAdjustPolicy comboSizePolicy = QComboBox::AdjustToContentsOnFirstShow; //QComboBox::AdjustToContents;
+    const QComboBox::SizeAdjustPolicy comboSizePolicy = QComboBox::AdjustToContentsOnFirstShow;
 
     WuQMacroManager* macroManager = WuQMacroManager::instance();
     CaretAssert(macroManager);
@@ -196,25 +196,7 @@ OverlayViewController::OverlayViewController(const Qt::Orientation orientation,
                                         + "ShowColorBar");
     macroManager->addMacroSupportToObject(m_colorBarToolButton,
                                           ("Enable " + descriptivePrefix + " colorbar"));
-    
-//    /*
-//     * ColorBar Tool Button
-//     */
-//    QIcon colorBarIcon;
-//    const bool colorBarIconValid = WuQtUtilities::loadIcon(":/LayersPanel/colorbar.png",
-//                                                           colorBarIcon);
-//    this->colorBarAction = WuQtUtilities::createAction("CB", 
-//                                                       "Display color bar for this overlay", 
-//                                                       this, 
-//                                                       this, 
-//                                                       SLOT(colorBarActionTriggered(bool)));
-//    this->colorBarAction->setCheckable(true);
-//    if (colorBarIconValid) {
-//        this->colorBarAction->setIcon(colorBarIcon);
-//    }
-//    QToolButton* colorBarToolButton = new QToolButton();
-//    colorBarToolButton->setDefaultAction(this->colorBarAction);
-    
+        
     /*
      * Settings Tool Button
      */
@@ -294,7 +276,7 @@ OverlayViewController::OverlayViewController(const Qt::Orientation orientation,
         this->gridLayoutGroup->addWidget(settingsToolButton,
                                          row, 1,
                                          Qt::AlignHCenter);
-        this->gridLayoutGroup->addWidget(m_colorBarToolButton, //colorBarToolButton,
+        this->gridLayoutGroup->addWidget(m_colorBarToolButton,
                                          row, 2);
         this->gridLayoutGroup->addWidget(m_constructionToolButton,
                                          row, 3);
@@ -325,7 +307,7 @@ OverlayViewController::OverlayViewController(const Qt::Orientation orientation,
                                          row, 0);
         this->gridLayoutGroup->addWidget(settingsToolButton,
                                          row, 1);
-        this->gridLayoutGroup->addWidget(m_colorBarToolButton, //colorBarToolButton,
+        this->gridLayoutGroup->addWidget(m_colorBarToolButton,
                                          row, 2);
         this->gridLayoutGroup->addWidget(m_constructionToolButton,
                                          row, 3);
@@ -416,11 +398,6 @@ OverlayViewController::fileComboBoxSelected(int indx)
     
     validateYokingSelection();
     
-    //validateYokingSelection(overlay->getYokingGroup());
-    // not needed with call to validateYokingSelection: this->updateViewController(this->overlay);
-    
-    // called inside validateYokingSelection();  this->updateUserInterfaceAndGraphicsWindow();
-
     updateOverlaySettingsEditor();
     updateViewController(this->overlay);
     
@@ -465,10 +442,16 @@ OverlayViewController::mapIndexSpinBoxValueChanged(int indx)
     
     const MapYokingGroupEnum::Enum mapYoking = overlay->getMapYokingGroup();
     if (mapYoking != MapYokingGroupEnum::MAP_YOKING_GROUP_OFF) {
+        AnnotationTextSubstitutionFile* nullAnnTextSubsFile(NULL);
+        HistologySlicesFile* nullHistologySlicesFile(NULL);
+        MediaFile* nullMediaFile(NULL);
         EventMapYokingSelectMap selectMapEvent(mapYoking,
                                                file,
-                                               NULL,
+                                               nullAnnTextSubsFile,
+                                               nullHistologySlicesFile,
+                                               nullMediaFile,
                                                overlayIndex,
+                                               MapYokingGroupEnum::MediaAllFramesStatus::ALL_FRAMES_OFF,
                                                overlay->isEnabled());
         EventManager::get()->sendEvent(selectMapEvent.getPointer());
     }
@@ -512,10 +495,16 @@ OverlayViewController::mapNameComboBoxSelected(int indx)
     
     const MapYokingGroupEnum::Enum mapYoking = overlay->getMapYokingGroup();
     if (mapYoking != MapYokingGroupEnum::MAP_YOKING_GROUP_OFF) {
+        AnnotationTextSubstitutionFile* nullAnnTextSubsFile(NULL);
+        HistologySlicesFile* nullHistologySlicesFile(NULL);
+        MediaFile* nullMediaFile(NULL);
         EventMapYokingSelectMap selectMapEvent(mapYoking,
                                                file,
-                                               NULL,
+                                               nullAnnTextSubsFile,
+                                               nullHistologySlicesFile,
+                                               nullMediaFile,
                                                indx,
+                                               MapYokingGroupEnum::MediaAllFramesStatus::ALL_FRAMES_OFF,
                                                overlay->isEnabled());
         EventManager::get()->sendEvent(selectMapEvent.getPointer());
     }
@@ -554,10 +543,16 @@ OverlayViewController::enabledCheckBoxClicked(bool checked)
         this->overlay->getSelectionData(myFile,
                                         myIndex);
         
+        AnnotationTextSubstitutionFile* nullAnnTextSubsFile(NULL);
+        HistologySlicesFile* nullHistologySlicesFile(NULL);
+        MediaFile* nullMediaFile(NULL);
         EventMapYokingSelectMap selectMapEvent(mapYoking,
                                                myFile,
-                                               NULL,
+                                               nullAnnTextSubsFile,
+                                               nullHistologySlicesFile,
+                                               nullMediaFile,
                                                myIndex,
+                                               MapYokingGroupEnum::MediaAllFramesStatus::ALL_FRAMES_OFF,
                                                overlay->isEnabled());
         EventManager::get()->sendEvent(selectMapEvent.getPointer());
     }
@@ -610,7 +605,6 @@ OverlayViewController::validateYokingSelection()
     m_mapYokingGroupComboBox->validateYokingChange(this->overlay);
     updateViewController(this->overlay);
     updateGraphicsWindow();
-    //EventManager::get()->sendEvent(EventGraphicsUpdateAllWindows().getPointer());
 }
 
 /**
@@ -672,12 +666,10 @@ OverlayViewController::updateViewController(Overlay* overlay)
      */
     std::vector<CaretMappableDataFile*> dataFiles;
     CaretMappableDataFile* selectedFile = NULL;
-    //AString selectedMapUniqueID = "";
     int32_t selectedMapIndex = -1;
     if (this->overlay != NULL) {
         this->overlay->getSelectionData(dataFiles, 
                                   selectedFile, 
-                                  //selectedMapUniqueID,
                                   selectedMapIndex);
     }
     
@@ -745,9 +737,6 @@ OverlayViewController::updateViewController(Overlay* overlay)
     m_mapYokingGroupComboBox->setMapYokingGroup(overlay->getMapYokingGroup());
     
     m_colorBarToolButton->setChecked(overlay->getColorBar()->isDisplayed());
-//    this->colorBarAction->blockSignals(true);
-//    this->colorBarAction->setChecked(overlay->getColorBar()->isDisplayed());
-//    this->colorBarAction->blockSignals(false);
     
     this->opacityDoubleSpinBox->blockSignals(true);
     this->opacityDoubleSpinBox->setValue(overlay->getOpacity());
@@ -816,7 +805,6 @@ OverlayViewController::updateViewController(Overlay* overlay)
     this->constructionAction->setEnabled(true);
     this->opacityDoubleSpinBox->setEnabled(haveOpacity);
     this->m_mapYokingGroupComboBox->getWidget()->setEnabled(haveYoking);
-    //this->colorBarAction->setEnabled(dataIsMappedWithPalette);
     this->m_colorBarToolButton->setEnabled(dataIsMappedWithPalette);
     this->settingsAction->setEnabled(true);
 }
@@ -853,10 +841,10 @@ OverlayViewController::updateGraphicsWindow()
 {
     EventManager::get()->sendEvent(EventSurfaceColoringInvalidate().getPointer());
     if (this->overlay->getMapYokingGroup() != MapYokingGroupEnum::MAP_YOKING_GROUP_OFF) {
-        EventManager::get()->sendEvent(EventGraphicsUpdateAllWindows().getPointer());
+        EventManager::get()->sendEvent(EventGraphicsPaintSoonAllWindows().getPointer());
     }
     else {
-        EventManager::get()->sendEvent(EventGraphicsUpdateOneWindow(this->browserWindowIndex).getPointer());
+        EventManager::get()->sendEvent(EventGraphicsPaintSoonOneWindow(this->browserWindowIndex).getPointer());
     }
 }
 
@@ -1010,6 +998,9 @@ OverlayViewController::menuConstructionAboutToShow()
                     break;
                 case DataFileTypeEnum::CONNECTIVITY_PARCEL_DENSE:
                     break;
+                case DataFileTypeEnum::CONNECTIVITY_PARCEL_DYNAMIC:
+                    dynConnFlag = true;
+                    break;
                 case DataFileTypeEnum::CONNECTIVITY_PARCEL_LABEL:
                     break;
                 case DataFileTypeEnum::CONNECTIVITY_PARCEL_SCALAR:
@@ -1026,8 +1017,12 @@ OverlayViewController::menuConstructionAboutToShow()
                     break;
                 case DataFileTypeEnum::CONNECTIVITY_SCALAR_DATA_SERIES:
                     break;
+                case DataFileTypeEnum::CZI_IMAGE_FILE:
+                    break;
                 case DataFileTypeEnum::FOCI:
                     break;
+                case DataFileTypeEnum::HISTOLOGY_SLICES:
+                    break;
                 case DataFileTypeEnum::IMAGE:
                     break;
                 case DataFileTypeEnum::LABEL:
@@ -1041,6 +1036,8 @@ OverlayViewController::menuConstructionAboutToShow()
                     break;
                 case DataFileTypeEnum::RGBA:
                     break;
+                case DataFileTypeEnum::SAMPLES:
+                    break;
                 case DataFileTypeEnum::SCENE:
                     break;
                 case DataFileTypeEnum::SPECIFICATION:
