@@ -30,17 +30,18 @@
 #include "BrainOpenGLWidget.h"
 #include "BrowserTabContent.h"
 #include "CaretAssert.h"
+#include "CaretLogger.h"
 #include "ControlPoint3D.h"
 #include "ControlPointFile.h"
 #include "DisplayPropertiesImages.h"
 #include "EventBrowserWindowDrawingContent.h"
-#include "EventGraphicsUpdateAllWindows.h"
-#include "EventGraphicsUpdateOneWindow.h"
+#include "EventGraphicsPaintSoonAllWindows.h"
+#include "EventGraphicsPaintSoonOneWindow.h"
 #include "EventManager.h"
 #include "EventUserInterfaceUpdate.h"
 #include "GuiManager.h"
 #include "ImageFile.h"
-#include "SelectionItemImage.h"
+#include "SelectionItemMediaLogicalCoordinate.h"
 #include "SelectionItemImageControlPoint.h"
 #include "SelectionItemVoxel.h"
 #include "SelectionManager.h"
@@ -61,14 +62,15 @@ using namespace caret;
 
 /**
  * Constructor.
+ * @param browserIndexIndex
+ *    Index of window
  */
-UserInputModeImage::UserInputModeImage(const int32_t windowIndex)
-: UserInputModeView(windowIndex,
-                    UserInputModeEnum::Enum::IMAGE),
-  m_windowIndex(windowIndex)
+UserInputModeImage::UserInputModeImage(const int32_t browserIndexIndex)
+: UserInputModeView(browserIndexIndex,
+                    UserInputModeEnum::Enum::IMAGE)
 {
     m_inputModeImageWidget = new UserInputModeImageWidget(this,
-                                                        windowIndex);
+                                                          browserIndexIndex);
     m_editOperation = EDIT_OPERATION_ADD;
     setWidgetForToolBar(m_inputModeImageWidget);
 }
@@ -160,7 +162,7 @@ UserInputModeImage::updateAfterControlPointsChanged()
     /*
      * Need to update all graphics windows and all border controllers.
      */
-    EventManager::get()->sendEvent(EventGraphicsUpdateAllWindows().getPointer());
+    EventManager::get()->sendEvent(EventGraphicsPaintSoonAllWindows().getPointer());
     EventManager::get()->sendEvent(EventUserInterfaceUpdate().getPointer());
 }
 
@@ -179,15 +181,14 @@ UserInputModeImage::mouseLeftClick(const MouseEvent& mouseEvent)
     }
     
     BrainOpenGLWidget* openGLWidget = mouseEvent.getOpenGLWidget();
-    //BrowserTabContent* browserTabContent = viewportContent->getBrowserTabContent();
     SelectionManager* idManager =
-    openGLWidget->performIdentification(mouseEvent.getX(),
-                                        mouseEvent.getY(),
-                                        true);
-    
-    SelectionItemImage* idImage = idManager->getImageIdentification();
-    CaretAssert(idImage);
+    openGLWidget->performIdentificationAll(mouseEvent.getX(),
+                                           mouseEvent.getY(),
+                                           true);
     
+    SelectionItemMediaLogicalCoordinate* idMediaPixel = idManager->getMediaLogicalCoordinateIdentification();
+    CaretAssert(idMediaPixel);
+
     SelectionItemVoxel* idVoxel = idManager->getVoxelIdentification();
     CaretAssert(idVoxel);
     
@@ -198,12 +199,12 @@ UserInputModeImage::mouseLeftClick(const MouseEvent& mouseEvent)
     
     switch (m_editOperation) {
         case EDIT_OPERATION_ADD:
-            if (idImage->isValid()
+            if (idMediaPixel->isValid()
                 && idVoxel->isValid()) {
-                addControlPoint(idImage,
+                addControlPoint(idMediaPixel,
                                 idVoxel);
             }
-            else if (idImage->isValid()) {
+            else if (idMediaPixel->isValid()) {
                 toolTipMessage = "Mouse click is over image but must also be over volume slice";
             }
             else if (idVoxel->isValid()) {
@@ -237,22 +238,33 @@ UserInputModeImage::mouseLeftClick(const MouseEvent& mouseEvent)
 /**
  * Create a control point for the given image and voxel coordinates.
  *
- * @param imageSelection
+ * @param mediaSelection
  *     The image selection.
  * @param voxelSelection
  *     The voxel selection.
  */
 void
-UserInputModeImage::addControlPoint(SelectionItemImage* imageSelection,
+UserInputModeImage::addControlPoint(SelectionItemMediaLogicalCoordinate* mediaSelection,
                                     const SelectionItemVoxel* voxelSelection)
 {
-    ImageFile* imageFile = imageSelection->getImageFile();
-    CaretAssert(imageFile);
+    MediaFile* mediaFile = mediaSelection->getMediaFile();
+    CaretAssert(mediaFile);
+    ImageFile* imageFile = mediaFile->castToImageFile();
+    if (imageFile == NULL) {
+        CaretLogWarning("File for adding control point must be an image file but is: "
+                        + DataFileTypeEnum::toName(mediaFile->getDataFileType()));
+        return;
+    }
     ControlPointFile* controlPointFile = imageFile->getControlPointFile();
     CaretAssert(controlPointFile);
     
-    const float pixelX = imageSelection->getPixelI();
-    const float pixelY = imageSelection->getPixelJ();
+    const PixelLogicalIndex pixelLogicalIndex(mediaSelection->getPixelLogicalIndex());
+    const int64_t imageHeight(imageFile->getHeight());
+    const PixelIndex pixelBottomLeft(pixelLogicalIndex.getI(),
+                                     imageHeight - pixelLogicalIndex.getJ(),
+                                     pixelLogicalIndex.getK());
+    const float pixelX = pixelBottomLeft.getI();
+    const float pixelY = pixelBottomLeft.getJ();
     const float pixelZ = 0.0;
     
     double voxelXYZ[3] = { 0.0, 0.0, 0.0 };
@@ -298,7 +310,7 @@ UserInputModeImage::deleteAllControlPoints()
 ImageFile*
 UserInputModeImage::getImageFile() const
 {
-    EventBrowserWindowDrawingContent windowGet(m_windowIndex);
+    EventBrowserWindowDrawingContent windowGet(getBrowserWindowIndex());
     EventManager::get()->sendEvent(windowGet.getPointer());
     
     DisplayPropertiesImages* dpi = GuiManager::get()->getBrain()->getDisplayPropertiesImages();
@@ -323,10 +335,9 @@ UserInputModeImage::getTabIndex() const
 {
     int32_t tabIndex = -1;
     
-    EventBrowserWindowDrawingContent windowGet(m_windowIndex);
+    EventBrowserWindowDrawingContent windowGet(getBrowserWindowIndex());
     EventManager::get()->sendEvent(windowGet.getPointer());
     
-    //DisplayPropertiesImages* dpi = GuiManager::get()->getBrain()->getDisplayPropertiesImages();
     BrowserTabContent* tabContent = windowGet.getSelectedBrowserTabContent();
     if (tabContent != NULL) {
         tabIndex = tabContent->getTabNumber();
