@@ -52,13 +52,14 @@
 #include "VolumeFileCreateDialog.h"
 #include "WuQDataEntryDialog.h"
 #include "WuQFactory.h"
+#include "WuQHyperlinkToolTip.h"
 #include "WuQMessageBox.h"
 #include "WuQSpinBoxOddValue.h"
 #include "WuQtUtilities.h"
 
 using namespace caret;
 
-
+static const QString& helpHyperlink("help://VoxelEditing");
     
 /**
  * \class caret::UserInputModeVolumeEditWidget 
@@ -138,7 +139,7 @@ UserInputModeVolumeEditWidget::updateWidget()
     bool isValid = false;
     
     UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
-    if (m_inputModeVolumeEdit->getVolumeEditInfo(volumeEditInfo)) {
+    if (m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo)) {
         m_lockAction->setChecked(volumeEditInfo.m_volumeFileEditorDelegate->isLocked(volumeEditInfo.m_mapIndex));
         
         if (volumeEditInfo.m_volumeFile != NULL) {
@@ -226,16 +227,22 @@ UserInputModeVolumeEditWidget::isModeButtonEnabled(const VolumeEditingModeEnum::
 {
     bool modeEnabledFlag(false);
     UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
-    if (m_inputModeVolumeEdit->getVolumeEditInfo(volumeEditInfo)) {
+    if (m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo)) {
         m_lockAction->setChecked(volumeEditInfo.m_volumeFileEditorDelegate->isLocked(volumeEditInfo.m_mapIndex));
         
         if (volumeEditInfo.m_volumeFile != NULL) {
-            const bool orthogonalFlag = (volumeEditInfo.m_sliceProjectionType
-                                         == VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_ORTHOGONAL);
-            if (orthogonalFlag) {
-                modeEnabledFlag = true;
+            switch (volumeEditInfo.m_sliceProjectionType) {
+                case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR:
+                    break;
+                case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_MPR_THREE:
+                    break;
+                case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_OBLIQUE:
+                    break;
+                case VolumeSliceProjectionTypeEnum::VOLUME_SLICE_PROJECTION_ORTHOGONAL:
+                    modeEnabledFlag = true;
+                    break;
             }
-            else {
+            if ( ! modeEnabledFlag) {
                 modeEnabledFlag = VolumeEditingModeEnum::isObliqueEditingAllowed(mode);
             }
         }
@@ -258,6 +265,8 @@ UserInputModeVolumeEditWidget::createSelectionToolBar()
                                                                     this,
                                                                     this, SLOT(newFileActionTriggered())));
     WuQtUtilities::setToolButtonStyleForQt5Mac(m_newFileToolButton);
+    WuQHyperlinkToolTip::addWithHyperlink(m_newFileToolButton,
+                                          helpHyperlink);
     
     m_addMapsToolButton = new QToolButton();
     m_addMapsToolButton->setDefaultAction(WuQtUtilities::createAction("Add",
@@ -266,6 +275,8 @@ UserInputModeVolumeEditWidget::createSelectionToolBar()
                                                                       this,
                                                                       this, SLOT(addMapsActionTriggered())));
     WuQtUtilities::setToolButtonStyleForQt5Mac(m_addMapsToolButton);
+    WuQHyperlinkToolTip::addWithHyperlink(m_addMapsToolButton,
+                                          helpHyperlink);
     
     m_lockAction = WuQtUtilities::createAction("Lock",
                                                "Lock/unlock volume file to disallow/allow editing",
@@ -275,12 +286,15 @@ UserInputModeVolumeEditWidget::createSelectionToolBar()
     QToolButton* lockFileToolButton = new QToolButton();
     lockFileToolButton->setDefaultAction(m_lockAction);
     WuQtUtilities::setToolButtonStyleForQt5Mac(lockFileToolButton);
-    
+    WuQHyperlinkToolTip::addWithHyperlink(lockFileToolButton,
+                                          m_lockAction,
+                                          helpHyperlink);
+
     
 
     QLabel* brushSizeLabel = new QLabel("Brush");
     const int MIN_BRUSH_SIZE = 1;
-    const int MAX_BRUSH_SIZE = 99;
+    const int MAX_BRUSH_SIZE = 9999;
     
     QLabel* xLabel = new QLabel("P:");
     m_xBrushSizeSpinBox = new WuQSpinBoxOddValue(this);
@@ -290,7 +304,9 @@ UserInputModeVolumeEditWidget::createSelectionToolBar()
                      this, SLOT(xBrushSizeValueChanged(int)));
     m_xBrushSizeSpinBox->getWidget()->setToolTip("Parasagittal brush size (voxels).\n"
                                                  "Must be an odd value.");
-    
+    WuQHyperlinkToolTip::addWithHyperlink(m_xBrushSizeSpinBox->getWidget(),
+                                          helpHyperlink);
+
     QLabel* yLabel = new QLabel("C:");
     m_yBrushSizeSpinBox = new WuQSpinBoxOddValue(this);
     m_yBrushSizeSpinBox->setRange(MIN_BRUSH_SIZE, MAX_BRUSH_SIZE);
@@ -299,7 +315,9 @@ UserInputModeVolumeEditWidget::createSelectionToolBar()
                      this, SLOT(yBrushSizeValueChanged(int)));
     m_yBrushSizeSpinBox->getWidget()->setToolTip("Coronal brush size (voxels).\n"
                                                  "Must be an odd value.");
-    
+    WuQHyperlinkToolTip::addWithHyperlink(m_yBrushSizeSpinBox->getWidget(),
+                                          helpHyperlink);
+
     QLabel* zLabel = new QLabel("A:");
     m_zBrushSizeSpinBox = new WuQSpinBoxOddValue(this);
     m_zBrushSizeSpinBox->setRange(MIN_BRUSH_SIZE, MAX_BRUSH_SIZE);
@@ -308,7 +326,9 @@ UserInputModeVolumeEditWidget::createSelectionToolBar()
                      this, SLOT(zBrushSizeValueChanged(int)));
     m_zBrushSizeSpinBox->getWidget()->setToolTip("Axial brush size (voxels).\n"
                                                  "Must be an odd value.");
-    
+    WuQHyperlinkToolTip::addWithHyperlink(m_zBrushSizeSpinBox->getWidget(),
+                                          helpHyperlink);
+
     m_voxelValueLabel = new QLabel("Value");
     m_voxelFloatValueSpinBox = WuQFactory::newDoubleSpinBoxWithMinMaxStepDecimalsSignalDouble(-1000.0,
                                                                                          1000.0,
@@ -316,6 +336,9 @@ UserInputModeVolumeEditWidget::createSelectionToolBar()
                                                                                          this,
                                                                                          SLOT(voxelValueChanged(double)));
     m_voxelFloatValueSpinBox->setValue(1.0);
+    m_voxelFloatValueSpinBox->setToolTip("Set value for functional volume editing");
+    WuQHyperlinkToolTip::addWithHyperlink(m_voxelFloatValueSpinBox,
+                                          helpHyperlink);
 
     m_voxelLabelValueAction = WuQtUtilities::createAction("Label",
                                                           "Choose Label for Voxels",
@@ -324,7 +347,9 @@ UserInputModeVolumeEditWidget::createSelectionToolBar()
     m_voxelLabelValueToolButton = new QToolButton();
     m_voxelLabelValueToolButton->setDefaultAction(m_voxelLabelValueAction);
     WuQtUtilities::setToolButtonStyleForQt5Mac(m_voxelLabelValueToolButton);
-    
+    WuQHyperlinkToolTip::addWithHyperlink(m_voxelLabelValueToolButton,
+                                          helpHyperlink);
+
     m_voxelLabelValueToolButton->setFixedWidth(m_voxelLabelValueToolButton->sizeHint().width());
     m_voxelFloatValueSpinBox->setFixedWidth(m_voxelLabelValueToolButton->sizeHint().width());
     
@@ -382,7 +407,9 @@ UserInputModeVolumeEditWidget::createEditWidget()
                                                                  this,
                                                                  this, SLOT(undoActionTriggered())));
     WuQtUtilities::setToolButtonStyleForQt5Mac(undoToolButton);
-    
+    WuQHyperlinkToolTip::addWithHyperlink(undoToolButton,
+                                          helpHyperlink);
+
     
     QToolButton* redoToolButton = new QToolButton();
     redoToolButton->setDefaultAction(WuQtUtilities::createAction("Redo",
@@ -390,7 +417,8 @@ UserInputModeVolumeEditWidget::createEditWidget()
                                                                  this,
                                                                  this, SLOT(redoActionTriggered())));
     WuQtUtilities::setToolButtonStyleForQt5Mac(redoToolButton);
-    
+    WuQHyperlinkToolTip::addWithHyperlink(redoToolButton,
+                                          helpHyperlink);
     
     QToolButton* resetToolButton = new QToolButton();
     resetToolButton->setDefaultAction(WuQtUtilities::createAction("Reset",
@@ -398,7 +426,9 @@ UserInputModeVolumeEditWidget::createEditWidget()
                                                                   this,
                                                                   this, SLOT(resetActionTriggered())));
     WuQtUtilities::setToolButtonStyleForQt5Mac(resetToolButton);
-    
+    WuQHyperlinkToolTip::addWithHyperlink(resetToolButton,
+                                          helpHyperlink);
+
     QWidget* widget = new QWidget();
     QHBoxLayout* editLayout = new QHBoxLayout(widget);
     WuQtUtilities::setLayoutSpacingAndMargins(editLayout, 4, 2);
@@ -420,7 +450,10 @@ UserInputModeVolumeEditWidget::createModeRadioButton(const VolumeEditingModeEnum
 {
     QRadioButton* rb = new QRadioButton(VolumeEditingModeEnum::toGuiName(mode));
     WuQtUtilities::setWordWrappedToolTip(rb, VolumeEditingModeEnum::toToolTip(mode));
+    WuQHyperlinkToolTip::addWithHyperlink(rb,
+                                          helpHyperlink);
     
+
     return rb;
 }
 /**
@@ -587,7 +620,14 @@ UserInputModeVolumeEditWidget::getEditingMode() const
 void
 UserInputModeVolumeEditWidget::newFileActionTriggered()
 {
-    VolumeFileCreateDialog newVolumeDialog(m_newFileToolButton);
+    VolumeMappableInterface* underlayVolume(NULL);
+    UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
+    if (m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo)) {
+        underlayVolume = volumeEditInfo.m_underlayVolume;
+    }
+    
+    VolumeFileCreateDialog newVolumeDialog(underlayVolume,
+                                           m_newFileToolButton);
     if (newVolumeDialog.exec() == VolumeFileCreateDialog::Accepted) {
         VolumeFile* vf = newVolumeDialog.getVolumeFile();
         if (vf != NULL) {
@@ -618,7 +658,7 @@ UserInputModeVolumeEditWidget::viewVolumeInNewOverlay(VolumeFile* vf,
                                                       const int32_t mapIndex)
 {
     UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
-    m_inputModeVolumeEdit->getVolumeEditInfo(volumeEditInfo);
+    m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo);
     if (volumeEditInfo.m_topOverlay != NULL) {
         /*
          * Add new overlay and place new volume file in the top most overlay
@@ -632,8 +672,7 @@ UserInputModeVolumeEditWidget::viewVolumeInNewOverlay(VolumeFile* vf,
                                                       mapIndex);
         volumeEditInfo.m_topOverlay->setEnabled(true);
         volumeEditInfo.m_topOverlay->setMapYokingGroup(MapYokingGroupEnum::MAP_YOKING_GROUP_OFF);
-        m_inputModeVolumeEdit->updateGraphicsAfterEditing(vf,
-                                                          mapIndex);
+        m_inputModeVolumeEdit->updateGraphicsAfterEditing();
     }
     
     EventManager::get()->sendEvent(EventUserInterfaceUpdate().getPointer());
@@ -647,7 +686,7 @@ void
 UserInputModeVolumeEditWidget::addMapsActionTriggered()
 {
     UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
-    if (m_inputModeVolumeEdit->getVolumeEditInfo(volumeEditInfo)) {
+    if (m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo)) {
         VolumeFile* vf = volumeEditInfo.m_volumeFile;
         
         WuQDataEntryDialog ded("Add Map",
@@ -683,7 +722,21 @@ void
 UserInputModeVolumeEditWidget::lockFileActionTriggered()
 {
     UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
-    if (m_inputModeVolumeEdit->getVolumeEditInfo(volumeEditInfo)) {
+    if (m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo)) {
+        /*
+         * Warn user if unlocking and volume is not plumb
+         */
+        if ( ! m_lockAction->isChecked()) {
+            if ( ! volumeEditInfo.m_volumeFile->isPlumb()) {
+                const AString msg("Volume is not aligned to P/C/A Axes.\n"
+                                  "Editing may not function correctly.");
+                const bool result(WuQMessageBox::warningOkCancel(this, msg));
+                if ( ! result) {
+                    m_lockAction->setChecked(true);
+                    return;
+                }
+            }
+        }
         volumeEditInfo.m_volumeFileEditorDelegate->setLocked(volumeEditInfo.m_mapIndex,
                                                              m_lockAction->isChecked());
     }
@@ -696,15 +749,14 @@ void
 UserInputModeVolumeEditWidget::undoActionTriggered()
 {
     UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
-    if (m_inputModeVolumeEdit->getVolumeEditInfo(volumeEditInfo)) {
+    if (m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo)) {
         AString errorMessage;
         if ( ! volumeEditInfo.m_volumeFileEditorDelegate->undo(volumeEditInfo.m_mapIndex,
                                                                errorMessage)) {
             WuQMessageBox::errorOk(this,
                                    errorMessage);
         }
-        m_inputModeVolumeEdit->updateGraphicsAfterEditing(volumeEditInfo.m_volumeFile,
-                                                          volumeEditInfo.m_mapIndex);
+        m_inputModeVolumeEdit->updateGraphicsAfterEditing();
     }
 }
 
@@ -715,15 +767,14 @@ void
 UserInputModeVolumeEditWidget::redoActionTriggered()
 {
     UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
-    if (m_inputModeVolumeEdit->getVolumeEditInfo(volumeEditInfo)) {
+    if (m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo)) {
         AString errorMessage;
         if ( ! volumeEditInfo.m_volumeFileEditorDelegate->redo(volumeEditInfo.m_mapIndex,
                                                                errorMessage)) {
             WuQMessageBox::errorOk(this,
                                    errorMessage);
         }
-        m_inputModeVolumeEdit->updateGraphicsAfterEditing(volumeEditInfo.m_volumeFile,
-                                                          volumeEditInfo.m_mapIndex);
+        m_inputModeVolumeEdit->updateGraphicsAfterEditing();
     }
 }
 
@@ -734,15 +785,14 @@ void
 UserInputModeVolumeEditWidget::resetActionTriggered()
 {
     UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
-    if (m_inputModeVolumeEdit->getVolumeEditInfo(volumeEditInfo)) {
+    if (m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo)) {
         AString errorMessage;
         if ( ! volumeEditInfo.m_volumeFileEditorDelegate->reset(volumeEditInfo.m_mapIndex,
                                                                errorMessage)) {
             WuQMessageBox::errorOk(this,
                                    errorMessage);
         }
-        m_inputModeVolumeEdit->updateGraphicsAfterEditing(volumeEditInfo.m_volumeFile,
-                                                          volumeEditInfo.m_mapIndex);
+        m_inputModeVolumeEdit->updateGraphicsAfterEditing();
     }
 }
 
@@ -789,7 +839,7 @@ void
 UserInputModeVolumeEditWidget::labelValueActionTriggered()
 {
     UserInputModeVolumeEdit::VolumeEditInfo volumeEditInfo;
-    if (m_inputModeVolumeEdit->getVolumeEditInfo(volumeEditInfo)) {
+    if (m_inputModeVolumeEdit->getVolumeEditInfoForStatus(volumeEditInfo)) {
         if (volumeEditInfo.m_volumeFile != NULL) {
             GiftiLabelTableEditor lte(volumeEditInfo.m_volumeFile,
                                       volumeEditInfo.m_mapIndex,
