@@ -75,7 +75,7 @@ OperationParameters* OperationVolumeLabelImport::getParameters()
         "Label names are specified on a separate line from their value and color, in order to let label names contain spaces.  " +
         "Whitespace is trimmed from both ends of the label name, but is kept if it is in the middle of a label.  " +
         "Do not specify the \"unlabeled\" key in the file, it is assumed that 0 means not labeled unless -unlabeled-value is specified.  " +
-        "The value of <key> specifies what value in the imported file should be used as this label.  " +
+        "The value of <key> specifies what value in the imported file should be used as this label (these same key values are also used in the output file).  " +
         "The values of <red>, <green>, <blue> and <alpha> must be integers from 0 to 255, and will specify the color the label is drawn as " +
         "(alpha of 255 means fully opaque, which is probably what you want).\n\n" +
         "By default, it will create new label names with names like LABEL_5 for any values encountered that are not mentioned in the " +
@@ -163,7 +163,7 @@ void OperationVolumeLabelImport::useParameters(OperationParameters* myParams, Pr
             }
             if (value == GiftiLabel::getInvalidLabelKey())
             {
-                throw OperationException("entry #" + AString::number(labelCount) + ", " + AString(labelName.c_str()) + " specifies unusable key value: " + value);
+                throw OperationException("entry #" + AString::number(labelCount) + ", " + AString(labelName.c_str()) + " specifies unusable key value: " + AString::number(value));
             }
             while (isspace(labelListFile.peek()))
             {
