@@ -22,21 +22,27 @@
 
 #include "CaretAssert.h"
 #include "CaretLogger.h"
-
-#include "ProgramParametersException.h"
+#include "CaretCommandGlobalOptions.h"
 
 #include "AnnotationFile.h"
 #include "BorderFile.h"
+#include "CaretDataFileHelper.h"
 #include "CiftiFile.h"
 #include "FociFile.h"
 #include "LabelFile.h"
 #include "MetricFile.h"
+#include "ProgramParametersException.h"
 #include "SurfaceFile.h"
 #include "VolumeFile.h"
 
 using namespace std;
 using namespace caret;
 
+const AString ProvenanceHelper::PROVENANCE_NAME = "Provenance";
+const AString ProvenanceHelper::PARENT_PROVENANCE_NAME = "ParentProvenance";
+const AString ProvenanceHelper::PROGRAM_PROVENANCE_NAME = "ProgramProvenance";
+const AString ProvenanceHelper::CWD_PROVENANCE_NAME = "WorkingDirectory";
+
 ParameterComponent::ParameterComponent()
 {
 }
@@ -75,6 +81,7 @@ OperationParameters::OperationParameters()
 
 ParameterComponent::ParameterComponent(const ParameterComponent& rhs)
 {
+    m_provHelper = rhs.m_provHelper;
     m_paramList.resize(rhs.m_paramList.size());
     for (size_t i = 0; i < m_paramList.size(); ++i)
     {
@@ -97,6 +104,180 @@ ParameterComponent::ParameterComponent(const ParameterComponent& rhs)
     }
 }
 
+void ProvenanceHelper::addToProvenance(const GiftiMetaData* md, const AString& filename)
+{
+    if (m_outputProvDone)
+    {
+        CaretAssert(false);
+        throw ProgramParametersException("an output file was requested before all parent provenance was added");
+    }
+    if (!m_doProvenance) return;
+    CaretMutexLocker locked(&m_mutex);//this will get called during parallel file reading, protect modification of the parent provenance
+    if (md != NULL)
+    {
+        AString prov = md->get(PROVENANCE_NAME);
+        if (prov != "")
+        {
+            m_parentProvenance += filename + ":\n" + prov + "\n\n";
+        }
+    }
+}
+
+void ProvenanceHelper::outputProvenance(GiftiMetaData* md)
+{
+    if (!m_doProvenance || md == NULL) return;
+    md->set(PROVENANCE_NAME, m_provenance);
+    md->set(PROGRAM_PROVENANCE_NAME, m_versionProvenance);
+    md->set(CWD_PROVENANCE_NAME, m_workingDir);
+    if (m_parentProvenance != "")
+    {
+        md->set(PARENT_PROVENANCE_NAME, m_parentProvenance);
+    }
+    m_outputProvDone = true;//this shouldn't be used in parallel, don't need to protect it
+}
+
+void ParameterComponent::prepareProvenance(ProvenanceHelper* helper)
+{
+    m_provHelper = helper;
+    for (size_t i = 0; i < m_optionList.size(); ++i)
+    {
+        m_optionList[i]->prepareProvenance(helper);
+    }
+    for (size_t i = 0; i < m_repeatableOptions.size(); ++i)
+    {
+        m_repeatableOptions[i]->prepareProvenance(helper);
+    }
+}
+
+void RepeatableOption::prepareProvenance(ProvenanceHelper* helper)
+{
+    m_template.prepareProvenance(helper);
+    for (size_t i = 0; i < m_instances.size(); ++i)
+    {
+        m_instances[i]->prepareProvenance(helper);
+    }
+}
+
+void ParameterComponent::checkInputFilesExist()
+{
+    for (size_t i = 0; i < m_paramList.size(); ++i)
+    {
+        m_paramList[i]->checkExists();
+    }
+    //don't check output files
+    for (size_t i = 0; i < m_optionList.size(); ++i)
+    {
+        if (m_optionList[i]->m_present)
+        {
+            m_optionList[i]->checkInputFilesExist();
+        }
+    }
+    for (size_t i = 0; i < m_repeatableOptions.size(); ++i)
+    {
+        m_repeatableOptions[i]->checkInputFilesExist();
+    }
+}
+
+void RepeatableOption::checkInputFilesExist()
+{
+    //don't check the template
+    for (size_t i = 0; i < m_instances.size(); ++i)
+    {
+        m_instances[i]->checkInputFilesExist();
+    }
+}
+
+void ParameterComponent::openAllInputFiles()
+{
+    for (size_t i = 0; i < m_paramList.size(); ++i)
+    {
+        //hack, but maintainable: call the appropriate "get" and then reset the "operation used" flag
+        switch (m_paramList[i]->getType())
+        {
+            case OperationParametersEnum::ANNOTATION:
+                getAnnotation(m_paramList[i]->m_key);
+                break;
+            case OperationParametersEnum::BORDER:
+                getBorder(m_paramList[i]->m_key);
+                break;
+            case OperationParametersEnum::CIFTI:
+                getCifti(m_paramList[i]->m_key);
+                break;
+            case OperationParametersEnum::FOCI:
+                getFoci(m_paramList[i]->m_key);
+                break;
+            case OperationParametersEnum::LABEL:
+                getLabel(m_paramList[i]->m_key);
+                break;
+            case OperationParametersEnum::METRIC:
+                getMetric(m_paramList[i]->m_key);
+                break;
+            case OperationParametersEnum::SURFACE:
+                getSurface(m_paramList[i]->m_key);
+                break;
+            case OperationParametersEnum::VOLUME:
+                getVolume(m_paramList[i]->m_key);
+                break;
+            case OperationParametersEnum::BOOL:
+            case OperationParametersEnum::DOUBLE:
+            case OperationParametersEnum::INT:
+            case OperationParametersEnum::STRING:
+                break;
+        }
+        m_paramList[i]->m_operationUsed = false;
+    }
+    for (size_t i = 0; i < m_optionList.size(); ++i)
+    {
+        if (m_optionList[i]->m_present)
+        {
+            m_optionList[i]->openAllInputFiles();
+        }
+    }
+    for (size_t i = 0; i < m_repeatableOptions.size(); ++i)
+    {
+        m_repeatableOptions[i]->openAllInputFiles();
+    }
+}
+
+void ParameterComponent::closeAllInputFiles()
+{
+    for (size_t i = 0; i < m_paramList.size(); ++i)
+    {
+        //hacky way, delete the whole parameter and let the destructor sort it out - we will only call this when we are done with the inputs
+        delete m_paramList[i];
+    }
+    m_paramList.clear();
+    for (size_t i = 0; i < m_optionList.size(); ++i)
+    {
+        if (m_optionList[i]->m_present)
+        {
+            m_optionList[i]->closeAllInputFiles();
+        }
+    }
+    for (size_t i = 0; i < m_repeatableOptions.size(); ++i)
+    {
+        m_repeatableOptions[i]->closeAllInputFiles();
+    }
+}
+
+void RepeatableOption::openAllInputFiles()
+{
+    //don't call it on the template
+    for (size_t i = 0; i < m_instances.size(); ++i)
+    {
+        m_instances[i]->openAllInputFiles();
+    }
+}
+
+void RepeatableOption::closeAllInputFiles()
+{
+    //don't call it on the template
+    for (size_t i = 0; i < m_instances.size(); ++i)
+    {
+        m_instances[i]->closeAllInputFiles();
+    }
+}
+
 OptionalParameter* ParameterComponent::createOptionalParameter(const int32_t key, const AString& optionSwitch, const AString& description)
 {
     if (!checkUniqueOption(key))
@@ -110,7 +291,7 @@ OptionalParameter* ParameterComponent::createOptionalParameter(const int32_t key
     return ret;
 }
 
-ParameterComponent* ParameterComponent::createRepeatableParameter(const int32_t key, const AString& optionSwitch, const AString& description)
+OptionalComponent* ParameterComponent::createRepeatableParameter(const int32_t key, const AString& optionSwitch, const AString& description)
 {
     if (!checkUniqueRepeatable(key))
     {
@@ -204,11 +385,11 @@ vector<AString> ParameterComponent::findUncheckedParams(const AString& contextSt
     {
         if (!m_repeatableOptions[i]->m_operationUsed)
         {
-            ret.push_back("option '" + m_repeatableOptions[i]->m_optionSwitch + "' of " + contextString + " was not checked by the operation");
+            ret.push_back("option '" + m_repeatableOptions[i]->m_template.m_optionSwitch + "' of " + contextString + " was not checked by the operation");
         }
         for (size_t j = 0; j < m_repeatableOptions[i]->m_instances.size(); ++j)
         {
-            vector<AString> temp = m_repeatableOptions[i]->m_instances[j]->findUncheckedParams("option '" + m_repeatableOptions[i]->m_optionSwitch + "'");
+            vector<AString> temp = m_repeatableOptions[i]->m_instances[j]->findUncheckedParams("option '" + m_repeatableOptions[i]->m_template.m_optionSwitch + "'");
             ret.insert(ret.end(), temp.begin(), temp.end());
         }
     }
@@ -541,21 +722,6 @@ bool ParameterComponent::getBoolean(const int32_t key)
     return ((BooleanParameter*)getInputParameter(key, OperationParametersEnum::BOOL))->m_parameter;
 }
 
-CiftiFile* ParameterComponent::getCifti(const int32_t key)
-{
-    return ((CiftiParameter*)getInputParameter(key, OperationParametersEnum::CIFTI))->m_parameter.getPointer();
-}
-
-FociFile* ParameterComponent::getFoci(const int32_t key)
-{
-    return ((FociParameter*)getInputParameter(key, OperationParametersEnum::FOCI))->m_parameter.getPointer();
-}
-
-BorderFile* ParameterComponent::getBorder(const int32_t key)
-{
-    return ((BorderParameter*)getInputParameter(key, OperationParametersEnum::BORDER))->m_parameter.getPointer();
-}
-
 double ParameterComponent::getDouble(const int32_t key)
 {
     return ((DoubleParameter*)getInputParameter(key, OperationParametersEnum::DOUBLE))->m_parameter;
@@ -566,72 +732,224 @@ int64_t ParameterComponent::getInteger(const int32_t key)
     return ((IntegerParameter*)getInputParameter(key, OperationParametersEnum::INT))->m_parameter;
 }
 
-LabelFile* ParameterComponent::getLabel(const int32_t key)
-{
-    return ((LabelParameter*)getInputParameter(key, OperationParametersEnum::LABEL))->m_parameter.getPointer();
-}
-
-AnnotationFile* ParameterComponent::getAnnotation(const int32_t key)
-{
-    return ((AnnotationParameter*)getInputParameter(key, OperationParametersEnum::ANNOTATION))->m_parameter.getPointer();
-}
-
-MetricFile* ParameterComponent::getMetric(const int32_t key)
-{
-    return ((MetricParameter*)getInputParameter(key, OperationParametersEnum::METRIC))->m_parameter.getPointer();
-}
-
 const AString& ParameterComponent::getString(const int32_t key)
 {
     return ((StringParameter*)getInputParameter(key, OperationParametersEnum::STRING))->m_parameter;
 }
 
+AnnotationFile* ParameterComponent::getAnnotation(const int32_t key)
+{
+    AnnotationParameter* myParam = (AnnotationParameter*)getInputParameter(key, OperationParametersEnum::ANNOTATION);
+    if (myParam->m_parameter == NULL)
+    {
+        try
+        {
+            myParam->lazyGet()->readFile(myParam->m_filename);
+            m_provHelper->addToProvenance(myParam->m_parameter->getFileMetaData(), myParam->m_filename);
+        } catch (const bad_alloc&) {
+            throw DataFileException(myParam->m_filename, CaretDataFileHelper::createBadAllocExceptionMessage(myParam->m_filename));
+        }
+    }
+    return myParam->m_parameter;
+}
+
+BorderFile* ParameterComponent::getBorder(const int32_t key)
+{
+    BorderParameter* myParam = (BorderParameter*)getInputParameter(key, OperationParametersEnum::BORDER);
+    if (myParam->m_parameter == NULL)
+    {
+        try
+        {
+            myParam->lazyGet()->readFile(myParam->m_filename);
+            m_provHelper->addToProvenance(myParam->m_parameter->getFileMetaData(), myParam->m_filename);
+        } catch (const bad_alloc&) {
+            throw DataFileException(myParam->m_filename, CaretDataFileHelper::createBadAllocExceptionMessage(myParam->m_filename));
+        }
+    }
+    return myParam->m_parameter;
+}
+
+CiftiFile* ParameterComponent::getCifti(const int32_t key)
+{
+    CiftiParameter* myParam = (CiftiParameter*)getInputParameter(key, OperationParametersEnum::CIFTI);
+    if (myParam->m_parameter == NULL)
+    {
+        try
+        {
+            myParam->lazyGet()->openFile(myParam->m_filename);
+            if (caret_global_command_options.m_ciftiReadMemory)
+            {
+                myParam->m_parameter->convertToInMemory();
+            }
+        } catch (const bad_alloc&) {
+            throw DataFileException(myParam->m_filename, CaretDataFileHelper::createBadAllocExceptionMessage(myParam->m_filename));
+        }
+        m_provHelper->addToProvenance(myParam->m_parameter->getCiftiXML().getFileMetaData(), myParam->m_filename);
+    }
+    return myParam->m_parameter;
+}
+
+FociFile* ParameterComponent::getFoci(const int32_t key)
+{
+    FociParameter* myParam = (FociParameter*)getInputParameter(key, OperationParametersEnum::FOCI);
+    if (myParam->m_parameter == NULL)
+    {
+        try
+        {
+            myParam->lazyGet()->readFile(myParam->m_filename);
+            m_provHelper->addToProvenance(myParam->m_parameter->getFileMetaData(), myParam->m_filename);
+        } catch (const bad_alloc&) {
+            throw DataFileException(myParam->m_filename, CaretDataFileHelper::createBadAllocExceptionMessage(myParam->m_filename));
+        }
+    }
+    return myParam->m_parameter;
+}
+
+LabelFile* ParameterComponent::getLabel(const int32_t key)
+{
+    LabelParameter* myParam = (LabelParameter*)getInputParameter(key, OperationParametersEnum::LABEL);
+    if (myParam->m_parameter == NULL)
+    {
+        try
+        {
+            myParam->lazyGet()->readFile(myParam->m_filename);
+            m_provHelper->addToProvenance(myParam->m_parameter->getFileMetaData(), myParam->m_filename);
+        } catch (const bad_alloc&) {
+            throw DataFileException(myParam->m_filename, CaretDataFileHelper::createBadAllocExceptionMessage(myParam->m_filename));
+        }
+    }
+    return myParam->m_parameter;
+}
+
+MetricFile* ParameterComponent::getMetric(const int32_t key)
+{
+    MetricParameter* myParam = (MetricParameter*)getInputParameter(key, OperationParametersEnum::METRIC);
+    if (myParam->m_parameter == NULL)
+    {
+        try
+        {
+            myParam->lazyGet()->readFile(myParam->m_filename);
+            m_provHelper->addToProvenance(myParam->m_parameter->getFileMetaData(), myParam->m_filename);
+        } catch (const bad_alloc&) {
+            throw DataFileException(myParam->m_filename, CaretDataFileHelper::createBadAllocExceptionMessage(myParam->m_filename));
+        }
+    }
+    return myParam->m_parameter;
+}
+
 SurfaceFile* ParameterComponent::getSurface(const int32_t key)
 {
-    return ((SurfaceParameter*)getInputParameter(key, OperationParametersEnum::SURFACE))->m_parameter.getPointer();
+    SurfaceParameter* myParam = (SurfaceParameter*)getInputParameter(key, OperationParametersEnum::SURFACE);
+    if (myParam->m_parameter == NULL)
+    {
+        try
+        {
+            myParam->lazyGet()->readFile(myParam->m_filename);
+            m_provHelper->addToProvenance(myParam->m_parameter->getFileMetaData(), myParam->m_filename);
+        } catch (const bad_alloc&) {
+            throw DataFileException(myParam->m_filename, CaretDataFileHelper::createBadAllocExceptionMessage(myParam->m_filename));
+        }
+    }
+    return myParam->m_parameter;
 }
 
 VolumeFile* ParameterComponent::getVolume(const int32_t key)
 {
-    return ((VolumeParameter*)getInputParameter(key, OperationParametersEnum::VOLUME))->m_parameter.getPointer();
+    VolumeParameter* myParam = (VolumeParameter*)getInputParameter(key, OperationParametersEnum::VOLUME);
+    if (myParam->m_parameter == NULL)
+    {
+        try
+        {
+            myParam->lazyGet()->readFile(myParam->m_filename);
+            m_provHelper->addToProvenance(myParam->m_parameter->getFileMetaData(), myParam->m_filename);
+        } catch (const bad_alloc&) {
+            throw DataFileException(myParam->m_filename, CaretDataFileHelper::createBadAllocExceptionMessage(myParam->m_filename));
+        }
+    }
+    return myParam->m_parameter;
 }
 
-CiftiFile* ParameterComponent::getOutputCifti(const int32_t key)
+//delay provenance/global options for in-memory outputs until after operation, because reinitializing volume file clears the header
+AnnotationFile* ParameterComponent::getOutputAnnotation(const int32_t key)
 {
-    return ((CiftiParameter*)getOutputParameter(key, OperationParametersEnum::CIFTI))->m_parameter.getPointer();
-}
-
-FociFile* ParameterComponent::getOutputFoci(const int32_t key)
-{
-    return ((FociParameter*)getOutputParameter(key, OperationParametersEnum::FOCI))->m_parameter.getPointer();
+    return ((AnnotationParameter*)getOutputParameter(key, OperationParametersEnum::ANNOTATION))->lazyGet();
 }
 
 BorderFile* ParameterComponent::getOutputBorder(const int32_t key)
 {
-    return ((BorderParameter*)getOutputParameter(key, OperationParametersEnum::BORDER))->m_parameter.getPointer();
+    return ((BorderParameter*)getOutputParameter(key, OperationParametersEnum::BORDER))->lazyGet();
+}
+
+//cifti can do on-disk writing, so it gets special treatment, does provenance and global options early
+CiftiFile* ParameterComponent::getOutputCifti(const int32_t key)
+{
+    CiftiParameter* myParam = (CiftiParameter*)getOutputParameter(key, OperationParametersEnum::CIFTI);
+    if (myParam->m_parameter == NULL)
+    {
+        CiftiFile* thisCifti = myParam->lazyGet();
+        if (myParam->m_doOnDiskWrite)
+        {
+            thisCifti->setWritingFile(myParam->m_filename);
+        }
+        if (caret_global_command_options.m_ciftiScale)
+        {
+            thisCifti->setWritingDataTypeAndScaling(caret_global_command_options.m_ciftiDType, caret_global_command_options.m_ciftiMin, caret_global_command_options.m_ciftiMax);
+        } else {
+            thisCifti->setWritingDataTypeNoScaling(caret_global_command_options.m_ciftiDType);
+        }
+        if (myParam->m_collidingParam != NULL)
+        {
+            bool warn = true;//setting the colliding pointer means it would have been on-disk if the filenames were different
+            if (myParam->m_collidingParam->m_parameter != NULL)
+            {
+                vector<int64_t> dims = myParam->m_collidingParam->m_parameter->getDimensions();//for the purpose of warning, assume the output dims will be the same as the input being overwritten
+                int64_t totalSize = sizeof(float);
+                for (int j = 0; j < (int)dims.size(); ++j)
+                {
+                    totalSize *= dims[j];
+                }
+                if (totalSize <= ((int64_t)2) * 1024 * 1024 * 1024)//suppress the message for non-large input files, on the assumption that the output file will be the same size
+                {
+                    warn = false;
+                }
+            }
+            if (warn)
+            {
+                CaretLogInfo("Computing output file '" + myParam->m_filename + "' in memory due to collision with input file");
+            }
+        }
+        CiftiXML tempXML;
+        CiftiSeriesMap tempMap(1);
+        tempXML.setNumberOfDimensions(2);
+        tempXML.setMap(0, tempMap);
+        tempXML.setMap(1, tempMap);
+        m_provHelper->outputProvenance(tempXML.getFileMetaData());
+        thisCifti->setCiftiXML(tempXML, false);//'false' tells it to use this new metadata, rather than copying metadata from the old XML (which is default so that provenance metadata persists through naive usage)
+    }
+    return myParam->m_parameter;
+}
+
+FociFile* ParameterComponent::getOutputFoci(const int32_t key)
+{
+    return ((FociParameter*)getOutputParameter(key, OperationParametersEnum::FOCI))->lazyGet();
 }
 
 LabelFile* ParameterComponent::getOutputLabel(const int32_t key)
 {
-    return ((LabelParameter*)getOutputParameter(key, OperationParametersEnum::LABEL))->m_parameter.getPointer();
-}
-
-SurfaceFile* ParameterComponent::getOutputSurface(const int32_t key)
-{
-    return ((SurfaceParameter*)getOutputParameter(key, OperationParametersEnum::SURFACE))->m_parameter.getPointer();
-}
-
-VolumeFile* ParameterComponent::getOutputVolume(const int32_t key)
-{
-    return ((VolumeParameter*)getOutputParameter(key, OperationParametersEnum::VOLUME))->m_parameter.getPointer();
-}
-
-AnnotationFile* ParameterComponent::getOutputAnnotation(const int32_t key)
-{
-    return ((AnnotationParameter*)getOutputParameter(key, OperationParametersEnum::ANNOTATION))->m_parameter.getPointer();
+    return ((LabelParameter*)getOutputParameter(key, OperationParametersEnum::LABEL))->lazyGet();
 }
 
 MetricFile* ParameterComponent::getOutputMetric(const int32_t key)
 {
-    return ((MetricParameter*)getOutputParameter(key, OperationParametersEnum::METRIC))->m_parameter.getPointer();
+    return ((MetricParameter*)getOutputParameter(key, OperationParametersEnum::METRIC))->lazyGet();
+}
+
+SurfaceFile* ParameterComponent::getOutputSurface(const int32_t key)
+{
+    return ((SurfaceParameter*)getOutputParameter(key, OperationParametersEnum::SURFACE))->lazyGet();
+}
+
+VolumeFile* ParameterComponent::getOutputVolume(const int32_t key)
+{
+    return ((VolumeParameter*)getOutputParameter(key, OperationParametersEnum::VOLUME))->lazyGet();
 }
