@@ -695,14 +695,13 @@ QList<QwtLegendData> QwtPlotMultiBarChart::legendData() const
         QwtLegendData data;
 
         QVariant titleValue;
-        qVariantSetValue( titleValue, d_data->barTitles[i] );
+        titleValue.setValue(d_data->barTitles[i] );
         data.setValue( QwtLegendData::TitleRole, titleValue );
 
         if ( !legendIconSize().isEmpty() )
         {
             QVariant iconValue;
-            qVariantSetValue( iconValue, 
-                legendIcon( i, legendIconSize() ) );
+            iconValue.setValue(legendIcon( i, legendIconSize() ) );
 
             data.setValue( QwtLegendData::IconRole, iconValue );
         }
