@@ -91,7 +91,7 @@ void QwtScaleWidget::initScale( QwtScaleDraw::Alignment align )
 {
     d_data = new PrivateData;
 
-    d_data->layoutFlags = 0;
+    d_data->layoutFlags = LayoutFlags();
     if ( align == QwtScaleDraw::RightScale )
         d_data->layoutFlags |= TitleInverted;
 
@@ -415,7 +415,7 @@ void QwtScaleWidget::paintEvent( QPaintEvent *event )
     painter.setClipRegion( event->region() );
 
     QStyleOption opt;
-    opt.init(this);
+    opt.initFrom(this);
     style()->drawPrimitive(QStyle::PE_Widget, &opt, &painter, this);
 
     draw( &painter );
@@ -718,9 +718,8 @@ QSize QwtScaleWidget::minimumSizeHint() const
     if ( o == Qt::Vertical )
         size.transpose();
 
-    int left, right, top, bottom;
-    getContentsMargins( &left, &top, &right, &bottom );
-    return size + QSize( left + right, top + bottom );
+    QMargins m(contentsMargins());
+    return size + QSize( m.left() + m.right(), m.top() + m.bottom() );
 }
 
 /*!
