@@ -219,7 +219,15 @@ void QwtWidgetOverlay::updateMask()
         draw( &painter );
         painter.end();
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+        QVector<QRect> rects;
+        for (auto& r : hint) {
+            rects.push_back(r);
+        }
+        mask = qwtAlphaMask( image, rects );
+#else
         mask = qwtAlphaMask( image, hint.rects() );
+#endif
 
         if ( d_data->renderMode == QwtWidgetOverlay::DrawOverlay )
         {
@@ -269,8 +277,18 @@ void QwtWidgetOverlay::paintEvent( QPaintEvent* event )
         const QImage image( d_data->rgbaBuffer, 
             width(), height(), qwtMaskImageFormat() );
 
+
+        QVector<QRect> clipRegionRects;
+#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
+        for (auto& r : clipRegion) {
+            clipRegionRects.push_back(r);
+        }
+#else
+        clipRegionRects = clipRegion.rects();
+#endif
+        
         QVector<QRect> rects;
-        if ( clipRegion.rects().size() > 2000 )
+        if ( clipRegionRects.size() > 2000 )
         {
             // the region is to complex
             painter.setClipRegion( clipRegion );
@@ -278,7 +296,7 @@ void QwtWidgetOverlay::paintEvent( QPaintEvent* event )
         }
         else
         {
-            rects = clipRegion.rects();
+            rects = clipRegionRects;
         }
 
         for ( int i = 0; i < rects.size(); i++ )
