@@ -39,7 +39,6 @@
 #include "ScenePathNameArray.h"
 #include "ScenePrimitive.h"
 #include "ScenePrimitiveArray.h"
-#include "SceneXmlElements.h"
 #include "WuQMacroGroup.h"
 #include "WuQMacroGroupXmlStreamWriter.h"
 
@@ -192,6 +191,8 @@ SceneXmlStreamWriter::writeSceneObject(const SceneObject* sceneObject)
             break;
         case SceneObjectDataTypeEnum::SCENE_INTEGER:
             break;
+        case SceneObjectDataTypeEnum::SCENE_LONG_INTEGER:
+            break;
         case SceneObjectDataTypeEnum::SCENE_INVALID:
             break;
         case SceneObjectDataTypeEnum::SCENE_PATH_NAME:
@@ -233,6 +234,9 @@ SceneXmlStreamWriter::writeArrayObject(const SceneObjectArray* objectArray)
         case SceneObjectDataTypeEnum::SCENE_INTEGER:
             writeArrayPrimitiveType(objectArray->castToScenePrimitiveArray());
             break;
+        case SceneObjectDataTypeEnum::SCENE_LONG_INTEGER:
+            writeArrayPrimitiveType(objectArray->castToScenePrimitiveArray());
+            break;
         case SceneObjectDataTypeEnum::SCENE_INVALID:
             CaretAssert(0);
             break;
@@ -313,6 +317,13 @@ SceneXmlStreamWriter::writeMapObject(const SceneObjectMapIntegerKey* objectMap)
             }
                 break;
             case SceneObjectDataTypeEnum::SCENE_INTEGER:
+            {
+                const ScenePrimitive* value = valueObject->castToScenePrimitive();
+                CaretAssert(value);
+                m_xmlWriter->writeCharacters(value->stringValue());
+            }
+                break;
+            case SceneObjectDataTypeEnum::SCENE_LONG_INTEGER:
             {
                 const ScenePrimitive* value = valueObject->castToScenePrimitive();
                 CaretAssert(value);
@@ -380,6 +391,9 @@ SceneXmlStreamWriter::writeSingleObject(const SceneObject* sceneObject)
         case SceneObjectDataTypeEnum::SCENE_INTEGER:
             writePrimitive(sceneObject->castToScenePrimitive());
             break;
+        case SceneObjectDataTypeEnum::SCENE_LONG_INTEGER:
+            writePrimitive(sceneObject->castToScenePrimitive());
+            break;
         case SceneObjectDataTypeEnum::SCENE_INVALID:
             CaretAssert(0);
             break;
